declare module "weave/app/WeaveProperties" {
    import * as weavejs from "weavejs";
    import { Weave } from "weavejs";
    import LinkableBoolean = weavejs.core.LinkableBoolean;
    import LinkableHashMap = weavejs.core.LinkableHashMap;
    import ILinkableObject = weavejs.api.core.ILinkableObject;
    import ILinkableObjectWithNewProperties = weavejs.api.core.ILinkableObjectWithNewProperties;
    import KeySet = weavejs.data.key.KeySet;
    import KeyFilter = weavejs.data.key.KeyFilter;
    import ColorColumn = weavejs.data.column.ColorColumn;
    export class AccessibilityProperties {
        enableAccessibilityFeatures: LinkableBoolean;
        enableCaptioning: LinkableBoolean;
    }
    export default class WeaveProperties implements ILinkableObject, ILinkableObjectWithNewProperties {
        static WEAVE_PROPERTIES: string;
        static DEFAULT_COLOR_COLUMN: string;
        static DEFAULT_COLOR_BIN_COLUMN: string;
        static DEFAULT_COLOR_DATA_COLUMN: string;
        static DEFAULT_SUBSET_KEYFILTER: string;
        static DEFAULT_SELECTION_KEYSET: string;
        static DEFAULT_PROBE_KEYSET: string;
        static ALWAYS_HIGHLIGHT_KEYSET: string;
        static SAVED_SELECTION_KEYSETS: string;
        static SAVED_SUBSETS_KEYFILTERS: string;
        static getProperties(context: Weave | ILinkableObject): WeaveProperties;
        static notify(weave: Weave, level: "error" | "warning" | "info" | "success", message: string): void;
        private _weave;
        notificationSystem: NotificationSystem.System;
        enableMenuBar: LinkableBoolean;
        showSessionHistorySlider: LinkableBoolean;
        enableSessionHistoryControls: LinkableBoolean;
        toolInteractions: LinkableHashMap;
        accessibility: AccessibilityProperties;
        enableGeometryProbing: LinkableBoolean;
        macros: LinkableHashMap;
        readonly weave: Weave;
        readonly defaultProbeKeySet: KeySet;
        readonly defaultSelectionKeySet: KeySet;
        readonly defaultSubsetKeyFilter: KeyFilter;
        readonly defaultColorColumn: ColorColumn;
        readonly defaultColorBinColumn: any;
        readonly defaultColorDataColumn: any;
        private init();
        readonly deprecatedStateMapping: Object;
    }
}
declare module "weave/modules/jquery" {
    var _default: JQueryStatic;
    export default _default;
}
declare module "weave/admin/Login" {
    import * as React from "react";
    export interface ILoginProps extends React.Props<Login> {
        onLogin?: (fields: any) => void;
    }
    export interface ILoginState {
    }
    export default class Login extends React.Component<ILoginProps, ILoginState> {
        element: Element;
        username: HTMLInputElement;
        password: HTMLInputElement;
        form: HTMLDivElement;
        constructor(props: ILoginProps);
        invalid(): void;
        componentDidMount(): void;
        render(): JSX.Element;
    }
}
declare module "weave/admin/ServiceLogin" {
    import * as React from "react";
    import * as weavejs from "weavejs";
    import PopupWindow = weavejs.ui.PopupWindow;
    import WeaveAdminService = weavejs.net.WeaveAdminService;
    import Login from "weave/admin/Login";
    export default class ServiceLogin {
        service: WeaveAdminService;
        context: React.ReactInstance;
        login: Login;
        onSuccess: (username: string) => void;
        onCancel: () => void;
        constructor(context: React.ReactInstance, service: WeaveAdminService);
        open: (onSuccess?: (username: string) => void, onCancel?: () => void) => PopupWindow;
        private show;
        handleLogin: (fields: {
            username: string;
            password: string;
        }, onSuccess: (username: string) => void) => void;
        conditionalOpen(onSuccess?: (username: string) => void, onCancel?: () => void): void;
    }
}
declare module "weave/menu/IWeaveMenus" {
    import * as React from "react";
    import * as weavejs from "weavejs";
    import { Weave } from "weavejs";
    import MenuItemProps = weavejs.ui.menu.MenuItemProps;
    import { CreateObjectFunction } from "weave/menu/WeaveMenus";
    import ServiceLogin from "weave/admin/ServiceLogin";
    export interface IWeaveMenus {
        context: React.ReactInstance;
        weave: Weave;
        createObject: CreateObjectFunction;
        onFileLoaded: () => void;
        openDataManager: () => void;
        enableDataManagerItem: () => boolean;
        showFileMenu: boolean;
        login: ServiceLogin;
        fileMenu: {
            getSessionItems: () => MenuItemProps[];
        };
        dataMenu: {
            getExportItems: () => MenuItemProps[];
        };
        getMenuList: () => MenuItemProps[];
    }
    export class IWeaveMenus {
    }
    export default IWeaveMenus;
}
declare module "weave/menu/SystemMenu" {
    import * as weavejs from "weavejs";
    import MenuBarItemProps = weavejs.ui.menu.MenuBarItemProps;
    import MenuItemProps = weavejs.ui.menu.MenuItemProps;
    import IWeaveMenus from "weave/menu/IWeaveMenus";
    export default class SystemMenu implements MenuBarItemProps {
        constructor(owner: IWeaveMenus);
        owner: IWeaveMenus;
        label: string;
        bold: boolean;
        readonly menu: MenuItemProps[];
    }
}
declare module "weave/dialog/ConfirmationDialog" {
    import * as React from "react";
    export default class ConfirmationDialog {
        static open(context: React.ReactInstance, message: string, onOk?: () => void, onCancel?: () => void): void;
    }
}
declare module "weave/modules/react-dropzone" {
    var _default: typeof ReactDropzone.Dropzone;
    export default _default;
}
declare module "weave/dialog/LocalFileOpenComponent" {
    import * as React from "react";
    import { IOpenFileProps, IOpenFileState } from "weave/dialog/FileDialog";
    export default class LocalFileOpenComponent extends React.Component<IOpenFileProps, IOpenFileState> {
        constructor(props: IOpenFileProps);
        handleFileChange: (event: React.FormEvent) => void;
        render(): JSX.Element;
    }
}
declare module "weave/ui/DataTable" {
    import * as React from "react";
    import * as weavejs from "weavejs";
    import SmartComponent = weavejs.ui.SmartComponent;
    import ResizingDivState = weavejs.ui.ResizingDivState;
    export type SortDirection = "ASC" | "DESC" | "NONE";
    export interface ISortHeaderProps extends React.Props<SortHeaderCell> {
        onSortChange?: (columnKey: string, sortDirection: SortDirection) => void;
        sortDirection?: SortDirection;
        disableSort?: boolean;
        columnKey?: string;
    }
    export const SortTypes: {
        ASC: "ASC";
        DESC: "DESC";
    };
    export class SortHeaderCell extends SmartComponent<ISortHeaderProps, Object> {
        defaultProps: ISortHeaderProps;
        constructor(props: ISortHeaderProps);
        static UpArrow(props: {}): JSX.Element;
        static DownArrow(props: {}): JSX.Element;
        render(): JSX.Element;
        onSortChange: (e: React.MouseEvent) => void;
        reverseSortDirection: (sortDirection: SortDirection) => "ASC" | "DESC";
    }
    export interface IDataTableProps<RowDatum> extends React.Props<DataTable<RowDatum>> {
        idProperty: string | ((row: RowDatum) => string);
        rows: RowDatum[];
        getCellValue?: (row: RowDatum, columnKey: string) => React.ReactChild;
        columnIds: string[];
        columnTitles?: {
            [columnId: string]: React.ReactChild;
        } | ((columnId: string) => React.ReactChild);
        enableHover?: boolean;
        enableSelection?: boolean;
        disableSort?: boolean;
        probedIds?: string[];
        selectedIds?: string[];
        onHover?: (id: string[]) => void;
        onSelection?: (id: string[]) => void;
        onCellDoubleClick?: (rowId: string, columnId: string) => void;
        rowHeight?: number;
        headerHeight?: number;
        initialColumnWidth?: number;
        evenlyExpandRows?: boolean;
        allowResizing?: boolean;
        width?: number;
        height?: number;
        showBottomBorder?: boolean;
        allowClear?: boolean;
        multiple?: boolean;
        sortId?: string;
        sortDirection?: SortDirection;
        /**
         *	a callback function that will be called if you want to sort the data
         *  manually. if this function is provided, the sortFunction will not be used
         **/
        onSortCallback?: (columnKey: string, sortDirection: SortDirection) => void;
        /**
         *  a sort function that will be called if you want to sort the data
         *  manually, otherwise the table will be sorted by default using plain value
         *  comparison
         **/
        sortFunction?: (rowIndexA: number, rowIndexB: number, columnKey: string) => number;
    }
    export interface IDataTableState {
        columnWidths?: {
            [columnId: string]: number;
        };
        sortId?: string;
        sortDirection?: SortDirection;
        width?: number;
        height?: number;
        orderOfRows?: number[];
        probedIds?: string[];
        selectedIds?: string[];
    }
    export class DataTable<RowDatum> extends SmartComponent<IDataTableProps<RowDatum>, IDataTableState> {
        private keyDown;
        private shiftDown;
        private firstIndex;
        private secondIndex;
        private lastClicked;
        private container;
        static defaultProps: IDataTableProps<any>;
        static defaultGetCellValue(row: any, columnKey: string): React.ReactChild;
        private idPropertyGetter;
        constructor(props: IDataTableProps<RowDatum>);
        componentWillReceiveProps(nextProps: IDataTableProps<RowDatum>): void;
        setIdPropertyGetter(props: IDataTableProps<RowDatum>): void;
        moveSelectedToTop(): void;
        getValue(index: number, columnKey: string): React.ReactChild;
        getId(index: number): string;
        getRowClass: (index: number) => string;
        onColumnResizeEndCallback: (newColumnWidth: number, columnKey: string) => void;
        onMouseEnter: (event: React.MouseEvent, index: number) => void;
        onMouseLeave: (event: React.MouseEvent, index: number) => void;
        onMouseDown: (event: React.MouseEvent, index: number) => void;
        updateSortDirection: (columnKey: string, sortDirection: SortDirection) => void;
        sortColumnIndices: (columnKey: string, sortDirection: SortDirection, orderOfRows: number[]) => void;
        handleResize: (newSize: ResizingDivState) => void;
        renderCell: (props: {
            rowIndex: number;
            columnKey: string;
            height: number;
            width: number;
        }) => JSX.Element;
        getColumnTitle(columnId: string): React.ReactChild;
        render(): JSX.Element;
    }
    export default class ObjectDataTable extends DataTable<IRow> {
    }
    export interface IRow {
        [columnKey: string]: React.ReactChild;
    }
}
declare module "weave/modules/clipboard" {
    import * as Clipboard from "clipboard";
    var _default: new (selector: string | Element | NodeListOf<Element>, options?: ClipboardOptions) => Clipboard;
    export default _default;
}
declare module "weave/util/FormatUtils" {
    export default class FormatUtils {
        static d3formatter: (n: number) => string;
        static defaultNumberFormatting(x: number): number | string;
        static defaultFileSizeFormatting(byteFileSize: number): string;
        static defaultFuzzyTimeAgoFormatting(date: Date): string;
    }
}
declare module "weave/ui/FileInfoView" {
    import * as React from "react";
    import * as weavejs from "weavejs";
    import WeaveFileInfo = weavejs.net.beans.WeaveFileInfo;
    export interface IFileInfoViewProps extends React.Props<FileInfoView> {
        fileInfo?: WeaveFileInfo;
        className?: string;
    }
    export interface IFileInfoViewState {
    }
    export default class FileInfoView extends React.Component<IFileInfoViewProps, IFileInfoViewState> {
        element: Element;
        clipboard: Clipboard;
        defaultProps: IFileInfoViewProps;
        constructor(props: IFileInfoViewProps);
        componentDidMount(): void;
        componentDidUpdate(): void;
        render(): JSX.Element;
    }
}
declare module "weave/dialog/WeaveServerFileOpenComponent" {
    import * as weavejs from "weavejs";
    import SmartComponent = weavejs.ui.SmartComponent;
    import { IOpenFileProps, IOpenFileState } from "weave/dialog/FileDialog";
    import ServiceLogin from "weave/admin/ServiceLogin";
    export default class WeaveServerFileOpenComponent extends SmartComponent<IOpenFileProps, IOpenFileState> {
        element: Element;
        dimmerSelector: any;
        login: ServiceLogin;
        constructor(props: IOpenFileProps);
        handleSuccess: (fields: any) => void;
        getWeaveFiles: () => void;
        openLogin: () => void;
        handleCancel: () => void;
        componentDidMount(): void;
        componentDidUpdate(): void;
        componentWillUnmount(): void;
        render(): JSX.Element;
    }
}
declare module "weave/dialog/FileDialog" {
    import * as React from "react";
    import * as weavejs from "weavejs";
    import WeaveFileInfo = weavejs.net.beans.WeaveFileInfo;
    import SmartComponent = weavejs.ui.SmartComponent;
    import PopupWindow = weavejs.ui.PopupWindow;
    export interface FileListItem {
        label: string;
        iconClass: string;
        isNewFile?: boolean;
    }
    export interface IOpenFileProps {
        openHandler: (file: string | File) => void;
        context?: React.ReactInstance;
    }
    export interface IOpenFileState {
        rejected?: boolean;
        fileInfo?: WeaveFileInfo;
        fileNames?: string[];
        allFiles?: boolean;
    }
    export interface IFileDialogProps extends React.Props<FileDialog> {
        openHandler: (file: string | File) => void;
        skipConfirmation?: boolean;
        context: React.ReactInstance;
    }
    export interface IFileDialogState {
        selected?: FileListItem;
    }
    export default class FileDialog extends SmartComponent<IFileDialogProps, IFileDialogState> {
        static NEW_SESSION: FileListItem;
        static MY_COMPUTER: FileListItem;
        static WEAVE_SERVER: FileListItem;
        static listItems: FileListItem[];
        static window: PopupWindow;
        static storageRegistry: Map<FileListItem, React.ComponentClass<IOpenFileProps>>;
        constructor(props: IFileDialogProps);
        confirmOpenHandler: (file: string | File) => void;
        componentDidMount(): void;
        render(): JSX.Element;
    }
}
declare module "weave/menu/FileMenu" {
    import * as weavejs from "weavejs";
    import PopupWindow = weavejs.ui.PopupWindow;
    import MenuBarItemProps = weavejs.ui.menu.MenuBarItemProps;
    import MenuItemProps = weavejs.ui.menu.MenuItemProps;
    import WeaveArchive = weavejs.core.WeaveArchive;
    import IWeaveMenus from "weave/menu/IWeaveMenus";
    export default class FileMenu implements MenuBarItemProps {
        constructor(owner: IWeaveMenus);
        owner: IWeaveMenus;
        label: string;
        bold: boolean;
        fileName: string;
        archive: WeaveArchive;
        readonly menu: MenuItemProps[];
        openFileDialog: () => PopupWindow;
        getSessionItems(): MenuItemProps[];
        saveDialog(fileName: string, onSave: (newFileName: string) => void): void;
        /**
         * This function will update the progress given a meta object file name and a percentage progress
         *
         * @param meta The meta object containing the percentage and file name
         */
        updateProgressIndicator: (meta: {
            percent: number;
            currentFile: string;
        }) => void;
        openFile: (e: any) => void;
        /**
         * TEMPORARY SOLUTION until we have a place to register file type handlers
         * Ideally this list would be dynamically generated.
         * @return An Array of FileFilter objects
         */
        getSupportedFileTypes(dataFilesOnly?: Boolean): string[];
        map_url_file: Map<string, File>;
        load: (file_or_url: string | File, pushHistory?: boolean) => void;
        pushHistory(url: string): void;
        handleHistoryEvent: (event: PopStateEvent) => void;
        newSession: () => void;
        handleOpenedFile: (file: File, dataFilesOnly?: Boolean) => void;
        loadArchive(fileContent: Uint8Array): void;
        handleOpenedFileContent(fileName: string, fileContent: Uint8Array, dataFilesOnly?: Boolean): void;
        private findDataSource<T>(type, filter, create?);
        static buildBaseUrl: () => string;
        static buildUrl: (url: String) => string;
        private _saveToServer;
        saveToServer: () => void;
        private _saveFile;
        saveFile: () => void;
    }
}
declare module "weave/ui/ColumnSelector" {
    import * as React from "react";
    import * as weavejs from "weavejs";
    import IColumnWrapper = weavejs.api.data.IColumnWrapper;
    import IWeaveTreeNode = weavejs.api.data.IWeaveTreeNode;
    import ILinkableHashMap = weavejs.api.core.ILinkableHashMap;
    export interface IColumnSelectorProps {
        attributeName: string;
        attributes: Map<string, IColumnWrapper | ILinkableHashMap>;
        pushCrumb?: (title: string, renderFn: () => JSX.Element, stateObject: any) => void;
        showAsList?: boolean;
        style?: React.CSSProperties;
    }
    export interface IColumnSelectorState {
    }
    export default class ColumnSelector extends React.Component<IColumnSelectorProps, IColumnSelectorState> {
        constructor(props: IColumnSelectorProps);
        componentWillReceiveProps(nextProps: IColumnSelectorProps): void;
        private comboBox;
        private lastActiveNode;
        private weaveRoot;
        private weaveRootTreeNode;
        static findSelectableAttributes(attribute: IColumnWrapper | ILinkableHashMap, defaultLabel?: string): [string, Map<string, IColumnWrapper | ILinkableHashMap>];
        private static getDataSourceDependencies(attribute);
        private setColumn;
        setColumnInHashmap: (selectedOptions: IWeaveTreeNode[]) => void;
        private readonly columnsHashmap;
        render(): JSX.Element;
    }
}
declare module "weave/editor/ControlPanel" {
    import * as React from "react";
    import * as weavejs from "weavejs";
    import { Weave } from "weavejs";
    import Dictionary2D = weavejs.util.Dictionary2D;
    import PopupWindow = weavejs.ui.PopupWindow;
    import PopupWindowProps = weavejs.ui.PopupWindowProps;
    export default class ControlPanel extends PopupWindow {
        static d2d_weave_class_popup: Dictionary2D<Weave, typeof React.Component, PopupWindow>;
        static openInstance<P>(weave: Weave, ComponentType: new (..._: any[]) => React.Component<P, any>, popupProps?: PopupWindowProps, componentProps?: P): ControlPanel;
    }
}
declare module "weave/ui/WeaveTree" {
    import * as React from "react";
    export interface IWeaveTreeState<TreeNode> {
        selectedItems?: TreeNode[];
        openItems?: TreeNode[];
        columnWidth?: number;
    }
    export interface IWeaveTreeProps<TreeNode> {
        root?: TreeNode;
        treeDescriptor?: ITreeDescriptor<TreeNode>;
        style?: any;
        hideRoot?: boolean;
        hideLeaves?: boolean;
        hideBranches?: boolean;
        filterFunc?: (node: TreeNode) => boolean;
        multipleSelection?: boolean;
        onSelect?: (selectedItems: TreeNode[]) => void;
        onExpand?: (openItems: TreeNode[]) => void;
        initialOpenItems?: TreeNode[];
        initialSelectedItems?: TreeNode[];
        onDoubleClick?: (item: TreeNode) => void;
    }
    export class WeaveTree<TreeNode> extends React.Component<IWeaveTreeProps<TreeNode>, IWeaveTreeState<TreeNode>> {
        static defaultProps: IWeaveTreeProps<any>;
        constructor(props: IWeaveTreeProps<TreeNode>);
        state: IWeaveTreeState<TreeNode>;
        componentWillReceiveProps(nextProps: IWeaveTreeProps<TreeNode>): void;
        isOpen(node: TreeNode): boolean;
        private nodeArraysChanged(arrayA, arrayB);
        private areNodesEqual;
        componentDidUpdate(prevProps: IWeaveTreeProps<TreeNode>, prevState: IWeaveTreeState<TreeNode>): void;
        componentDidMount(): void;
        private internalSetOpen(node, value);
        static CLASSNAME: string;
        static BRANCH_ICON_CLASSNAME: string;
        static LEAF_ICON_CLASSNAME: string;
        static OPEN_BRANCH_ICON_CLASSNAME: string;
        static EXPANDER_CLOSED_CLASS_NAME: string;
        static EXPANDER_OPEN_CLASS_NAME: string;
        static EXPANDER_HIDDEN_CLASS_NAME: string;
        private renderItem;
        enumerateItems: (node: TreeNode, result?: [number, TreeNode][], depth?: number) => [number, TreeNode][];
        rowHeight: number;
        private lastEnumeration;
        onSelect: (indices: string[]) => void;
        computeRowWidth(rowJSX: React.ReactChild): number;
        private longestRowJSX;
        render(): JSX.Element;
    }
    export interface ITreeDescriptor<Node> {
        getLabel(node: Node): string;
        isEqual(node1: Node, node2: Node): boolean;
        getChildren: (node: Node) => Node[];
        hasChildBranches: (node: Node) => boolean;
        isBranch: (node: Node) => boolean;
        addChildAt?: (parent: Node, newChild: Node, index: int) => boolean;
        removeChildAt?: (parent: Node, child: Node, index: int) => boolean;
    }
    export interface IBasicTreeNode {
        label?: string;
        children?: IBasicTreeNode[];
    }
    export class BasicTreeDescriptor<Node extends IBasicTreeNode> implements ITreeDescriptor<Node> {
        getLabel(node: Node): string;
        isEqual(node1: Node, node2: Node): boolean;
        getChildren(node: Node): Node[];
        isBranch(node: Node): boolean;
        hasChildBranches(node: Node): boolean;
        addChildAt(parent: Node, newChild: Node, index: int): boolean;
        removeChildAt(parent: Node, child: Node, index: int): boolean;
    }
    export default class BasicWeaveTree extends WeaveTree<IBasicTreeNode> {
    }
}
declare module "weave/ui/WeaveTreeNodeDescriptor" {
    import * as weavejs from "weavejs";
    import IWeaveTreeNode = weavejs.api.data.IWeaveTreeNode;
    import { ITreeDescriptor } from "weave/ui/WeaveTree";
    /**
     * Tells a Tree control how to work with IWeaveTreeNode objects.
     */
    export default class WeaveTreeNodeDescriptor<Node extends IWeaveTreeNode> implements ITreeDescriptor<Node> {
        getLabel(node: Node): string;
        isEqual(node1: Node, node2: Node): boolean;
        getChildren(node: Node): Node[];
        hasChildBranches(node: Node): boolean;
        isBranch(node: Node): boolean;
    }
}
declare module "weave/ui/WeaveDataTree" {
    import * as weavejs from "weavejs";
    import IWeaveTreeNode = weavejs.api.data.IWeaveTreeNode;
    import IColumnReference = weavejs.api.data.IColumnReference;
    import { WeaveTree, IWeaveTreeProps } from "weave/ui/WeaveTree";
    export default class WeaveDataTree extends WeaveTree<IWeaveTreeNode & IColumnReference> {
        static defaultProps: IWeaveTreeProps<any>;
        constructor(props: IWeaveTreeProps<IWeaveTreeNode & IColumnReference>);
    }
}
declare module "weave/ui/HierarchyExplorer" {
    import * as weavejs from "weavejs";
    import IWeaveTreeNode = weavejs.api.data.IWeaveTreeNode;
    import IColumnReference = weavejs.api.data.IColumnReference;
    import SmartComponent = weavejs.ui.SmartComponent;
    export interface IHierarchyExplorerProps {
        initialSelectedItems: (IWeaveTreeNode & IColumnReference)[];
        root: IWeaveTreeNode & IColumnReference;
        onSelect: (selectedNodes: (IWeaveTreeNode & IColumnReference)[]) => void;
        onDoubleClick: (clickedNode: IWeaveTreeNode & IColumnReference) => void;
        skipSelections?: boolean;
    }
    export interface IHierarchyExplorerState {
    }
    export default class HierarchyExplorer extends SmartComponent<IHierarchyExplorerProps, IHierarchyExplorerState> {
        constructor(props: IHierarchyExplorerProps);
        componentWillReceiveProps(nextProps: IHierarchyExplorerProps): void;
        readonly selectedFolder: IWeaveTreeNode & IColumnReference;
        selectedItems: (IWeaveTreeNode & IColumnReference)[];
        componentDidMount(): void;
        private folderTree;
        private columnTree;
        render(): JSX.Element;
    }
}
declare module "weave/ui/ButtonGroupBar" {
    import * as React from "react";
    import * as weavejs from "weavejs";
    import SmartComponent = weavejs.ui.SmartComponent;
    export interface IButtonGroupProps extends React.HTMLProps<ButtonGroupBar> {
        items: string[];
        activeButton?: number | string;
        buttonStyle?: React.CSSProperties;
        activeButtonStyle?: React.CSSProperties;
        clickHandler?: Function;
    }
    export interface IButtonGroupState {
        activeButton: number | string;
    }
    export default class ButtonGroupBar extends SmartComponent<IButtonGroupProps, IButtonGroupState> {
        constructor(props: IButtonGroupProps);
        componentWillReceiveProps(nextProps: IButtonGroupProps): void;
        private clickHandler;
        render(): JSX.Element;
    }
}
declare module "weave/ui/AttributeSelector" {
    import * as React from "react";
    import * as weavejs from "weavejs";
    import IWeaveTreeNode = weavejs.api.data.IWeaveTreeNode;
    import ILinkableHashMap = weavejs.api.core.ILinkableHashMap;
    import IColumnReference = weavejs.api.data.IColumnReference;
    import IColumnWrapper = weavejs.api.data.IColumnWrapper;
    import SmartComponent = weavejs.ui.SmartComponent;
    import ControlPanel from "weave/editor/ControlPanel";
    export interface IAttributeSelectorProps {
        attributeName?: string;
        attributes: Map<string, (IColumnWrapper | ILinkableHashMap)>;
    }
    export interface IAttributeSelectorState {
        selectedAttributeName?: string;
    }
    export default class AttributeSelector extends SmartComponent<IAttributeSelectorProps, IAttributeSelectorState> {
        private rootNode;
        constructor(props: IAttributeSelectorProps);
        private readonly usingHashMap;
        private readonly selectedAttribute;
        private readonly selectedColumnRefs;
        componentDidMount(): void;
        componentWillReceiveProps(nextProps: IAttributeSelectorProps): void;
        componentWillUpdate(nextProps: IAttributeSelectorProps, nextState: IAttributeSelectorState): void;
        onButtonBarClick: (event: React.MouseEvent, name?: string, index?: number) => void;
        private addColumns(refs);
        onAddSelected: () => void;
        onSelectAll: () => void;
        onDoubleClick: (item: IWeaveTreeNode) => void;
        onSelectColumn: (selectedItems: IWeaveTreeNode[]) => void;
        getSelectedTreeNodes(): (IWeaveTreeNode & IColumnReference)[];
        static openInstance(context: React.ReactInstance, attributeName: string, attributes: Map<string, IColumnWrapper | ILinkableHashMap>): ControlPanel;
        private selectableAttributeComponentKey;
        private hierarchyExplorer;
        render(): JSX.Element;
    }
}
declare module "weave/ui/ColorPicker" {
    import * as React from "react";
    export interface ColorPickerProps extends React.Props<ColorPicker> {
        hexColor?: string;
        onChange?: (hexColor: string) => void;
        onClose?: (hexColor: string) => void;
        onClick?: (hexColor: string) => void;
        buttonMode?: boolean;
        buttonLabel?: string | React.ReactChild;
        direction?: string;
        noDefaultSize?: boolean;
        style?: React.CSSProperties;
        className?: string;
    }
    export interface ColorPickerState {
        hexColor?: string;
        buttonLabel?: string | React.ReactChild;
    }
    export default class ColorPicker extends React.Component<ColorPickerProps, ColorPickerState> {
        popup: React.ReactInstance;
        element: HTMLElement;
        static BOTTOM_LEFT: string;
        static BOTTOM_RIGHT: string;
        static TOP_LEFT: string;
        static TOP_RIGHT: string;
        constructor(props: ColorPickerProps);
        componentWillReceiveProps(nextProps: ColorPickerProps): void;
        handleClick: (event: React.MouseEvent) => void;
        handleClose: () => void;
        handleChange: (color: any) => void;
        componentWillUnmount(): void;
        render(): JSX.Element;
    }
}
declare module "weave/ui/SelectableAttributeComponent" {
    import * as React from "react";
    import { IColumnSelectorProps } from "weave/ui/ColumnSelector";
    import ControlPanel from "weave/editor/ControlPanel";
    export interface ISelectableAttributeComponentProps extends IColumnSelectorProps {
    }
    export interface ISelectableAttributeComponentState {
    }
    export default class SelectableAttributeComponent extends React.Component<ISelectableAttributeComponentProps, ISelectableAttributeComponentState> {
        constructor(props: ISelectableAttributeComponentProps);
        renderAttributeSelectorForEditor: (attributeName: string) => React.ReactChild;
        launchAttributeSelector: (attributeName: string) => ControlPanel;
        render(): JSX.Element;
    }
}
declare module "weave/api/ui/IVisTool" {
    import * as React from "react";
    import * as weavejs from "weavejs";
    import ILinkableHashMap = weavejs.api.core.ILinkableHashMap;
    import IColumnWrapper = weavejs.api.data.IColumnWrapper;
    import ISelectableAttributes = weavejs.api.data.ISelectableAttributes;
    export interface IVisToolProps {
    }
    export interface IVisToolState {
    }
    export interface IVisTool extends ISelectableAttributes {
        title: string;
        renderEditor: (pushCrumb: (title: string, renderFn: () => JSX.Element, stateObject: any) => void) => JSX.Element;
    }
    export class IVisTool {
        static renderSelectableAttributes(selectableAttributes: Map<string, (IColumnWrapper | ILinkableHashMap)>, pushCrumb: (title: string, renderFn: () => JSX.Element, stateObject: any) => void): React.ReactChild[][];
    }
    export default IVisTool;
}
declare module "weave/api/ui/IAltText" {
    import * as weavejs from "weavejs";
    import LinkableString = weavejs.core.LinkableString;
    import LinkableBoolean = weavejs.core.LinkableBoolean;
    export class IAltTextConfig {
        text: LinkableString;
        showAsCaption: LinkableBoolean;
    }
    export default class IAltText {
        altText: IAltTextConfig;
        getAutomaticDescription: () => string;
    }
}
declare module "weave/tool/AbstractVisTool" {
    import * as React from "react";
    import * as weavejs from "weavejs";
    import MenuItemProps = weavejs.ui.menu.MenuItemProps;
    import IGetMenuItems = weavejs.ui.menu.IGetMenuItems;
    import IQualifiedKey = weavejs.api.data.IQualifiedKey;
    import IAttributeColumn = weavejs.api.data.IAttributeColumn;
    import KeySet = weavejs.data.key.KeySet;
    import LinkableNumber = weavejs.core.LinkableNumber;
    import LinkableString = weavejs.core.LinkableString;
    import FilteredKeySet = weavejs.data.key.FilteredKeySet;
    import DynamicKeyFilter = weavejs.data.key.DynamicKeyFilter;
    import ILinkableObjectWithNewProperties = weavejs.api.core.ILinkableObjectWithNewProperties;
    import ILinkableHashMap = weavejs.api.core.ILinkableHashMap;
    import IColumnWrapper = weavejs.api.data.IColumnWrapper;
    import IColumnReference = weavejs.api.data.IColumnReference;
    import IInitSelectableAttributes = weavejs.api.ui.IInitSelectableAttributes;
    import IVisTool, { IVisToolProps, IVisToolState } from "weave/api/ui/IVisTool";
    import IAltText from "weave/api/ui/IAltText";
    import { IAltTextConfig } from "weave/api/ui/IAltText";
    export type AbstractVisToolImpl = typeof AbstractVisTool;
    export class Margin {
        top: LinkableNumber;
        bottom: LinkableNumber;
        left: LinkableNumber;
        right: LinkableNumber;
    }
    export class OverrideBounds {
        xMin: LinkableNumber;
        yMin: LinkableNumber;
        xMax: LinkableNumber;
        yMax: LinkableNumber;
    }
    export interface VisToolGroup {
        filteredKeySet: FilteredKeySet;
        selectionFilter: DynamicKeyFilter;
        probeFilter: DynamicKeyFilter;
    }
    export default class AbstractVisTool<P extends IVisToolProps, S extends IVisToolState> extends React.Component<P, S> implements IVisTool, ILinkableObjectWithNewProperties, IGetMenuItems, IInitSelectableAttributes, IAltText {
        constructor(props: P);
        componentDidMount(): void;
        panelTitle: LinkableString;
        altText: IAltTextConfig;
        xAxisName: LinkableString;
        yAxisName: LinkableString;
        margin: Margin;
        overrideBounds: OverrideBounds;
        filteredKeySet: FilteredKeySet;
        selectionFilter: DynamicKeyFilter;
        probeFilter: DynamicKeyFilter;
        protected readonly selectionKeySet: KeySet;
        protected isSelected(key: IQualifiedKey): boolean;
        protected readonly probeKeySet: KeySet;
        protected isProbed(key: IQualifiedKey): boolean;
        readonly title: string;
        getAutomaticDescription(): string;
        readonly defaultPanelTitle: string;
        readonly defaultXAxisLabel: string;
        readonly defaultYAxisLabel: string;
        readonly selectableAttributes: Map<string, (IColumnWrapper | ILinkableHashMap)>;
        initSelectableAttributes(input: (IAttributeColumn | IColumnReference)[]): void;
        static initSelectableAttributes(selectableAttributes: Map<string, (IColumnWrapper | ILinkableHashMap)>, input: (IAttributeColumn | IColumnReference)[]): void;
        private static createFromSetToSubset(set, filter);
        private static removeFromSetToSubset(set, filter);
        private static clearSubset(filter);
        private static localProbeKeySet;
        static getMenuItems(target: VisToolGroup): MenuItemProps[];
        getMenuItems(): MenuItemProps[];
        getSelectableAttributesEditor(pushCrumb?: (title: string, renderFn: () => JSX.Element, stateObject: any) => void): React.ReactChild[][];
        renderNumberEditor(linkableNumber: LinkableNumber, flex: number): JSX.Element;
        getMarginEditor(): React.ReactChild[][];
        getTitlesEditor(): React.ReactChild[][];
        getAltTextEditor(): React.ReactChild[][];
        renderEditor: (pushCrumb?: (title: string, renderFn: () => JSX.Element, stateObject: any) => void) => JSX.Element;
        readonly deprecatedStateMapping: Object;
        static handlePointClick(toolGroup: VisToolGroup, event: MouseEvent): void;
    }
}
declare module "weave/tool/c3tool/C3Chart" {
    import * as weavejs from "weavejs";
    import * as c3 from "c3";
    import SmartComponent = weavejs.ui.SmartComponent;
    export interface C3ChartProps {
        config: c3.ChartConfiguration;
    }
    export default class C3Chart extends SmartComponent<C3ChartProps, {}> {
        constructor(props: C3ChartProps);
        private key;
        chart: c3.ChartAPI;
        render(): JSX.Element;
        componentDidMount(): void;
        componentDidUpdate(): void;
        componentWillReceiveProps(props: C3ChartProps): void;
        componentWillUnmount(): void;
        updateChart(): void;
        destroyChart(): void;
    }
}
declare module "weave/util/PrintUtils" {
    export default class PrintUtils {
        static onBeforeUnLoad: () => void;
        static onLoad: () => void;
        static printTool(tool: Element): void;
        static printCanvasTool(tool: Element): void;
    }
}
declare module "weave/tool/c3tool/AbstractC3Tool" {
    import * as weavejs from "weavejs";
    import * as c3 from "c3";
    import ToolTip = weavejs.ui.ToolTip;
    import MenuItemProps = weavejs.ui.menu.MenuItemProps;
    import AbstractVisTool from "weave/tool/AbstractVisTool";
    import C3Chart from "weave/tool/c3tool/C3Chart";
    import { IVisToolProps, IVisToolState } from "weave/api/ui/IVisTool";
    export interface IAbstractC3ToolProps extends IVisToolProps {
        font?: string;
        fontSize?: number;
    }
    export default class AbstractC3Tool extends AbstractVisTool<IAbstractC3ToolProps, IVisToolState> {
        constructor(props: IVisToolProps);
        componentDidMount(): void;
        componentWillUnmount(): void;
        componentDidUpdate(): void;
        getMenuItems(): MenuItemProps[];
        validateSize(): void;
        render(): JSX.Element;
        protected toolTip: ToolTip;
        protected element: HTMLElement;
        protected chartComponent: C3Chart;
        protected chart: c3.ChartAPI;
        protected c3Config: c3.ChartConfiguration;
        private xAxisClass;
        private yAxisClass;
        private y2AxisClass;
        private busy;
        private debouncedHandleC3Selection;
        private debouncedHandleChange;
        protected mergeConfig(c3Config: c3.ChartConfiguration): void;
        private handleChange();
        protected handleC3Render(): void;
        protected handleC3Selection(): void;
        protected handleC3MouseOver(d: any): void;
        protected handleC3MouseOut(d: any): void;
        /**
         * @param forced true if chart generation should be forced
         * @return true if the chart should be (re)generated
         */
        protected validate(forced?: boolean): boolean;
        readonly internalWidth: number;
        readonly internalHeight: number;
        protected updateConfigMargin(): void;
        protected updateConfigAxisX(): void;
        protected updateConfigAxisY(): void;
        protected handlePointClick(event: MouseEvent): void;
        private cullAxis(axisSize, axisClass);
        protected cullAxes(): void;
        customStyle(array: Array<number>, type: string, filter: string, style: any): void;
        customSelectorStyle(array: Array<number>, selector: any, style: any): void;
        private _getCullingMetrics(size, axisClass);
        getInterval(classSelector: string, requiredValues: number): number;
        getFontString(): string;
        /**
         *
         * @param label
         * @param angle
         * @returns {number}
         */
        getRotatedLabelHeight(label: string, angle: number): number;
        /**
         * Truncate a string from the middle by 'adj' characters and replace with 'replacement'
         * @param str String to truncate.
         * @param adj Number of characters to remove from the middle.
         * @param replacement String to put in place of removed content.
         * @returns {string} The string that results from removing 'adj' characters and replacing with 'replacement'
         */
        centerEllipseString(str: string, adj: number, replacement: string): string;
        formatXAxisLabel(label: string, angle: number): string;
        formatYAxisLabel(label: string, angle: number): string;
    }
}
declare module "weave/util/ChartUtils" {
    import * as weavejs from "weavejs";
    import ComboBoxOption = weavejs.ui.ComboBoxOption;
    export default class ChartUtils {
        static getAxisLabelAngleChoices(): ComboBoxOption[];
    }
}
declare module "weave/tool/c3tool/C3BarChart" {
    import * as React from "react";
    import * as weavejs from "weavejs";
    import * as c3 from "c3";
    import DynamicColumn = weavejs.data.column.DynamicColumn;
    import ILinkableHashMap = weavejs.api.core.ILinkableHashMap;
    import IAttributeColumn = weavejs.api.data.IAttributeColumn;
    import LinkableHashMap = weavejs.core.LinkableHashMap;
    import AlwaysDefinedColumn = weavejs.data.column.AlwaysDefinedColumn;
    import ColorRamp = weavejs.util.ColorRamp;
    import LinkableString = weavejs.core.LinkableString;
    import LinkableBoolean = weavejs.core.LinkableBoolean;
    import LinkableNumber = weavejs.core.LinkableNumber;
    import IColumnWrapper = weavejs.api.data.IColumnWrapper;
    import AbstractC3Tool from "weave/tool/c3tool/AbstractC3Tool";
    import { IVisToolProps } from "weave/api/ui/IVisTool";
    export default class C3BarChart extends AbstractC3Tool {
        heightColumns: LinkableHashMap;
        labelColumn: DynamicColumn;
        sortColumn: DynamicColumn;
        colorColumn: AlwaysDefinedColumn;
        chartColors: ColorRamp;
        groupingMode: LinkableString;
        legendPosition: LinkableString;
        horizontalMode: LinkableBoolean;
        showValueLabels: LinkableBoolean;
        showXAxisLabel: LinkableBoolean;
        xAxisLabelAngle: LinkableNumber;
        barWidthRatio: LinkableNumber;
        private verifyGroupingMode(mode);
        private verifyLegendPosition(position);
        private verifyBarRatio(ratio);
        readonly yLabelColumn: IAttributeColumn;
        private RECORD_FORMAT;
        private RECORD_DATATYPE;
        private yLabelColumnDataType;
        private heightColumnNames;
        private heightColumnsLabels;
        protected c3ConfigYAxis: c3.YAxisConfiguration;
        private records;
        constructor(props: IVisToolProps);
        private formatGetStringFromNumber;
        protected handleC3Selection(): void;
        protected handleC3MouseOver(d: any): void;
        private dataChanged();
        updateStyle(): void;
        readonly defaultXAxisLabel: string;
        readonly defaultYAxisLabel: string;
        getAutomaticDescription(): string;
        protected validate(forced?: boolean): boolean;
        readonly selectableAttributes: Map<string, ILinkableHashMap | IColumnWrapper>;
        readonly defaultPanelTitle: string;
        getMarginEditor(): React.ReactChild[][];
        renderEditor: (pushCrumb?: (title: string, renderFn: () => JSX.Element, stateObject: any) => void) => JSX.Element;
        readonly deprecatedStateMapping: Object;
    }
}
declare module "weave/ui/ColorRampComponent" {
    import * as React from "react";
    export interface ColorRampComponentProps extends React.HTMLProps<HTMLDivElement> {
        ramp: string[];
        direction?: "left" | "right" | "top" | "bottom";
    }
    export interface ColorRampComponentState {
    }
    export default class ColorRampComponent extends React.Component<ColorRampComponentProps, ColorRampComponentState> {
        constructor(props: ColorRampComponentProps);
        render(): JSX.Element;
    }
}
declare module "weave/ui/BinNamesList" {
    import * as React from "react";
    import * as weavejs from "weavejs";
    import AbstractBinningDefinition = weavejs.data.bin.AbstractBinningDefinition;
    export interface BinNamesListProps {
        binningDefinition: AbstractBinningDefinition;
        showHeaderRow?: boolean;
    }
    export default class BinNamesList extends React.Component<BinNamesListProps, {}> {
        constructor(props: BinNamesListProps);
        componentWillReceiveProps(nextProps: BinNamesListProps): void;
        componentWillUnmount(): void;
        static defaultProps: BinNamesListProps;
        render(): JSX.Element;
    }
}
declare module "weave/editor/BinningDefinitionEditor" {
    import * as React from "react";
    import * as weavejs from "weavejs";
    import SmartComponent = weavejs.ui.SmartComponent;
    import ILinkableHashMap = weavejs.api.core.ILinkableHashMap;
    import BinnedColumn = weavejs.data.column.BinnedColumn;
    import AbstractBinningDefinition = weavejs.data.bin.AbstractBinningDefinition;
    import IColumnWrapper = weavejs.api.data.IColumnWrapper;
    export interface BinningDefinitionEditorProps {
        showNoneOption?: boolean;
        binnedColumn: BinnedColumn;
        compact?: boolean;
        onButtonClick?: React.MouseEventHandler;
        pushCrumb?: (title: string, renderFn: () => JSX.Element, stateObject: any) => void;
        insertTableRows?: React.ReactChild[][];
    }
    export interface BinningDefinitionEditorState {
    }
    export default class BinningDefinitionEditor extends React.Component<BinningDefinitionEditorProps, BinningDefinitionEditorState> {
        static binClassToBinLabel: Map<typeof AbstractBinningDefinition, string>;
        constructor(props: BinningDefinitionEditorProps);
        onBinButtonClick: (event: React.MouseEvent) => void;
        renderBinningDefinitionSelectorForEditor: () => JSX.Element;
        renderCompactView(): JSX.Element;
        renderFullView(): JSX.Element;
        render(): JSX.Element;
    }
    export interface BinningDefinitionSelectorProps {
        showNoneOption?: boolean;
        attributeName: string;
        attributes: Map<string, IColumnWrapper | ILinkableHashMap>;
        pushCrumb?: (title: string, renderFn: () => JSX.Element, stateObject: any) => void;
        insertTableRows?: React.ReactChild[][];
    }
    export interface BinningDefinitionSelectorState {
    }
    export class BinningDefinitionSelector extends SmartComponent<BinningDefinitionSelectorProps, BinningDefinitionSelectorState> {
        private _simple;
        private _customSplit;
        private _quantile;
        private _equalInterval;
        private _stdDev;
        private _category;
        private _jenks;
        private _allBinDefs;
        private binLabelToBin;
        static defaultProps: BinningDefinitionSelectorProps;
        constructor(props: BinningDefinitionSelectorProps);
        readonly column: BinnedColumn;
        getColumn(props: BinningDefinitionSelectorProps): BinnedColumn;
        componentWillReceiveProps(nextProps: BinningDefinitionSelectorProps): void;
        private handleBinnedColumnChange(binnedColumn);
        private compareTargetBinningType(localDef);
        private updateTargetBinningDef();
        private linkOverride(property);
        setBinningDefinition(localDef: AbstractBinningDefinition): void;
        private linkBinningDefinition(value);
        private hasOverrideMinAndMax();
        private getBinDefRenderProps(binDef);
        render(): JSX.Element;
    }
}
declare module "weave/ui/ColorRampList" {
    import * as React from "react";
    import * as weavejs from "weavejs";
    import VBox = weavejs.ui.flexbox.VBox;
    export interface ColorRampListProps extends React.Props<ColorRampList> {
        allColorRamps: {
            name: string;
            tags: string;
            colors: number[];
        }[];
        selectedColors?: number[];
        onChange?: (selectedRamp: number[]) => void;
    }
    export interface ColorRampListState {
        selectedColors?: number[];
    }
    export default class ColorRampList extends React.Component<ColorRampListProps, ColorRampListState> {
        columnTitles: {
            [columnId: string]: string | JSX.Element;
        };
        tableContainer: VBox;
        tableContainerElement: HTMLElement;
        constructor(props: ColorRampListProps);
        static defaultProps: ColorRampListProps;
        private getRampNameFromRamp(selectedColors);
        componentWillReceiveProps(nextProps: ColorRampListProps): void;
        handleTableSelection: (id: string[]) => void;
        render(): JSX.Element;
    }
}
declare module "weave/editor/ColorRampEditor" {
    import * as React from "react";
    import * as weavejs from "weavejs";
    import ColorRamp = weavejs.util.ColorRamp;
    export interface ColorRampEditorProps extends React.Props<ColorRampEditor> {
        colorRamp: ColorRamp;
        compact?: boolean;
        onButtonClick?: React.MouseEventHandler;
        pushCrumb?: (title: string, renderFn: () => JSX.Element, stateObject: any) => void;
    }
    export interface ColorRampEditorState {
    }
    export default class ColorRampEditor extends React.Component<ColorRampEditorProps, ColorRampEditorState> {
        private colorRampWatcher;
        colorRamp: ColorRamp;
        constructor(props: ColorRampEditorProps);
        componentWillReceiveProps(nextProps: ColorRampEditorProps): void;
        private onButtonClick;
        renderColorRampSelectorForEditor: () => JSX.Element;
        renderCompactView(): JSX.Element;
        renderFullView(): JSX.Element;
        render(): JSX.Element;
    }
}
declare module "weave/tool/ColorLegend" {
    import * as React from "react";
    import * as weavejs from "weavejs";
    import CSSProperties = React.CSSProperties;
    import MenuItemProps = weavejs.ui.menu.MenuItemProps;
    import IAttributeColumn = weavejs.api.data.IAttributeColumn;
    import DynamicColumn = weavejs.data.column.DynamicColumn;
    import FilteredKeySet = weavejs.data.key.FilteredKeySet;
    import DynamicKeyFilter = weavejs.data.key.DynamicKeyFilter;
    import LinkableNumber = weavejs.core.LinkableNumber;
    import ILinkableHashMap = weavejs.api.core.ILinkableHashMap;
    import LinkableString = weavejs.core.LinkableString;
    import LinkableBoolean = weavejs.core.LinkableBoolean;
    import IColumnWrapper = weavejs.api.data.IColumnWrapper;
    import IColumnReference = weavejs.api.data.IColumnReference;
    import IInitSelectableAttributes = weavejs.api.ui.IInitSelectableAttributes;
    import ILinkableObjectWithNewProperties = weavejs.api.core.ILinkableObjectWithNewProperties;
    import IVisTool, { IVisToolProps, IVisToolState } from "weave/api/ui/IVisTool";
    export default class ColorLegend extends React.Component<IVisToolProps, IVisToolState> implements ILinkableObjectWithNewProperties, IVisTool, IInitSelectableAttributes {
        panelTitle: LinkableString;
        filteredKeySet: FilteredKeySet;
        selectionFilter: DynamicKeyFilter;
        probeFilter: DynamicKeyFilter;
        dynamicColorColumn: DynamicColumn;
        maxColumns: LinkableNumber;
        shapeSize: LinkableNumber;
        shapeType: LinkableString;
        showLegendName: LinkableBoolean;
        reverseOrder: LinkableBoolean;
        altText: LinkableString;
        element: HTMLElement;
        private readonly colorColumn;
        private readonly binnedColumn;
        private readonly binningDefinition;
        private readonly selectionKeySet;
        private readonly probeKeySet;
        private toolTip;
        constructor(props: IVisToolProps);
        readonly title: string;
        readonly defaultPanelTitle: string;
        readonly numberOfBins: number;
        getSelectedBins(): number[];
        getProbedBins(): number[];
        handleClick(bin: number, event: React.MouseEvent): void;
        handleProbe(bin: number, mouseOver: boolean, event: MouseEvent): void;
        componentDidMount(): void;
        componentWillUnmount(): void;
        getMenuItems(): MenuItemProps[];
        private cellBorderWidth;
        private cellPadding;
        getInteractionStyle(bin: number): CSSProperties;
        getCell(cellIndex: number, shapeSize: number, textStyle: React.CSSProperties): JSX.Element;
        render(): JSX.Element;
        readonly selectableAttributes: Map<string, ILinkableHashMap | IColumnWrapper>;
        initSelectableAttributes(input: (IAttributeColumn | IColumnReference)[]): void;
        renderEditor: (pushCrumb?: (title: string, renderFn: () => JSX.Element, stateObject: any) => void) => JSX.Element;
        readonly deprecatedStateMapping: Object;
    }
}
declare module "weave/tool/c3tool/C3Gauge" {
    import * as React from "react";
    import * as weavejs from "weavejs";
    import ColorRamp = weavejs.util.ColorRamp;
    import FilteredKeySet = weavejs.data.key.FilteredKeySet;
    import DynamicColumn = weavejs.data.column.DynamicColumn;
    import DynamicBinningDefinition = weavejs.data.bin.DynamicBinningDefinition;
    import IColumnWrapper = weavejs.api.data.IColumnWrapper;
    import AbstractC3Tool from "weave/tool/c3tool/AbstractC3Tool";
    import { IVisToolProps } from "weave/api/ui/IVisTool";
    export default class C3Gauge extends AbstractC3Tool {
        meterColumn: DynamicColumn;
        binningDefinition: DynamicBinningDefinition;
        colorRamp: ColorRamp;
        private colStats;
        private RECORD_FORMAT;
        private RECORD_DATATYPE;
        private keyToIndex;
        private records;
        constructor(props: IVisToolProps);
        protected updateConfigMargin(): void;
        protected validate(forced?: boolean): boolean;
        readonly selectableAttributes: Map<string, weavejs.api.core.ILinkableHashMap | IColumnWrapper>;
        getMarginEditor(): React.ReactChild[][];
        getTitlesEditor(): React.ReactChild[][];
        readonly defaultPanelTitle: string;
        readonly deprecatedStateMapping: (Object | {
            "children": {
                "visualization": {
                    "plotManager": {
                        "plotters": {
                            "plot": {
                                "filteredKeySet": FilteredKeySet;
                                "meterColumn": DynamicColumn;
                                "colorRamp": ColorRamp;
                                "binningDefinition": DynamicBinningDefinition;
                            };
                        };
                    };
                };
            };
        })[];
    }
}
declare module "weave/plot/SolidLineStyle" {
    import * as weavejs from "weavejs";
    import { Graphics } from "pixi.js";
    import ILinkableObject = weavejs.api.core.ILinkableObject;
    import IQualifiedKey = weavejs.api.data.IQualifiedKey;
    import LinkableBoolean = weavejs.core.LinkableBoolean;
    import AlwaysDefinedColumn = weavejs.data.column.AlwaysDefinedColumn;
    import NormalizedColumn = weavejs.data.column.NormalizedColumn;
    export default class SolidLineStyle implements ILinkableObject {
        constructor();
        private _callbackCollection;
        private _triggerCounter;
        private map_column_dataType;
        private map_column_defaultValue;
        private createColumn(dataType, defaultValue);
        enable: LinkableBoolean;
        color: AlwaysDefinedColumn;
        weight: AlwaysDefinedColumn;
        alpha: AlwaysDefinedColumn;
        caps: AlwaysDefinedColumn;
        joints: AlwaysDefinedColumn;
        miterLimit: AlwaysDefinedColumn;
        readonly normalizedWeightColumn: NormalizedColumn;
        /**
         * For use with ColumnUtils.getRecords()
         */
        readonly recordFormat: {
            'color': AlwaysDefinedColumn;
            'weight': AlwaysDefinedColumn;
            'alpha': AlwaysDefinedColumn;
            'caps': AlwaysDefinedColumn;
            'joints': AlwaysDefinedColumn;
            'miterLimit': AlwaysDefinedColumn;
        };
        /**
         * For use with ColumnUtils.getRecords()
         */
        readonly recordType: {
            'color': NumberConstructor;
            'weight': NumberConstructor;
            'alpha': NumberConstructor;
            'caps': StringConstructor;
            'joints': StringConstructor;
            'miterLimit': NumberConstructor;
        };
        /**
         * IQualifiedKey -> getLineStyleParams() result
         */
        private map_key_style;
        beginLineStyle(key: IQualifiedKey, graphics: Graphics): void;
        getStyle(key: IQualifiedKey): {
            color: number;
            weight: number;
            alpha: number;
            caps: string;
            joints: string;
            miterLimit: number;
        };
    }
}
declare module "weave/plot/SolidFillStyle" {
    import * as weavejs from "weavejs";
    import { Graphics } from "pixi.js";
    import ILinkableObject = weavejs.api.core.ILinkableObject;
    import IQualifiedKey = weavejs.api.data.IQualifiedKey;
    import LinkableBoolean = weavejs.core.LinkableBoolean;
    import AlwaysDefinedColumn = weavejs.data.column.AlwaysDefinedColumn;
    export default class SolidFillStyle implements ILinkableObject {
        /**
         * Used to enable or disable fill patterns.
         */
        enable: LinkableBoolean;
        /**
         * These properties are used with a basic Graphics.setFill() function call.
         */
        color: AlwaysDefinedColumn;
        alpha: AlwaysDefinedColumn;
        /**
         * For use with ColumnUtils.getRecords()
         */
        readonly recordFormat: {
            'color': AlwaysDefinedColumn;
            'alpha': AlwaysDefinedColumn;
        };
        /**
         * For use with ColumnUtils.getRecords()
         */
        readonly recordType: {
            'color': NumberConstructor;
            'alpha': NumberConstructor;
        };
        beginFillStyle(key: IQualifiedKey, graphics: Graphics): void;
        getStyle(key: IQualifiedKey): {
            color: number;
            alpha: number;
        };
    }
}
declare module "weave/tool/c3tool/C3Histogram" {
    import * as weavejs from "weavejs";
    import * as c3 from "c3";
    import IAttributeColumn = weavejs.api.data.IAttributeColumn;
    import BinnedColumn = weavejs.data.column.BinnedColumn;
    import ColorColumn = weavejs.data.column.ColorColumn;
    import FilteredKeySet = weavejs.data.key.FilteredKeySet;
    import LinkableString = weavejs.core.LinkableString;
    import LinkableBoolean = weavejs.core.LinkableBoolean;
    import DynamicColumn = weavejs.data.column.DynamicColumn;
    import LinkableNumber = weavejs.core.LinkableNumber;
    import IColumnWrapper = weavejs.api.data.IColumnWrapper;
    import ILinkableHashMap = weavejs.api.core.ILinkableHashMap;
    import IColumnReference = weavejs.api.data.IColumnReference;
    import AbstractC3Tool from "weave/tool/c3tool/AbstractC3Tool";
    import SolidLineStyle from "weave/plot/SolidLineStyle";
    import SolidFillStyle from "weave/plot/SolidFillStyle";
    import { IVisToolProps } from "weave/api/ui/IVisTool";
    export default class C3Histogram extends AbstractC3Tool {
        binnedColumn: BinnedColumn;
        columnToAggregate: DynamicColumn;
        aggregationMethod: LinkableString;
        fill: SolidFillStyle;
        line: SolidLineStyle;
        barWidthRatio: LinkableNumber;
        horizontalMode: LinkableBoolean;
        showValueLabels: LinkableBoolean;
        xAxisLabelAngle: LinkableNumber;
        private verifyBarRatio(ratio);
        initSelectableAttributes(input: (IAttributeColumn | IColumnReference)[]): void;
        readonly colorColumn: ColorColumn;
        private _callbackRecursion;
        private setColorColumn();
        private setBinnedColumn();
        private readonly RECORD_FORMAT;
        private RECORD_DATATYPE;
        private histData;
        private keys;
        private records;
        protected c3ConfigYAxis: c3.YAxisConfiguration;
        readonly internalColorColumn: ColorColumn;
        constructor(props: IVisToolProps);
        private getLabelString(num);
        readonly defaultXAxisLabel: string;
        readonly defaultYAxisLabel: string;
        private getYAxisLabel();
        protected handleC3Selection(): void;
        updateStyle(): void;
        private dataChanged();
        private getAggregateValue(records, columnToAggregateName, aggregationMethod);
        protected validate(forced?: boolean): boolean;
        readonly selectableAttributes: Map<string, ILinkableHashMap | IColumnWrapper>;
        readonly defaultPanelTitle: string;
        updateColor(color: string): void;
        renderEditor: (pushCrumb: (title: string, renderFn: () => JSX.Element, stateObject: any) => void) => JSX.Element;
        readonly deprecatedStateMapping: (Object | {
            "children": {
                "visualization": {
                    "plotManager": {
                        "plotters": {
                            "plot": {
                                "filteredKeySet": FilteredKeySet;
                                "binnedColumn": BinnedColumn;
                                "columnToAggregate": DynamicColumn;
                                "aggregationMethod": LinkableString;
                                "fillStyle": SolidFillStyle;
                                "lineStyle": SolidLineStyle;
                                "drawPartialBins": boolean;
                                "horizontalMode": boolean;
                                "showValueLabels": boolean;
                                "valueLabelColor": number;
                                "valueLabelHorizontalAlign": string;
                                "valueLabelMaxWidth": number;
                                "valueLabelVerticalAlign": string;
                            };
                        };
                    };
                };
            };
        })[];
    }
}
declare module "weave/tool/c3tool/C3ColorHistogram" {
    import C3Histogram from "weave/tool/c3tool/C3Histogram";
    import { IVisToolProps } from "weave/api/ui/IVisTool";
    export default class C3ColorHistogram extends C3Histogram {
        constructor(props: IVisToolProps);
        readonly defaultPanelTitle: string;
    }
}
declare module "weave/tool/c3tool/C3LineChart" {
    import * as weavejs from "weavejs";
    import * as c3 from "c3";
    import ILinkableHashMap = weavejs.api.core.ILinkableHashMap;
    import FilteredKeySet = weavejs.data.key.FilteredKeySet;
    import LinkableHashMap = weavejs.core.LinkableHashMap;
    import LinkableString = weavejs.core.LinkableString;
    import IColumnWrapper = weavejs.api.data.IColumnWrapper;
    import LinkableNumber = weavejs.core.LinkableNumber;
    import AbstractC3Tool from "weave/tool/c3tool/AbstractC3Tool";
    import SolidLineStyle from "weave/plot/SolidLineStyle";
    import { IVisToolProps } from "weave/api/ui/IVisTool";
    export default class C3LineChart extends AbstractC3Tool {
        columns: LinkableHashMap;
        line: SolidLineStyle;
        curveType: LinkableString;
        xAxisLabelAngle: LinkableNumber;
        private RECORD_FORMAT;
        private RECORD_DATATYPE;
        private keyToIndex;
        private yAxisValueToLabel;
        private records;
        private columnLabels;
        private chartType;
        protected c3ConfigYAxis: c3.YAxisConfiguration;
        constructor(props: IVisToolProps);
        private getQKey(datum);
        protected handleC3MouseOver(d: any): void;
        protected handleC3Selection(): void;
        protected validate(forced?: boolean): boolean;
        readonly selectableAttributes: Map<string, ILinkableHashMap | IColumnWrapper>;
        readonly defaultPanelTitle: string;
        renderEditor: (pushCrumb: (title: string, renderFn: () => JSX.Element, stateObject: any) => void) => JSX.Element;
        readonly deprecatedStateMapping: (Object | {
            "children": {
                "visualization": {
                    "plotManager": {
                        "plotters": {
                            "plot": {
                                "filteredKeySet": FilteredKeySet;
                                "columns": LinkableHashMap;
                                "curveType": LinkableString;
                                "lineStyle": SolidLineStyle;
                                "enableGroupBy": boolean;
                                "groupKeyType": string;
                                "normalize": boolean;
                                "shapeBorderAlpha": number;
                                "shapeBorderColor": number;
                                "shapeBorderThickness": number;
                                "shapeSize": number;
                                "shapeToDraw": string;
                                "zoomToSubset": boolean;
                            };
                        };
                    };
                };
            };
        })[];
    }
}
declare module "weave/tool/c3tool/C3XYLineChart" {
    import * as weavejs from "weavejs";
    import * as c3 from "c3";
    import AbstractC3Tool from "weave/tool/c3tool/AbstractC3Tool";
    import SolidLineStyle from "weave/plot/SolidLineStyle";
    import { IVisToolProps } from "weave/api/ui/IVisTool";
    import ILinkableHashMap = weavejs.api.core.ILinkableHashMap;
    import FilteredKeySet = weavejs.data.key.FilteredKeySet;
    import LinkableHashMap = weavejs.core.LinkableHashMap;
    import LinkableString = weavejs.core.LinkableString;
    import DynamicColumn = weavejs.data.column.DynamicColumn;
    import IColumnWrapper = weavejs.api.data.IColumnWrapper;
    import LinkableNumber = weavejs.core.LinkableNumber;
    import ColorRamp = weavejs.util.ColorRamp;
    export default class C3XYLineChart extends AbstractC3Tool {
        xColumn: DynamicColumn;
        sortColumn: DynamicColumn;
        yColumns: LinkableHashMap;
        line: SolidLineStyle;
        curveType: LinkableString;
        ramp: ColorRamp;
        xAxisLabelAngle: LinkableNumber;
        dataXType: string;
        data: any[];
        private indexToKey;
        private yAxisValueToLabel;
        private columnLabels;
        private chartType;
        protected c3ConfigYAxis: c3.YAxisConfiguration;
        constructor(props: IVisToolProps);
        private getQKey(d);
        protected handleC3MouseOver(d: any): void;
        protected handleC3Selection(): void;
        protected validate(forced?: boolean): boolean;
        readonly selectableAttributes: Map<string, ILinkableHashMap | IColumnWrapper>;
        readonly defaultPanelTitle: string;
        renderEditor: (pushCrumb: (title: string, renderFn: () => JSX.Element, stateObject: any) => void) => JSX.Element;
        readonly deprecatedStateMapping: (Object | {
            "children": {
                "visualization": {
                    "plotManager": {
                        "plotters": {
                            "plot": {
                                "filteredKeySet": FilteredKeySet;
                                "columns": LinkableHashMap;
                                "curveType": LinkableString;
                                "lineStyle": SolidLineStyle;
                                "enableGroupBy": boolean;
                                "groupKeyType": string;
                                "normalize": boolean;
                                "shapeBorderAlpha": number;
                                "shapeBorderColor": number;
                                "shapeBorderThickness": number;
                                "shapeSize": number;
                                "shapeToDraw": string;
                                "zoomToSubset": boolean;
                            };
                        };
                    };
                };
            };
        })[];
    }
}
declare module "weave/tool/DataMessageTool" {
    import * as React from "react";
    import * as weavejs from "weavejs";
    import ILinkableHashMap = weavejs.api.core.ILinkableHashMap;
    import IColumnWrapper = weavejs.api.data.IColumnWrapper;
    import LinkableString = weavejs.core.LinkableString;
    import LinkableDynamicObject = weavejs.core.LinkableDynamicObject;
    import DynamicKeyFilter = weavejs.data.key.DynamicKeyFilter;
    import IVisTool from "weave/api/ui/IVisTool";
    import { IVisToolState } from "weave/api/ui/IVisTool";
    import { IVisToolProps } from "weave/api/ui/IVisTool";
    export default class DataMessageTool extends React.Component<IVisToolProps, IVisToolState> implements IVisTool {
        constructor(props: IVisToolProps);
        readonly selectableAttributes: Map<string, ILinkableHashMap | IColumnWrapper>;
        panelTitle: LinkableString;
        messageTarget: LinkableDynamicObject;
        keySetSource: DynamicKeyFilter;
        command: LinkableString;
        readonly title: string;
        readonly defaultPanelTitle: string;
        renderEditor: (pushCrumb?: (title: string, renderFn: () => JSX.Element, stateObject: any) => void) => JSX.Element;
        sendMessage: () => void;
        render(): JSX.Element;
    }
}
declare module "weave/tool/c3tool/C3PieChart" {
    import * as React from "react";
    import * as weavejs from "weavejs";
    import FilteredKeySet = weavejs.data.key.FilteredKeySet;
    import DynamicColumn = weavejs.data.column.DynamicColumn;
    import LinkableNumber = weavejs.core.LinkableNumber;
    import IColumnWrapper = weavejs.api.data.IColumnWrapper;
    import AbstractC3Tool from "weave/tool/c3tool/AbstractC3Tool";
    import SolidFillStyle from "weave/plot/SolidFillStyle";
    import SolidLineStyle from "weave/plot/SolidLineStyle";
    import { IVisToolProps } from "weave/api/ui/IVisTool";
    export default class C3PieChart extends AbstractC3Tool {
        data: DynamicColumn;
        label: DynamicColumn;
        fill: SolidFillStyle;
        line: SolidLineStyle;
        innerRadius: LinkableNumber;
        private RECORD_FORMAT;
        private RECORD_DATATYPE;
        private keyToIndex;
        private records;
        constructor(props: IVisToolProps);
        protected handleC3MouseOver(d: any): void;
        protected handleC3Selection(): void;
        private updateStyle();
        protected validate(forced?: boolean): boolean;
        readonly selectableAttributes: Map<string, weavejs.api.core.ILinkableHashMap | IColumnWrapper>;
        readonly defaultPanelTitle: string;
        renderEditor: (pushCrumb: (title: string, renderFn: () => JSX.Element, stateObject: any) => void) => JSX.Element;
        getTitlesEditor(): React.ReactChild[][];
        readonly deprecatedStateMapping: (Object | {
            "children": {
                "visualization": {
                    "plotManager": {
                        "plotters": {
                            "plot": {
                                "filteredKeySet": FilteredKeySet;
                                "data": DynamicColumn;
                                "fill": SolidFillStyle;
                                "innerRadius": LinkableNumber;
                                "label": DynamicColumn;
                                "line": SolidLineStyle;
                                "labelAngleRatio": number;
                            };
                        };
                    };
                };
            };
        })[];
    }
}
declare module "weave/tool/c3tool/C3ScatterPlot" {
    import * as weavejs from "weavejs";
    import * as c3 from "c3";
    import DynamicColumn = weavejs.data.column.DynamicColumn;
    import AlwaysDefinedColumn = weavejs.data.column.AlwaysDefinedColumn;
    import LinkableNumber = weavejs.core.LinkableNumber;
    import IColumnWrapper = weavejs.api.data.IColumnWrapper;
    import SolidFillStyle from "weave/plot/SolidFillStyle";
    import SolidLineStyle from "weave/plot/SolidLineStyle";
    import AbstractC3Tool from "weave/tool/c3tool/AbstractC3Tool";
    import { IVisToolProps } from "weave/api/ui/IVisTool";
    export default class C3ScatterPlot extends AbstractC3Tool {
        dataX: DynamicColumn;
        dataY: DynamicColumn;
        radius: AlwaysDefinedColumn;
        fill: SolidFillStyle;
        line: SolidLineStyle;
        xAxisLabelAngle: LinkableNumber;
        private readonly radiusNorm;
        private readonly radiusData;
        private RECORD_FORMAT;
        private RECORD_DATATYPE;
        private keyToIndex;
        private xAxisValueToLabel;
        private yAxisValueToLabel;
        private dataXType;
        private dataYType;
        private records;
        protected c3ConfigYAxis: c3.YAxisConfiguration;
        constructor(props: IVisToolProps);
        protected handleC3MouseOver(d: any): void;
        protected handleC3Selection(): void;
        protected validate(forced?: boolean): boolean;
        readonly selectableAttributes: Map<string, weavejs.api.core.ILinkableHashMap | IColumnWrapper>;
        readonly defaultPanelTitle: string;
        readonly defaultXAxisLabel: string;
        readonly defaultYAxisLabel: string;
        getAutomaticDescription(): string;
        renderEditor: (pushCrumb: (title: string, renderFn: () => JSX.Element, stateObject: any) => void) => JSX.Element;
        readonly deprecatedStateMapping: Object;
    }
}
declare module "weave/util/ConfigUtils" {
    import * as weavejs from "weavejs";
    import LinkableNumber = weavejs.core.LinkableNumber;
    export default class ConfigUtils {
        static renderNumberEditor(linkableNumber: LinkableNumber, flex: number): JSX.Element;
    }
}
declare module "weave/tool/Sparkline" {
    import * as React from "react";
    import * as weavejs from "weavejs";
    import ResizingDivState = weavejs.ui.ResizingDivState;
    import SmartComponent = weavejs.ui.SmartComponent;
    import LinkableString = weavejs.core.LinkableString;
    import LinkableNumber = weavejs.core.LinkableNumber;
    import LinkableHashMap = weavejs.core.LinkableHashMap;
    import IColumnWrapper = weavejs.api.data.IColumnWrapper;
    import ILinkableHashMap = weavejs.api.core.ILinkableHashMap;
    import DynamicColumn = weavejs.data.column.DynamicColumn;
    import IQualifiedKey = weavejs.api.data.IQualifiedKey;
    import IAttributeColumn = weavejs.api.data.IAttributeColumn;
    import IInitSelectableAttributes = weavejs.api.ui.IInitSelectableAttributes;
    import IColumnReference = weavejs.api.data.IColumnReference;
    import FilteredKeySet = weavejs.data.key.FilteredKeySet;
    import DynamicKeyFilter = weavejs.data.key.DynamicKeyFilter;
    import LinkableBoolean = weavejs.core.LinkableBoolean;
    import SolidFillStyle from "weave/plot/SolidFillStyle";
    import SolidLineStyle from "weave/plot/SolidLineStyle";
    import IVisTool from "weave/api/ui/IVisTool";
    import { IVisToolProps } from "weave/api/ui/IVisTool";
    import { IVisToolState } from "weave/api/ui/IVisTool";
    export type Record = {
        id: IQualifiedKey;
        value: number;
        fill: {
            color: string;
        };
        line: {
            color: string;
        };
    };
    export interface ISparklineProps extends IVisToolProps {
        width?: number;
        height?: number;
    }
    export interface ISparklineState extends IVisToolState {
        data?: number[][];
        width?: number;
        height?: number;
    }
    export default class Sparkline extends SmartComponent<ISparklineProps, ISparklineState> implements IVisTool, IInitSelectableAttributes {
        columns: LinkableHashMap;
        sortColumn: DynamicColumn;
        labelColumn: DynamicColumn;
        chartType: LinkableString;
        orientationMode: LinkableString;
        referenceLineMode: LinkableString;
        showAllRecords: LinkableBoolean;
        showRowLabels: LinkableBoolean;
        showNormalBands: LinkableBoolean;
        fill: SolidFillStyle;
        line: SolidLineStyle;
        marginTop: LinkableNumber;
        marginBottom: LinkableNumber;
        marginLeft: LinkableNumber;
        marginRight: LinkableNumber;
        panelTitle: LinkableString;
        altText: LinkableString;
        selectionFilter: DynamicKeyFilter;
        probeFilter: DynamicKeyFilter;
        filteredKeySet: FilteredKeySet;
        private records;
        private toolTip;
        private verifyChartMode(mode);
        private verifyOrientationMode(mode);
        private verifyReferenceLineMode(mode);
        private readonly selectionKeySet;
        private readonly probeKeySet;
        protected isSelected(key: IQualifiedKey): boolean;
        protected isProbed(key: IQualifiedKey): boolean;
        constructor(props: ISparklineProps);
        readonly title: string;
        readonly selectableAttributes: Map<string, ILinkableHashMap | IColumnWrapper>;
        readonly defaultPanelTitle: string;
        initSelectableAttributes(input: (IAttributeColumn | IColumnReference)[]): void;
        getTitleEditor(): React.ReactChild[][];
        getMarginEditor(): React.ReactChild[][];
        getAltTextEditor(): React.ReactChild[][];
        renderEditor: (pushCrumb: (title: string, renderFn: () => JSX.Element, stateObject: any) => void) => JSX.Element;
        readonly deprecatedStateMapping: {
            "columns": LinkableHashMap;
            "sortColumn": DynamicColumn;
        };
        componentDidUpdate(): void;
        componentDidMount(): void;
        componentWillUnmount(): void;
        handleResize: (newSize: ResizingDivState) => void;
        dataChanged(): void;
        getInteractedRecords(): Record[];
        /**
         * Gets the Sparkline reference line component depending on the mode
         * @param mode - The Sparkline reference line drawing mode
         */
        getReferenceLineComponent(mode: string): JSX.Element;
        /**
         * Gets the Spark Line component depending on the mode
         * @param mode - The Sparkline drawing mode
         * @returns React.ReactChild - returns the Sparkline to be displayed
         */
        getLineComponent(mode: string, style: React.CSSProperties): React.ReactChild;
        handleClick: (record: {
            id: IQualifiedKey;
            value: number;
            fill: {
                color: string;
            };
            line: {
                color: string;
            };
        }, event: React.MouseEvent) => void;
        handleProbe: (record: {
            id: IQualifiedKey;
            value: number;
            fill: {
                color: string;
            };
            line: {
                color: string;
            };
        }, mouseOver: boolean, event: React.MouseEvent) => void;
        getSparklines(): void;
        render(): JSX.Element;
    }
}
declare module "weave/tool/TableTool" {
    import * as React from "react";
    import * as weavejs from "weavejs";
    import MenuItemProps = weavejs.ui.menu.MenuItemProps;
    import FilteredKeySet = weavejs.data.key.FilteredKeySet;
    import IAttributeColumn = weavejs.api.data.IAttributeColumn;
    import IColumnReference = weavejs.api.data.IColumnReference;
    import ILinkableHashMap = weavejs.api.core.ILinkableHashMap;
    import LinkableHashMap = weavejs.core.LinkableHashMap;
    import LinkableString = weavejs.core.LinkableString;
    import LinkableNumber = weavejs.core.LinkableNumber;
    import LinkableBoolean = weavejs.core.LinkableBoolean;
    import DynamicKeyFilter = weavejs.data.key.DynamicKeyFilter;
    import IQualifiedKey = weavejs.api.data.IQualifiedKey;
    import IColumnWrapper = weavejs.api.data.IColumnWrapper;
    import IInitSelectableAttributes = weavejs.api.ui.IInitSelectableAttributes;
    import EventCallbackCollection = weavejs.core.EventCallbackCollection;
    import IVisTool, { IVisToolProps, IVisToolState } from "weave/api/ui/IVisTool";
    import { DataTable, SortDirection } from "weave/ui/DataTable";
    export interface IDataTableState extends IVisToolState {
        width?: number;
        height?: number;
    }
    export interface TableEventData {
        key: IQualifiedKey;
        column: IAttributeColumn;
    }
    export class AttributeColumnTable extends DataTable<IQualifiedKey> {
    }
    export default class TableTool extends React.Component<IVisToolProps, IDataTableState> implements IVisTool, IInitSelectableAttributes {
        attributeColumnTable: AttributeColumnTable;
        columns: LinkableHashMap;
        sortFieldIndex: LinkableNumber;
        columnWidth: LinkableNumber;
        rowHeight: LinkableNumber;
        headerHeight: LinkableNumber;
        sortInDescendingOrder: LinkableBoolean;
        panelTitle: LinkableString;
        selectionFilter: DynamicKeyFilter;
        probeFilter: DynamicKeyFilter;
        filteredKeySet: FilteredKeySet;
        private readonly selectionKeySet;
        private readonly probeKeySet;
        altText: LinkableString;
        idProperty: string;
        constructor(props: IVisToolProps);
        readonly deprecatedStateMapping: {
            showKeyColumn: (value: boolean) => void;
        };
        handleShowKeyColumn: (value: boolean) => void;
        readonly keyColumnShown: boolean;
        readonly title: string;
        componentDidMount(): void;
        componentDidUpdate(): void;
        getMenuItems(): MenuItemProps[];
        dataChanged(): void;
        handleProbe: (ids: string[]) => void;
        handleSelection: (ids: string[]) => void;
        readonly selectableAttributes: Map<string, ILinkableHashMap | IColumnWrapper>;
        readonly defaultPanelTitle: string;
        static MAX_DEFAULT_COLUMNS: number;
        initSelectableAttributes(input: (IAttributeColumn | IColumnReference)[]): void;
        renderEditor: (pushCrumb: (title: string, renderFn: () => JSX.Element, stateObject: any) => void) => JSX.Element;
        getTitlesEditor(): React.ReactChild[][];
        onSort: (columnKey: string, sortDirection: SortDirection) => void;
        events: EventCallbackCollection<TableEventData>;
        handleCellDoubleClick: (rowId: string, columnKey: string) => void;
        getCellValue: (row: IQualifiedKey, columnKey: string) => React.ReactChild;
        getColumnTitle: (columnKey: string) => React.ReactChild;
        render(): JSX.Element;
    }
}
declare module "weave/tool/TextTool" {
    import * as React from "react";
    import * as weavejs from "weavejs";
    import LinkableString = weavejs.core.LinkableString;
    import LinkableNumber = weavejs.core.LinkableNumber;
    import IColumnWrapper = weavejs.api.data.IColumnWrapper;
    import ILinkableHashMap = weavejs.api.core.ILinkableHashMap;
    import IVisTool from "weave/api/ui/IVisTool";
    import { IVisToolProps } from "weave/api/ui/IVisTool";
    import { IVisToolState } from "weave/api/ui/IVisTool";
    export default class TextTool extends React.Component<IVisToolProps, IVisToolState> implements IVisTool {
        htmlText: LinkableString;
        padding: LinkableNumber;
        panelBackgroundColor: LinkableNumber;
        panelBorderColor: LinkableNumber;
        private element;
        private textToolContainerClass;
        constructor(props: IVisToolProps);
        panelTitle: LinkableString;
        altText: LinkableString;
        readonly title: string;
        readonly selectableAttributes: Map<string, ILinkableHashMap | IColumnWrapper>;
        readonly defaultPanelTitle: string;
        getTitlesEditor(): React.ReactChild[][];
        renderEditor: (pushCrumb?: Function) => JSX.Element;
        readonly deprecatedStateMapping: {
            "htmlText": LinkableString;
            "padding": LinkableNumber;
            "panelBackgroundColor": LinkableNumber;
            "panelBorderColor": LinkableNumber;
        };
        componentDidUpdate(): void;
        render(): JSX.Element;
    }
}
declare module "weave/modules/proj4" {
    import * as proj4 from "proj4";
    var _default: typeof proj4;
    export default _default;
}
declare module "weave/tool/oltool/IOpenLayersMapTool" {
    import * as ol from "openlayers";
    import * as weavejs from "weavejs";
    import LinkableString = weavejs.core.LinkableString;
    import LinkableHashMap = weavejs.core.LinkableHashMap;
    import Bounds2D = weavejs.geom.Bounds2D;
    /**
     *
     */
    export interface IOpenLayersMapTool {
        /**
         *
         */
        projectionSRS: LinkableString;
        getDefaultProjection: () => string;
        map: ol.Map;
        layers: LinkableHashMap;
        getExtent(): Bounds2D;
        interactionMode: LinkableString;
    }
    export class IOpenLayersMapTool {
        static MAP_TOOL: string;
    }
    export default IOpenLayersMapTool;
}
declare module "weave/modules/jszip" {
    import * as jszip from "jszip";
    var _default: {
        (): jszip;
        new (): jszip;
        prototype: jszip;
        support: JSZipSupport;
        compressions: {
            DEFLATE: DEFLATE;
        };
    };
    export default _default;
}
declare module "weave/tool/oltool/Projections" {
    import * as weavejs from "weavejs";
    import * as ol from "openlayers";
    import WeavePromise = weavejs.util.WeavePromise;
    export default class Projections {
        static DEFAULT_PROJECTION: string;
        private static projectionDbPromise;
        static readonly projectionDbReadyOrFailed: boolean;
        static getProjection(projectionName: string): ol.proj.Projection;
        static loadProjDatabase(): WeavePromise<boolean>;
        static projectionVerifier(value: string): boolean;
        static estimatedExtentMap: Map<string, [number, number, number, number]>;
        static getEstimatedExtent(proj: ol.proj.Projection): ol.Extent;
    }
}
declare module "weave/tool/oltool/layer/AbstractLayer" {
    import * as React from "react";
    import * as weavejs from "weavejs";
    import * as ol from "openlayers";
    import ILinkableObject = weavejs.api.core.ILinkableObject;
    import LinkableNumber = weavejs.core.LinkableNumber;
    import LinkableBoolean = weavejs.core.LinkableBoolean;
    import LinkableVariable = weavejs.core.LinkableVariable;
    import LinkableString = weavejs.core.LinkableString;
    import IColumnWrapper = weavejs.api.data.IColumnWrapper;
    import IFilteredKeySet = weavejs.api.data.IFilteredKeySet;
    export type EditableField = [LinkableBoolean | LinkableString | LinkableNumber, (string | {
        label: string;
        value: any;
    })[]] | LinkableVariable | IFilteredKeySet;
    import Bounds2D = weavejs.geom.Bounds2D;
    import IOpenLayersMapTool from "weave/tool/oltool/IOpenLayersMapTool";
    export default class AbstractLayer implements ILinkableObject {
        opacity: LinkableNumber;
        visible: LinkableBoolean;
        selectable: LinkableBoolean;
        private projectionSRS;
        readonly deprecatedStateMapping: Object;
        getExtent(): Bounds2D;
        static selectableLayerFilter(layer: ol.layer.Base): boolean;
        private renderEditableField(value, key);
        renderEditableFields(): React.ReactChild[][];
        renderEditor: (pushCrumb?: (title: string, renderFn: () => JSX.Element, stateObject: any) => void) => JSX.Element;
        readonly editableFields: Map<string, EditableField>;
        readonly selectableAttributes: Map<string, IColumnWrapper>;
        constructor();
        onLayerReady(): void;
        updateProjection(): void;
        parent: IOpenLayersMapTool;
        private _source;
        source: ol.source.Source;
        private _olLayer;
        private addAndConfigureLayer();
        olLayer: ol.layer.Layer;
        readonly outputProjection: string;
        getDescription(): string;
        dispose(): void;
    }
}
declare module "weave/tool/oltool/layer/AbstractFeatureLayer" {
    import * as weavejs from "weavejs";
    import * as ol from "openlayers";
    import IQualifiedKey = weavejs.api.data.IQualifiedKey;
    import KeySet = weavejs.data.key.KeySet;
    import FilteredKeySet = weavejs.data.key.FilteredKeySet;
    import DynamicKeyFilter = weavejs.data.key.DynamicKeyFilter;
    import DynamicColumn = weavejs.data.column.DynamicColumn;
    import ExtendedDynamicColumn = weavejs.data.column.ExtendedDynamicColumn;
    import AbstractLayer from "weave/tool/oltool/layer/AbstractLayer";
    import { EditableField } from "weave/tool/oltool/layer/AbstractLayer";
    export abstract class AbstractFeatureLayer extends AbstractLayer {
        private updateMetaStyle;
        private debounced_updateMetaStyles;
        private changedItems;
        filteredKeySet: FilteredKeySet;
        selectionFilter: DynamicKeyFilter;
        probeFilter: DynamicKeyFilter;
        private _cachedRequiredAttributes;
        protected getRequiredAttributes(): (DynamicColumn | ExtendedDynamicColumn)[];
        readonly requiredAttributes: (DynamicColumn | ExtendedDynamicColumn)[];
        getExtent(): weavejs.geom.Bounds2D;
        inputProjection: string;
        readonly selectionKeySet: KeySet;
        isSelected(key: IQualifiedKey): boolean;
        readonly probeKeySet: KeySet;
        isProbed(key: IQualifiedKey): boolean;
        readonly editableFields: Map<string, EditableField>;
        styleResolutionDependent: boolean;
        source: ol.source.Vector;
        constructor();
        onLayerReady(): void;
        onFeatureAdd(vectorEvent: any): void;
        onFeaturePropertyChange(objectEvent: any): void;
        abstract updateStyleData(): void;
        getToolTipColumns(): Array<any>;
        static toColorArray(color: string | number, alpha: any): any;
        static toColorRGBA(colorString: any, alpha: any): string;
        updateSetFromKeySet(keyFilter: DynamicKeyFilter, previousContents: Set<IQualifiedKey>): void;
        updateMetaStyles(): void;
        updateMetaStyle_unbound(feature: any): void;
        static olFillFromWeaveFill(fill: any, fade?: any): ol.style.Fill;
        static olStrokeFromWeaveStroke(stroke: any, fade?: number): ol.style.Stroke;
        static getOlProbedStyle(baseStrokeStyle: any): Array<ol.style.Style>;
        static getOlSelectionStyle(baseStrokeStyle: any): Array<ol.style.Style>;
        static SELECT_WIDTH: number;
        static PROBE_HALO_WIDTH: number;
        static PROBE_LINE_WIDTH: number;
        static Styles: Object;
    }
    export interface MetaStyleProperties {
        normalStyle: ol.style.Style | Array<ol.style.Style>;
        unselectedStyle: ol.style.Style | Array<ol.style.Style>;
        selectedStyle: ol.style.Style | Array<ol.style.Style>;
        probedStyle: ol.style.Style | Array<ol.style.Style>;
    }
    export default AbstractFeatureLayer;
}
declare module "weave/tool/oltool/layer/AbstractGlyphLayer" {
    import * as weavejs from "weavejs";
    import DynamicColumn = weavejs.data.column.DynamicColumn;
    import LinkableString = weavejs.core.LinkableString;
    import AbstractFeatureLayer from "weave/tool/oltool/layer/AbstractFeatureLayer";
    import { EditableField } from "weave/tool/oltool/layer/AbstractLayer";
    export abstract class AbstractGlyphLayer extends AbstractFeatureLayer {
        dataX: DynamicColumn;
        dataY: DynamicColumn;
        sourceProjection: LinkableString;
        readonly editableFields: Map<string, EditableField>;
        readonly selectableAttributes: Map<string, weavejs.api.data.IColumnWrapper>;
        protected getRequiredAttributes(): (weavejs.data.column.ExtendedDynamicColumn | DynamicColumn)[];
        constructor();
        readonly inputProjection: any;
        onLayerReady(): void;
        _getFeatureIds(): any[];
        updateProjection(): void;
        static _projectionErrorsShown: Set<string>;
        updateLocations(): void;
    }
    export default AbstractGlyphLayer;
}
declare module "weave/tool/oltool/layer/CircleCache" {
    import * as ol from "openlayers";
    export default class CircleCache {
        static cache: Map<string, ol.style.Circle>;
        static circleDefToString(fillStyle: ol.style.Fill, strokeStyle: ol.style.Stroke, radius: number): string;
        static getCircle(options: {
            fill?: ol.style.Fill;
            stroke?: ol.style.Stroke;
            radius: number;
        }): ol.style.Circle;
    }
}
declare module "weave/tool/oltool/layer/ScatterPlotLayer" {
    import * as weavejs from "weavejs";
    import * as ol from "openlayers";
    import IColumnWrapper = weavejs.api.data.IColumnWrapper;
    import AlwaysDefinedColumn = weavejs.data.column.AlwaysDefinedColumn;
    import IAttributeColumn = weavejs.api.data.IAttributeColumn;
    import AbstractGlyphLayer from "weave/tool/oltool/layer/AbstractGlyphLayer";
    import SolidFillStyle from "weave/plot/SolidFillStyle";
    import SolidLineStyle from "weave/plot/SolidLineStyle";
    export default class ScatterPlotLayer extends AbstractGlyphLayer {
        readonly selectableAttributes: Map<string, IColumnWrapper>;
        fill: SolidFillStyle;
        line: SolidLineStyle;
        radius: AlwaysDefinedColumn;
        private readonly radiusNorm;
        private readonly radiusData;
        constructor();
        onLayerReady(): void;
        readonly deprecatedStateMapping: {};
        getToolTipColumns(): IAttributeColumn[];
        static getSelectedStyle(record: any, strokeEnabled: boolean, fillEnabled: boolean, olSelectionStyle: Array<ol.style.Style>): Array<ol.style.Style>;
        static getProbedStyle(record: any, strokeEnabled: boolean, fillEnabled: boolean, olProbedStyle: Array<ol.style.Style>): Array<ol.style.Style>;
        static getNormalStyle(record: any, strokeEnabled: boolean, fillEnabled: boolean, olStroke: ol.style.Stroke, olFill: ol.style.Fill): Array<ol.style.Style>;
        static getUnselectedStyle(record: any, strokeEnabled: boolean, fillEnabled: boolean, olStrokeFaded: ol.style.Stroke, olFillFaded: ol.style.Fill): Array<ol.style.Style>;
        updateStyleData(): void;
    }
}
declare module "weave/tool/oltool/layer/GeometryLayer" {
    import * as weavejs from "weavejs";
    import IAttributeColumn = weavejs.api.data.IAttributeColumn;
    import DynamicColumn = weavejs.data.column.DynamicColumn;
    import AlwaysDefinedColumn = weavejs.data.column.AlwaysDefinedColumn;
    import { AbstractFeatureLayer } from "weave/tool/oltool/layer/AbstractFeatureLayer";
    import { EditableField } from "weave/tool/oltool/layer/AbstractLayer";
    import SolidFillStyle from "weave/plot/SolidFillStyle";
    import SolidLineStyle from "weave/plot/SolidLineStyle";
    export default class GeometryLayer extends AbstractFeatureLayer {
        private geoJsonParser;
        fill: SolidFillStyle;
        line: SolidLineStyle;
        geometryColumn: DynamicColumn;
        radius: AlwaysDefinedColumn;
        protected getRequiredAttributes(): (weavejs.data.column.ExtendedDynamicColumn | DynamicColumn)[];
        readonly selectableAttributes: Map<string, weavejs.api.data.IColumnWrapper>;
        readonly editableFields: Map<string, EditableField>;
        private readonly radiusNorm;
        private readonly radiusData;
        constructor();
        onLayerReady(): void;
        updateProjection(): void;
        readonly deprecatedStateMapping: {};
        readonly inputProjection: any;
        updateGeometryData(): void;
        getToolTipColumns(): IAttributeColumn[];
        updateStyleData(): void;
    }
}
declare module "weave/tool/oltool/layer/TileLayer" {
    import * as weavejs from "weavejs";
    import LinkableString = weavejs.core.LinkableString;
    import LinkableVariable = weavejs.core.LinkableVariable;
    import AbstractLayer from "weave/tool/oltool/layer/AbstractLayer";
    export default class TileLayer extends AbstractLayer {
        oldProviderName: string;
        provider: LinkableString;
        providerOptions: LinkableVariable;
        renderEditor: () => JSX.Element;
        getExtent(): weavejs.geom.Bounds2D;
        constructor();
        onLayerReady(): void;
        onProviderChange(): void;
        updateProjection(): void;
        static STAMEN_LAYERS: string[];
        static MAPQUEST_LAYERS: string[];
        readonly deprecatedStateMapping: {};
        private static isXYZString(url);
        private getSource();
        updateTileSource(): void;
    }
}
declare module "weave/tool/oltool/layer/ImageGlyphCache" {
    export default class ImageGlyphCache {
        private baseImageElements;
        private canvasMap;
        private imageMap;
        private context;
        constructor(context: any);
        requestBaseImageElement(url: any, callback: any): void;
        getCachedCanvas(url: any, color: any): {
            canvas: HTMLCanvasElement;
            freshCanvas: boolean;
        };
        requestDataUrl(url: string, color: any, callback: any): void;
        getImage(url: any, color: any): HTMLImageElement;
    }
}
declare module "weave/tool/oltool/layer/ImageGlyphLayer" {
    import * as weavejs from "weavejs";
    import * as ol from "openlayers";
    import AlwaysDefinedColumn = weavejs.data.column.AlwaysDefinedColumn;
    import IAttributeColumn = weavejs.api.data.IAttributeColumn;
    import AbstractGlyphLayer from "weave/tool/oltool/layer/AbstractGlyphLayer";
    export default class ImageGlyphLayer extends AbstractGlyphLayer {
        private imageGlyphCache;
        imageSize: AlwaysDefinedColumn;
        imageURL: AlwaysDefinedColumn;
        dataAlpha: AlwaysDefinedColumn;
        dataColor: AlwaysDefinedColumn;
        readonly selectableAttributes: Map<string, weavejs.api.data.IColumnWrapper>;
        constructor();
        onLayerReady(): void;
        getToolTipColumns(): IAttributeColumn[];
        setIconStyle(feature: ol.Feature, img: any, iconSize: number, alpha: number): void;
        updateStyleData(): void;
        readonly deprecatedStateMapping: {};
    }
}
declare module "weave/tool/oltool/layer/LabelLayer" {
    import * as weavejs from "weavejs";
    import DynamicColumn = weavejs.data.column.DynamicColumn;
    import AlwaysDefinedColumn = weavejs.data.column.AlwaysDefinedColumn;
    import LinkableBoolean = weavejs.core.LinkableBoolean;
    import AbstractGlyphLayer from "weave/tool/oltool/layer/AbstractGlyphLayer";
    import { EditableField } from "weave/tool/oltool/layer/AbstractLayer";
    export default class LabelLayer extends AbstractGlyphLayer {
        size: AlwaysDefinedColumn;
        text: DynamicColumn;
        color: AlwaysDefinedColumn;
        sortColumn: DynamicColumn;
        hideOverlappingText: LinkableBoolean;
        readonly selectableAttributes: Map<string, weavejs.api.data.IColumnWrapper>;
        readonly editableFields: Map<string, EditableField>;
        readonly deprecatedStateMapping: {};
        protected getRequiredAttributes(): (weavejs.data.column.ExtendedDynamicColumn | DynamicColumn)[];
        constructor();
        onLayerReady(): void;
        updateStyleData(): void;
    }
}
declare module "weave/tool/oltool/CustomZoomToExtent" {
    import * as ol from "openlayers";
    export default class CustomZoomToExtent extends ol.control.Control {
        private extent;
        constructor(opt_options?: olx.control.ZoomToExtentOptions);
        private handleClick(event);
        private handleZoomToExtent();
    }
}
declare module "weave/tool/oltool/InteractionModeCluster" {
    import * as ol from "openlayers";
    export default class InteractionModeCluster extends ol.control.Control {
        constructor(optOptions: any);
        private interactionMode;
        private updateInteractionMode_weaveToControl;
        setMap(map: ol.Map): void;
    }
}
declare module "weave/tool/oltool/ProbeInteraction" {
    import * as ol from "openlayers";
    import OpenLayersMapTool from "weave/tool/oltool/OpenLayersMapTool";
    export default class ProbeInteraction extends ol.interaction.Pointer {
        private topKey;
        private topZIndex;
        private topKeySet;
        private topLayer;
        private tool;
        private toolTip;
        constructor(tool: OpenLayersMapTool);
        setMap(map: ol.Map): void;
        private onFeatureAtPixel(feature, layer);
        private pixelToKey(pixel);
        private handleMoveEvent(event);
        handleOutEvent(event: MouseEvent): void;
    }
}
declare module "weave/tool/oltool/DragSelection" {
    import * as ol from "openlayers";
    export default class DragSelection extends ol.interaction.DragBox {
        private mode;
        private _probeInteraction;
        constructor();
        private boxEndCondition(mapBrowserEvent, startPixel, endPixel);
        private readonly probeInteraction;
        onBoxStart(event: any): void;
        updateSelection(extent: any): void;
        onBoxDrag(event: any): void;
        onBoxEnd(event: any): void;
    }
}
declare module "weave/tool/oltool/CustomDragZoom" {
    import * as ol from "openlayers";
    export default class CustomDragZoom extends ol.interaction.DragBox {
        constructor();
        private _probeInteraction;
        private readonly probeInteraction;
        onBoxStart(event: any): void;
        onBoxEnd(event: any): void;
    }
}
declare module "weave/tool/oltool/CustomView" {
    import * as ol from "openlayers";
    export default class CustomView extends ol.View {
        enableResolutionConstraint: boolean;
        constrainResolution(resolution: number, opt_delta?: number, opt_direction?: number): number;
    }
}
declare module "weave/tool/oltool/LayerManager" {
    import * as React from "react";
    import * as weavejs from "weavejs";
    import LinkableHashMap = weavejs.core.LinkableHashMap;
    import AbstractLayer from "weave/tool/oltool/layer/AbstractLayer";
    export interface ILayerManagerState {
        selectedLayer?: AbstractLayer;
        openedLayer?: AbstractLayer;
    }
    export interface ILayerManagerProps extends React.HTMLProps<LayerManager> {
        layers: LinkableHashMap;
        pushCrumb?: (title: string, renderFn: () => JSX.Element, stateObject: any) => void;
        selectedLayer?: AbstractLayer;
        onLayerSelection?: Function;
    }
    export default class LayerManager extends React.Component<ILayerManagerProps, ILayerManagerState> {
        constructor(props: ILayerManagerProps);
        componentWillReceiveProps(nextProps: ILayerManagerProps): void;
        onEditLayerClick: (layer: AbstractLayer) => void;
        generateItem: (layer: AbstractLayer, index: number) => JSX.Element;
        moveSelectedUp: () => void;
        moveSelectedDown: () => void;
        removeSelected: () => void;
        readonly selectionIndex: number;
        render(): JSX.Element;
    }
}
declare module "weave/tool/oltool/PanCluster" {
    import * as ol from "openlayers";
    export default class PanCluster extends ol.control.Control {
        constructor(optOptions?: any);
    }
}
declare module "weave/tool/oltool/OpenLayersMapTool" {
    import * as React from "react";
    import * as weavejs from "weavejs";
    import * as ol from "openlayers";
    import MenuItemProps = weavejs.ui.menu.MenuItemProps;
    import IQualifiedKey = weavejs.api.data.IQualifiedKey;
    import ZoomBounds = weavejs.geom.ZoomBounds;
    import LinkableString = weavejs.core.LinkableString;
    import LinkableVariable = weavejs.core.LinkableVariable;
    import LinkableBoolean = weavejs.core.LinkableBoolean;
    import LinkableHashMap = weavejs.core.LinkableHashMap;
    import LinkableNumber = weavejs.core.LinkableNumber;
    import IAttributeColumn = weavejs.api.data.IAttributeColumn;
    import IColumnReference = weavejs.api.data.IColumnReference;
    import EventCallbackCollection = weavejs.core.EventCallbackCollection;
    import Bounds2D = weavejs.geom.Bounds2D;
    import { OverrideBounds } from "weave/tool/AbstractVisTool";
    import IOpenLayersMapTool from "weave/tool/oltool/IOpenLayersMapTool";
    import AbstractLayer from "weave/tool/oltool/layer/AbstractLayer";
    import CustomZoomToExtent from "weave/tool/oltool/CustomZoomToExtent";
    import InteractionModeCluster from "weave/tool/oltool/InteractionModeCluster";
    import { IVisToolProps, IVisToolState } from "weave/api/ui/IVisTool";
    import IAltText from "weave/api/ui/IAltText";
    import { IAltTextConfig } from "weave/api/ui/IAltText";
    import PanCluster from "weave/tool/oltool/PanCluster";
    export interface MapEventData {
        map: OpenLayersMapTool;
        mapEvent: ol.MapBrowserEvent;
        type: string;
        key: IQualifiedKey;
        layer: AbstractLayer;
    }
    export default class OpenLayersMapTool extends React.Component<IVisToolProps, IVisToolState> implements IOpenLayersMapTool, IAltText {
        static isGeomColumnOrRef(column: (IAttributeColumn | IColumnReference)): boolean;
        private static controlIndex;
        altText: IAltTextConfig;
        getAutomaticDescription(): string;
        setOverrideExtent: () => void;
        clearOverrideExtent: () => void;
        overrideExtentDefined: () => boolean;
        overrideSet(): boolean;
        map: ol.Map;
        centerCallbackHandle: any;
        resolutionCallbackHandle: any;
        private element;
        zoomBounds: ZoomBounds;
        extentOverride: OverrideBounds;
        projectionSRS: LinkableString;
        interactionMode: LinkableString;
        enableMouseWheel: LinkableBoolean;
        layers: LinkableHashMap;
        panelTitle: LinkableString;
        snapZoomToBaseMap: LinkableBoolean;
        maxZoomLevel: LinkableNumber;
        minZoomLevel: LinkableNumber;
        zoomExtent: CustomZoomToExtent;
        zoomButtons: ol.control.Zoom;
        zoomSlider: ol.control.ZoomSlider;
        panButtons: PanCluster;
        mouseModeButtons: InteractionModeCluster;
        showZoomButtons: LinkableBoolean;
        showZoomSlider: LinkableBoolean;
        showPanButtons: LinkableBoolean;
        showZoomExtentButton: LinkableBoolean;
        showMouseModeControls: LinkableBoolean;
        toolPadding: LinkableNumber;
        controlLocation: LinkableVariable;
        readonly title: string;
        constructor(props: IVisToolProps);
        private initLater();
        initSelectableAttributes(input: (IAttributeColumn | IColumnReference)[]): void;
        readonly deprecatedStateMapping: Object;
        static matchesLayerSettings: (value: any) => boolean;
        deprecatedPathRewrite(relativePath: string[]): string[];
        updateCursor(): void;
        events: EventCallbackCollection<MapEventData>;
        private _stopEventPropagation;
        stopEventPropagation(): void;
        handleGenericEvent: (event: ol.MapBrowserEvent) => boolean;
        initializeMap(): void;
        updateViewParameters_weaveToOl(): void;
        private _lastSize;
        handleFrame(): void;
        private updateControl(lbool, control);
        private updateControls_weaveToOl();
        private updateControlPositions();
        updateCenter_olToWeave(): void;
        updateResolutionDependentStyles(event: ol.MapEvent): void;
        updateZoom_olToWeave(): void;
        updateZoomAndCenter_weaveToOl(): void;
        getDefaultProjection(): string;
        requestDetail(): void;
        updateResolutionSnapping(): void;
        updatePlotters_weaveToOl(): void;
        hasNonEmptySelection(): boolean;
        getMenuItems(): MenuItemProps[];
        readonly defaultPanelTitle: string;
        getExtent(): Bounds2D;
        zoomToSelection(inputKeys?: Array<IQualifiedKey>, zoomMarginPercent?: number): void;
        renderEditor: (pushCrumb: (title: string, renderFn: () => JSX.Element, stateObject: any) => void) => JSX.Element;
        componentDidMount(): void;
        render(): JSX.Element;
    }
    export interface IOpenLayersMapToolEditorState {
        selectedLayer: AbstractLayer;
    }
    export interface IOpenLayersMapToolEditorProps {
        tool: OpenLayersMapTool;
        pushCrumb: (title: string, renderFn: () => JSX.Element, stateObject: any) => void;
    }
}
declare module "weave/menu/ChartsMenu" {
    import * as weavejs from "weavejs";
    import MenuBarItemProps = weavejs.ui.menu.MenuBarItemProps;
    import MenuItemProps = weavejs.ui.menu.MenuItemProps;
    import IWeaveMenus from "weave/menu/IWeaveMenus";
    export default class ChartsMenu implements MenuBarItemProps {
        constructor(owner: IWeaveMenus);
        owner: IWeaveMenus;
        label: string;
        readonly menu: MenuItemProps[];
        getCreateObjectItems(): {
            label: string;
            click: any;
        }[];
        static isBeta(impl: Class): boolean;
    }
}
declare module "weave/dialog/InteractiveTour" {
    import * as React from "react";
    import * as weavejs from "weavejs";
    import LinkableString = weavejs.core.LinkableString;
    export interface InteractiveTourProps extends React.HTMLProps<InteractiveTour> {
        enableToolTip?: boolean;
        onClose?: Function;
    }
    export interface InteractiveTourState {
        visible?: boolean;
        activeStepName?: string;
        tooltipHeight?: number;
        tooltipWidth?: number;
    }
    export default class InteractiveTour extends React.Component<InteractiveTourProps, InteractiveTourState> {
        static stepName: LinkableString;
        static unMountedStepName: string;
        static enable: boolean;
        static steps: string[];
        static stepContents: string[];
        static stepPointers: string[];
        static stepComponentMap: any;
        static pointerComponentMap: any;
        static stepComponentRefCallbackMap: Map<string, (classInstance: any) => void>;
        static stepPointerRefCallbackMap: Map<string, (classInstance: any) => void>;
        static startTour(steps: string[], stepContents: string[], stepPointers: string[]): void;
        static callComponentRefCallback(stepName: string, classInstance: any): void;
        static getComponentRefCallback(stepName: string): (classInstance: any) => void;
        static getPointerRefCallback(stepName: string): (classInstance: any) => void;
        static isLastStep(index: number): boolean;
        static reset(): void;
        static targetComponentOnClick(stepName: string): void;
        constructor(props: InteractiveTourProps);
        private targetMountedNode;
        private pointerMountedNode;
        updateNextComponentName: () => void;
        closeHandler: () => void;
        render(): JSX.Element;
        componentDidUpdate(): void;
    }
}
declare module "weave/editor/DataSourceEditor" {
    import * as React from "react";
    import * as weavejs from "weavejs";
    import SmartComponent = weavejs.ui.SmartComponent;
    import LinkableWatcher = weavejs.core.LinkableWatcher;
    import IDataSource = weavejs.api.data.IDataSource;
    import IWeaveTreeNode = weavejs.api.data.IWeaveTreeNode;
    import IColumnReference = weavejs.api.data.IColumnReference;
    import ILinkableHashMap = weavejs.api.core.ILinkableHashMap;
    import LinkableString = weavejs.core.LinkableString;
    export const PREVIEW: "preview";
    export const METADATA: "metadata";
    export const BROWSE: "browse";
    export type View = typeof PREVIEW | typeof METADATA | typeof BROWSE;
    export interface IDataSourceEditorProps {
        dataSource: IDataSource;
    }
    export interface IDataSourceEditorState {
        selectedBranch?: IWeaveTreeNode & IColumnReference;
        selectedLeaf?: IWeaveTreeNode & IColumnReference;
        showPreviewView?: boolean;
        guideToTab?: string;
    }
    export default class DataSourceEditor extends SmartComponent<IDataSourceEditorProps, IDataSourceEditorState> {
        dataSourceWatcher: LinkableWatcher;
        protected weaveRoot: ILinkableHashMap;
        constructor(props: IDataSourceEditorProps);
        handleProps(props: IDataSourceEditorProps): void;
        componentWillReceiveProps(props: IDataSourceEditorProps): void;
        componentWillUnmount(): void;
        getLabelEditor(labelLinkableString: LinkableString): [React.ReactChild, React.ReactChild];
        readonly editorFields: [React.ReactChild, React.ReactChild][];
        renderFields(): JSX.Element;
        private static nodeEqualityFunc(a, b);
        private static isNotGeometryList(node);
        renderPreviewView(): JSX.Element;
        renderConfigureView(): JSX.Element;
        getColumns: () => IColumnReference[];
        renderTablePreview: (columnRefs: IColumnReference[]) => JSX.Element;
        setSelection(props: IDataSourceEditorProps, newBranch: IWeaveTreeNode & IColumnReference, newLeaf: IWeaveTreeNode & IColumnReference): void;
        render(): JSX.Element;
    }
}
declare module "weave/admin/ConnectionEditor" {
    import * as React from "react";
    import * as weavejs from "weavejs";
    import SmartComponent = weavejs.ui.SmartComponent;
    import WeaveAdminService = weavejs.net.WeaveAdminService;
    export interface ILinkedInputProps {
        field: string;
        outerComponent: React.Component<any, any>;
        type?: string;
    }
    export class LinkedInput extends React.Component<ILinkedInputProps, Object> {
        constructor(props: ILinkedInputProps);
        render(): JSX.Element;
    }
    export interface IConnectionEditorProps {
        service: WeaveAdminService;
        connectionName: string;
        handleError: (error: any) => void;
        handleMessage: (message: string) => void;
        handleSuccessfulSave: (message: string, password: string) => void;
    }
    export interface IConnectionEditorState {
        is_superuser?: boolean;
        name?: string;
        pass?: string;
        folderName?: string;
        passShow?: boolean;
        connectString?: string;
        editorMode?: string;
        dbServerAddress?: string;
        dbServerPort?: string;
        dbDatabaseName?: string;
        dbUsername?: string;
        dbPassword?: string;
        dbDomain?: string;
        dbPasswordShow?: boolean;
    }
    export default class ConnectionEditor extends SmartComponent<IConnectionEditorProps, IConnectionEditorState> {
        constructor(props: IConnectionEditorProps);
        componentWillReceiveProps(nextProps: IConnectionEditorProps): void;
        saveConnection: (overwrite: boolean) => void;
        loadFromConnection: (connectionName: string) => void;
        renderLinkedInput: (entry: [React.ReactChild, string, string, React.ReactChild, string]) => [React.ReactChild, JSX.Element];
        readonly connectString: string;
        private static DBNAME_MESSAGE;
        private static ADDRESS_MESSAGE;
        private static PORT_MESSAGE;
        render(): JSX.Element;
        /**
        * @param dbms The name of a DBMS (MySQL, PostGreSQL, Microsoft SQL Server)
        * @param ip The IP address of the DBMS.
        * @param port The port the DBMS is on (optional, can be "" to use default).
        * @param database The name of a database to connect to (can be "" for MySQL)
        * @param user The username to use when connecting.
        * @param pass The password associated with the username.
        * @param domain The domain paramter for a SQLServer connection.
        * @return A connect string that can be used in the getConnection() function.
        */
        static getConnectString(dbms: string, ip: string, port: string, database: string, user: string, pass: string, domain: string): string;
    }
}
declare module "weave/admin/ConfigurationStorageEditor" {
    import * as weavejs from "weavejs";
    import SmartComponent = weavejs.ui.SmartComponent;
    import WeaveAdminService = weavejs.net.WeaveAdminService;
    export interface IConfigurationStorageEditorProps {
        service: WeaveAdminService;
    }
    export interface IConfigurationStorageEditorState {
        connectionNames?: string[];
        currentConnectionName?: string;
        connectionName?: string;
        connectionPassword?: string;
        schemaName?: string;
        showAdvancedOptions?: boolean;
        metadataIdFields?: string;
        errors?: string[];
        messages?: string[];
    }
    export default class ConfigurationStorageEditor extends SmartComponent<IConfigurationStorageEditorProps, IConfigurationStorageEditorState> {
        constructor(props: IConfigurationStorageEditorProps);
        updateCurrentConnection(): void;
        componentDidUpdate(): void;
        componentDidMount(): void;
        handleError: (error: any) => void;
        handleMessage: (message: string) => void;
        save: () => void;
        render(): JSX.Element;
    }
}
declare module "weave/admin/ConnectionManager" {
    import * as weavejs from "weavejs";
    import PopupWindow = weavejs.ui.PopupWindow;
    import SmartComponent = weavejs.ui.SmartComponent;
    import DatabaseConfigInfo = weavejs.net.beans.DatabaseConfigInfo;
    import WeaveAdminService = weavejs.net.WeaveAdminService;
    export interface IConnectionManagerProps {
        service: WeaveAdminService;
    }
    export interface IConnectionManagerState {
        user?: string;
        errors?: string[];
        messages?: string[];
        connections?: string[];
        dbConfigInfo?: DatabaseConfigInfo;
        selected?: string;
    }
    export default class ConnectionManager extends SmartComponent<IConnectionManagerProps, IConnectionManagerState> {
        private login;
        constructor(props: IConnectionManagerProps);
        private element;
        componentDidMount(): void;
        handleError: (error: any) => void;
        handleMessage: (message: any) => void;
        updateConnectionsAndUser: () => void;
        private connectionToOption;
        createNewConnection: () => void;
        openConfigurationStorageEditor: () => PopupWindow;
        private handleSuccessfulSave;
        removeSelectedConnection: () => void;
        removeConnection: (connection: string) => void;
        render(): JSX.Element;
    }
}
declare module "weave/admin/SqlImport" {
    import * as React from "react";
    import * as weavejs from "weavejs";
    import SmartComponent = weavejs.ui.SmartComponent;
    import WeaveAdminService = weavejs.net.WeaveAdminService;
    export interface ISqlImportProps extends React.HTMLProps<SqlImport> {
        service: WeaveAdminService;
        selectIdFunc: (id: number) => void;
    }
    export interface ISqlImportState {
        append?: boolean;
        schema?: string;
        table?: string;
        displayName?: string;
        keyColumn?: string;
        keyColumnValid?: boolean;
        keyColumnTestInProgress?: boolean;
        keyType?: string;
        filteredKeyColumns?: string[];
        schemaOptions?: string[];
        tableOptions?: string[];
        columnOptions?: string[];
        keyTypeSuggestions?: string[];
        importInProgress?: boolean;
        errors?: string[];
    }
    export default class SqlImport extends SmartComponent<ISqlImportProps, ISqlImportState> {
        private login;
        constructor(props: ISqlImportProps);
        updateSchemas: () => void;
        updateTables: (schema: string) => void;
        updateColumns: (schema: string, table: string) => void;
        updateKeyTypeSuggestions: () => void;
        handleError: (error: any) => void;
        testKeyColumn: () => void;
        onImportClick: () => void;
        componentDidMount(): void;
        componentDidUpdate(prevProps: ISqlImportProps, prevState: ISqlImportState): void;
        private element;
        render(): JSX.Element;
    }
}
declare module "weave/editor/WeaveDataSourceEditor" {
    import * as React from "react";
    import * as weavejs from "weavejs";
    import IWeaveTreeNode = weavejs.api.data.IWeaveTreeNode;
    import PopupWindow = weavejs.ui.PopupWindow;
    import WeaveAdminService = weavejs.net.WeaveAdminService;
    import IColumnReference = weavejs.api.data.IColumnReference;
    import DataSourceEditor, { IDataSourceEditorProps } from "weave/editor/DataSourceEditor";
    export default class WeaveDataSourceEditor extends DataSourceEditor {
        componentWillReceiveProps(props: IDataSourceEditorProps): void;
        onHierarchySelected: (selectedItems: (IWeaveTreeNode & IColumnReference)[]) => void;
        setHierarchySelection(): void;
        readonly service: WeaveAdminService;
        private static getBaseUrl(serviceUrl);
        private selectId;
        openSqlImport: () => PopupWindow;
        openCsvImport: () => void;
        openConnectionManager: () => PopupWindow;
        readonly editorFields: [React.ReactChild, React.ReactChild][];
    }
}
declare module "weave/editor/MetadataGrid" {
    import * as React from "react";
    export type MetadataEntry = {
        [key: string]: any;
    };
    export interface MetadataGridProps extends React.Props<MetadataGrid> {
        entries: MetadataEntry[];
        onChangeCallback: (entry: MetadataEntry) => void;
    }
    export interface MetadataGridState {
        entry: MetadataEntry;
        properties?: string[];
    }
    export default class MetadataGrid extends React.Component<MetadataGridProps, MetadataGridState> {
        constructor(props: MetadataGridProps);
        componentWillReceiveProps(nextProps: MetadataGridProps): void;
        getEditor(entry: MetadataEntry, key: string, value: any): JSX.Element;
        getCombinedEntry(): MetadataEntry;
        render(): JSX.Element;
    }
}
declare module "weave/editor/CSVMetadataEditor" {
    import * as React from "react";
    import * as weavejs from "weavejs";
    import CSVDataSource = weavejs.data.source.CSVDataSource;
    import { MetadataEntry } from "weave/editor/MetadataGrid";
    export interface CSVMetadataEditorProps extends React.Props<CSVMetadataEditor> {
        datasource: CSVDataSource;
        onChangeCallback: (newMetadata: MetadataEntry, selectedIds: Array<number | string>) => void;
    }
    export interface CSVMetadataEditorState {
        selected?: Array<number | string>;
        columnIds?: Array<number | string>;
    }
    export default class CSVMetadataEditor extends React.Component<CSVMetadataEditorProps, CSVMetadataEditorState> {
        constructor(props: CSVMetadataEditorProps);
        setSelectedColumnIds: (columnIds: (string | number)[]) => void;
        getSelectedColumnIds(): Array<number | string>;
        handleMetadataChange: (entry: {
            [key: string]: any;
        }) => void;
        render(): JSX.Element;
    }
}
declare module "weave/ui/KeyTypeInput" {
    import * as React from "react";
    import * as weavejs from "weavejs";
    import LinkableString = weavejs.core.LinkableString;
    import Input = weavejs.ui.Input;
    export interface KeyTypeInputProps extends React.HTMLProps<Input> {
        keyTypeProperty: LinkableString;
    }
    export interface KeyTypeInputState {
    }
    export default class KeyTypeInput extends React.Component<KeyTypeInputProps, KeyTypeInputState> {
        constructor(props: KeyTypeInputProps);
        changeListener: (content: string) => void;
        render(): JSX.Element;
    }
}
declare module "weave/ui/FileSelector" {
    import * as React from "react";
    import * as weavejs from "weavejs";
    import LinkableFile = weavejs.core.LinkableFile;
    import LinkableString = weavejs.core.LinkableString;
    export interface IFileSelectorProps extends React.HTMLProps<FileSelector> {
        targetUrl: LinkableFile | LinkableString;
        placeholder?: string;
        accept?: string;
        onFileChange?: () => void;
    }
    export interface IFileSelectorState {
        validExtension: boolean;
    }
    export default class FileSelector extends React.Component<IFileSelectorProps, IFileSelectorState> {
        constructor(props: IFileSelectorProps);
        handleFileChange: (event: React.FormEvent) => void;
        componentWillReceiveProps(nextProps: IFileSelectorProps): void;
        render(): JSX.Element;
    }
}
declare module "weave/editor/CSVDataSourceEditor" {
    import * as React from "react";
    import * as weavejs from "weavejs";
    import PopupWindow = weavejs.ui.PopupWindow;
    import DataSourceEditor, { IDataSourceEditorProps } from "weave/editor/DataSourceEditor";
    export default class CSVDataSourceEditor extends DataSourceEditor {
        private _dataSourceNode;
        constructor(props: IDataSourceEditorProps);
        onUrlChange(): void;
        handleMetadataUpdate: (newMeta: {
            [key: string]: any;
        }, selectedIds: (string | number)[]) => void;
        handleProps(props: IDataSourceEditorProps): void;
        openMetadataEditor: () => PopupWindow;
        readonly editorFields: [React.ReactChild, React.ReactChild][];
        renderChildEditor(): JSX.Element;
    }
}
declare module "weave/editor/DBFDataSourceEditor" {
    import * as React from "react";
    import DataSourceEditor from "weave/editor/DataSourceEditor";
    export default class DBFDataSourceEditor extends DataSourceEditor {
        readonly editorFields: [React.ReactChild, React.ReactChild][];
    }
}
declare module "weave/editor/GeoJSONDataSourceEditor" {
    import * as React from "react";
    import DataSourceEditor from "weave/editor/DataSourceEditor";
    export default class GeoJSONDataSourceEditor extends DataSourceEditor {
        readonly editorFields: [React.ReactChild, React.ReactChild][];
    }
}
declare module "weave/editor/CensusGeographyFilter" {
    import * as React from "react";
    import * as weavejs from "weavejs";
    import LinkableVariable = weavejs.core.LinkableVariable;
    export interface CensusGeographyFilterProps {
        filterLinkableVariable: LinkableVariable;
        requires: string[];
        optional: string;
    }
    export interface CensusGeographyFilterState {
    }
    export class CensusGeographyFilter extends React.Component<CensusGeographyFilterProps, CensusGeographyFilterState> {
        constructor(props: CensusGeographyFilterProps);
        private state_fips;
        private county_fips;
        onFilterChange: (geoLevel: string, value: string) => void;
        renderFilter: (scope: string) => JSX.Element;
        render(): JSX.Element;
    }
    export interface CensusGeographyFilterColumnProps {
        geoLevel: string;
        parentGeo?: string;
        required: boolean;
        options: {
            fips: string;
            name: string;
        }[];
        selection?: string;
        onChange?: (geoLevel: string, value: string) => void;
    }
    export interface CensusGeographyFilterColumnState {
        selection?: string;
        enabled?: boolean;
    }
    export class CensusGeographyFilterColumn extends React.Component<CensusGeographyFilterColumnProps, CensusGeographyFilterColumnState> {
        constructor(props: CensusGeographyFilterColumnProps);
        state: CensusGeographyFilterColumnState;
        componentWillReceiveProps(nextProps: CensusGeographyFilterColumnProps): void;
        componentDidUpdate(prevProps: CensusGeographyFilterColumnProps, prevState: CensusGeographyFilterColumnState): void;
        updateEnabled: (event: React.FormEvent) => void;
        updateSelection: (event: React.FormEvent) => void;
        render(): JSX.Element;
    }
}
declare module "weave/editor/CensusDataSourceEditor" {
    import * as React from "react";
    import DataSourceEditor, { IDataSourceEditorState, IDataSourceEditorProps } from "weave/editor/DataSourceEditor";
    export interface CensusRawDataset {
        c_dataset: string[];
        c_vintage: number;
        identifier: string;
        title: string;
        c_isAvailable: boolean;
    }
    export interface ICensusDataSourceEditorState extends IDataSourceEditorState {
        dataFamily?: string;
        dataVintage?: string;
        geographies?: {
            value: string;
            label: string;
        }[];
        datasets?: CensusRawDataset[];
        optional?: string;
        requires?: string[];
    }
    export default class CensusDataSourceEditor extends DataSourceEditor {
        constructor(props: IDataSourceEditorProps);
        updateRequiresAndOptional: () => void;
        static isUsableFamily(family: string): boolean;
        static isInFamily(family: string, dataset: CensusRawDataset): boolean;
        static isOfVintage(vintage: string, dataset: CensusRawDataset): boolean;
        private api;
        state: ICensusDataSourceEditorState;
        private getDataFamilies();
        private getDataVintages(family);
        private getDatasets(family, vintage);
        private getDataset(datasetName);
        private getGeographies(dataSet);
        dataFamilyChanged: (selectedItem: any) => void;
        dataVintageChanged: (selectedItem: any) => void;
        readonly editorFields: [React.ReactChild, React.ReactChild][];
        renderFields(): JSX.Element;
    }
}
declare module "weave/editor/CKANDataSourceEditor" {
    import * as React from "react";
    import DataSourceEditor from "weave/editor/DataSourceEditor";
    import { IDataSourceEditorProps } from "weave/editor/DataSourceEditor";
    export default class CKANDataSourceEditor extends DataSourceEditor {
        private _dataSourceNode;
        constructor(props: IDataSourceEditorProps);
        readonly editorFields: [React.ReactChild, React.ReactChild][];
    }
}
declare module "weave/editor/CachedDataSourceEditor" {
    import * as React from "react";
    import DataSourceEditor from "weave/editor/DataSourceEditor";
    export default class CachedDataSourceEditor extends DataSourceEditor {
        readonly editorFields: [React.ReactChild, React.ReactChild][];
    }
}
declare module "weave/data/source/SpatialJoinTransform" {
    import * as weavejs from "weavejs";
    import ISelectableAttributes = weavejs.api.data.ISelectableAttributes;
    import IWeaveTreeNode = weavejs.api.data.IWeaveTreeNode;
    import LinkableString = weavejs.core.LinkableString;
    import DynamicColumn = weavejs.data.column.DynamicColumn;
    import ProxyColumn = weavejs.data.column.ProxyColumn;
    import AbstractDataSource = weavejs.data.source.AbstractDataSource;
    import IColumnReference = weavejs.api.data.IColumnReference;
    export default class SpatialJoinTransform extends AbstractDataSource implements ISelectableAttributes {
        geometryColumn: DynamicColumn;
        xColumn: DynamicColumn;
        yColumn: DynamicColumn;
        pointProjection: LinkableString;
        private _source;
        private _parser;
        readonly isLocal: boolean;
        readonly selectableAttributes: Map<string, (weavejs.api.data.IColumnWrapper | weavejs.api.core.ILinkableHashMap)>;
        constructor();
        protected initialize(forceRefresh?: Boolean): void;
        getHierarchyRoot(): IWeaveTreeNode & IColumnReference;
        protected generateHierarchyNode(metadata: {
            [property: string]: string;
        }): IWeaveTreeNode;
        protected requestColumnFromSource(proxyColumn: ProxyColumn): void;
    }
}
declare module "weave/editor/SpatialJoinTransformEditor" {
    import * as React from "react";
    import DataSourceEditor from "weave/editor/DataSourceEditor";
    export default class SpatialJoinTransformEditor extends DataSourceEditor {
        readonly editorFields: [React.ReactChild, React.ReactChild][];
    }
}
declare module "weave/editor/ForeignDataMappingTransformEditor" {
    import * as React from "react";
    import DataSourceEditor from "weave/editor/DataSourceEditor";
    export default class ForeignDataMappingTransformEditor extends DataSourceEditor {
        readonly editorFields: [React.ReactChild, React.ReactChild][];
    }
}
declare module "weave/editor/GroupedDataTransformEditor" {
    import * as React from "react";
    import DataSourceEditor from "weave/editor/DataSourceEditor";
    export default class GroupedDataTransformEditor extends DataSourceEditor {
        private isFiltered;
        private setFiltered;
        readonly editorFields: [React.ReactChild, React.ReactChild][];
    }
}
declare module "weave/menu/DataMenu" {
    import * as React from "react";
    import * as weavejs from "weavejs";
    import { Weave } from "weavejs";
    import MenuBarItemProps = weavejs.ui.menu.MenuBarItemProps;
    import MenuItemProps = weavejs.ui.menu.MenuItemProps;
    import IDataSource = weavejs.api.data.IDataSource;
    import IWeaveMenus from "weave/menu/IWeaveMenus";
    import { IDataSourceEditorProps } from "weave/editor/DataSourceEditor";
    export default class DataMenu implements MenuBarItemProps {
        constructor(owner: IWeaveMenus);
        owner: IWeaveMenus;
        label: string;
        readonly menu: MenuItemProps[];
        getExportItems(): MenuItemProps[];
        static editorRegistry: Map<new (..._: any[]) => IDataSource, React.ComponentClass<IDataSourceEditorProps>>;
        static getDataSourceItems(weave: Weave, onCreateItem?: (dataSource: IDataSource) => void): MenuItemProps[];
        static isBeta(impl: new () => IDataSource): boolean;
        getColumnsToExport: () => any[];
        exportCSV: () => void;
    }
}
declare module "weave/editor/ColorController" {
    import * as React from "react";
    import * as weavejs from "weavejs";
    import IColumnWrapper = weavejs.api.data.IColumnWrapper;
    import ColorColumn = weavejs.data.column.ColorColumn;
    import BinnedColumn = weavejs.data.column.BinnedColumn;
    import FilteredColumn = weavejs.data.column.FilteredColumn;
    export interface ColorControllerProps extends React.Props<ColorController> {
        colorColumn: ColorColumn;
    }
    export interface ColorControllerState {
    }
    export default class ColorController extends React.Component<ColorControllerProps, ColorControllerState> {
        tabLabels: string[];
        attributes: Map<string, IColumnWrapper>;
        constructor(props: ColorControllerProps);
        readonly binnedColumn: BinnedColumn;
        readonly dataColumn: FilteredColumn;
        handleFilterCheck: (value: boolean) => void;
        render(): JSX.Element;
    }
}
declare module "weave/editor/MouseoverController" {
    import * as React from "react";
    import * as weavejs from "weavejs";
    import ILinkableHashMap = weavejs.api.core.ILinkableHashMap;
    export interface MouseoverControllerProps extends React.Props<MouseoverController> {
        probedHeaderColumns: ILinkableHashMap;
        probedColumns: ILinkableHashMap;
    }
    export interface MouseoverControllerState {
    }
    export default class MouseoverController extends React.Component<MouseoverControllerProps, MouseoverControllerState> {
        attributes: Map<string, ILinkableHashMap>;
        constructor(props: MouseoverControllerProps);
        render(): JSX.Element;
    }
}
declare module "weave/ui/slider/RCSlider" {
    import * as React from "react";
    import * as weavejs from "weavejs";
    import SmartComponent = weavejs.ui.SmartComponent;
    export type SliderOption = {
        value: any;
        label: string;
    };
    export interface SliderProps {
        min?: number;
        max?: number;
        step?: number;
        options?: SliderOption[];
        selectedValues: any[];
        onChange: Function;
        vertical?: boolean;
        className: string;
        style: React.CSSProperties;
        type: string;
    }
    export default class RCSlider extends SmartComponent<SliderProps, {}> {
        static VERTICAL: string;
        static HORIZONTAL: string;
        static NUMERIC: string;
        static CATEGORICAL: string;
        static NUMERIC_DISCRETE: string;
        private options;
        private indexToValue;
        private valueToIndex;
        private indexToLabel;
        private min;
        private max;
        private element;
        private step;
        constructor(props: SliderProps);
        componentWillUpdate(): void;
        onChange(value: any): void;
        render(): JSX.Element;
    }
}
declare module "weave/ui/slider/HSlider" {
    import * as React from "react";
    import { SliderOption } from "weave/ui/slider/RCSlider";
    export interface HSliderProps {
        min?: number;
        max?: number;
        step?: number;
        options?: SliderOption[];
        selectedValues?: any[];
        type: string;
        reversed?: boolean;
        onChange?: (selectedValue: [string]) => void;
        style?: React.CSSProperties;
        className?: string;
    }
    export default class HSlider extends React.Component<HSliderProps, any> {
        constructor(props: HSliderProps);
        render(): JSX.Element;
    }
}
declare module "weave/ui/slider/VSlider" {
    import * as React from "react";
    import { SliderOption } from "weave/ui/slider/RCSlider";
    export interface VSliderProps {
        min?: number;
        max?: number;
        step?: number;
        options?: SliderOption[];
        selectedValues?: any[];
        type: string;
        reversed?: boolean;
        onChange?: (selectedValue: [string]) => void;
        style?: React.CSSProperties;
        className?: string;
    }
    export default class VSlider extends React.Component<VSliderProps, any> {
        constructor(props: VSliderProps);
        render(): JSX.Element;
    }
}
declare module "weave/ui/MenuLayoutComponent" {
    import * as React from "react";
    export interface IMenuLayoutComponentProps {
        selectedItems: any;
        options: {
            label: string;
            value: any;
        }[];
        multiple?: boolean;
        displayMode: string;
        onChange: (selectedValue: any[]) => void;
        playToggle?: () => void;
        isPlaying?: boolean;
    }
    export const LAYOUT_LIST: string;
    export const LAYOUT_COMBO: string;
    export const LAYOUT_VSLIDER: string;
    export const LAYOUT_HSLIDER: string;
    export const LAYOUT_CHECKBOXLIST: string;
    export interface IMenuLayoutComponentState {
    }
    export default class MenuLayoutComponent extends React.Component<IMenuLayoutComponentProps, IMenuLayoutComponentState> {
        constructor(props: IMenuLayoutComponentProps);
        render(): JSX.Element;
    }
}
declare module "weave/tool/AttributeMenuTool" {
    import * as React from "react";
    import * as weavejs from "weavejs";
    import IColumnWrapper = weavejs.api.data.IColumnWrapper;
    import LinkableHashMap = weavejs.core.LinkableHashMap;
    import LinkableString = weavejs.core.LinkableString;
    import LinkableBoolean = weavejs.core.LinkableBoolean;
    import LinkableNumber = weavejs.core.LinkableNumber;
    import LinkableVariable = weavejs.core.LinkableVariable;
    import LinkableWatcher = weavejs.core.LinkableWatcher;
    import ILinkableHashMap = weavejs.api.core.ILinkableHashMap;
    import IAttributeColumn = weavejs.api.data.IAttributeColumn;
    import IVisTool from "weave/api/ui/IVisTool";
    import { IVisToolProps } from "weave/api/ui/IVisTool";
    import { IVisToolState } from "weave/api/ui/IVisTool";
    export interface IAttributeMenuToolState extends IVisToolState {
        isPlaying: boolean;
    }
    export default class AttributeMenuTool extends React.Component<IVisToolProps, IAttributeMenuToolState> implements IVisTool {
        constructor(props: IVisToolProps);
        panelTitle: LinkableString;
        choices: LinkableHashMap;
        layoutMode: LinkableString;
        selectedAttribute: LinkableVariable;
        targetToolPath: LinkableVariable;
        targetAttribute: LinkableString;
        playEnabled: LinkableBoolean;
        playbackIntervalSeconds: LinkableNumber;
        toolWatcher: LinkableWatcher;
        altText: LinkableString;
        verifyLayoutMode(value: string): boolean;
        setToolWatcher: () => void;
        readonly title: string;
        readonly selectableAttributes: Map<string, ILinkableHashMap | IColumnWrapper>;
        readonly options: {
            label: string;
            value: IAttributeColumn;
        }[];
        private playTimeoutHandle;
        private playStep;
        componentDidUpdate(prevProps: IVisToolProps, prevState: IAttributeMenuToolState): void;
        private readonly selectedAttributes;
        getTargetAttribute(): IColumnWrapper | ILinkableHashMap;
        onSelectedAttribute: () => void;
        handleSelection: (selectedValue: IColumnWrapper | IColumnWrapper[]) => void;
        renderEditor: (pushCrumb?: (title: string, renderFn: () => JSX.Element, stateObject: any) => void) => JSX.Element;
        togglePlay: () => void;
        render(): JSX.Element;
    }
}
declare module "weave/editor/AbstractFilterEditor" {
    import * as React from "react";
    import * as weavejs from "weavejs";
    import LinkableBoolean = weavejs.core.LinkableBoolean;
    import ColumnDataFilter = weavejs.data.key.ColumnDataFilter;
    import DynamicColumn = weavejs.data.column.DynamicColumn;
    import ILinkableObjectWithNewProperties = weavejs.api.core.ILinkableObjectWithNewProperties;
    import IColumnStatistics = weavejs.api.data.IColumnStatistics;
    export type FilterOption = {
        value: string | number;
        label: string;
    };
    export interface FilterEditorProps {
        filter: ColumnDataFilter;
    }
    export interface FilterEditorState {
    }
    export default class AbstractFilterEditor extends React.Component<FilterEditorProps, FilterEditorState> implements ILinkableObjectWithNewProperties {
        showPlayButton: LinkableBoolean;
        showToggle: LinkableBoolean;
        showToggleLabel: LinkableBoolean;
        private filterWatcher;
        private statsWatcher;
        protected options: FilterOption[];
        constructor(props: FilterEditorProps);
        componentWillReceiveProps(props: FilterEditorProps): void;
        filter: ColumnDataFilter;
        readonly column: DynamicColumn;
        readonly stats: IColumnStatistics;
        handleFilter(): void;
        handleColumn(): void;
        componentDidMount(): void;
        onChange(selectedValues: Object): void;
        readonly deprecatedStateMapping: Object;
    }
}
declare module "weave/editor/DiscreteValuesDataFilterEditor" {
    import * as weavejs from "weavejs";
    import LinkableString = weavejs.core.LinkableString;
    import LinkableVariable = weavejs.core.LinkableVariable;
    import AbstractFilterEditor from "weave/editor/AbstractFilterEditor";
    import { FilterEditorProps } from "weave/editor/AbstractFilterEditor";
    import { FilterOption } from "weave/editor/AbstractFilterEditor";
    export default class DiscreteValuesDataFilterEditor extends AbstractFilterEditor {
        static readonly OPTIONS: string[];
        layoutMode: LinkableString;
        values: LinkableVariable;
        constructor(props: FilterEditorProps);
        verifyLayoutMode(value: string): boolean;
        readonly deprecatedStateMapping: Object;
        getChoices(): FilterOption[];
        render(): JSX.Element;
    }
}
declare module "weave/editor/NumericRangeDataFilterEditor" {
    import * as weavejs from "weavejs";
    import LinkableBoolean = weavejs.core.LinkableBoolean;
    import AbstractFilterEditor from "weave/editor/AbstractFilterEditor";
    import { FilterEditorProps } from "weave/editor/AbstractFilterEditor";
    export default class NumericRangeDataFilterEditor extends AbstractFilterEditor {
        static readonly OPTIONS: string[];
        forceDiscreteValues: LinkableBoolean;
        constructor(props: FilterEditorProps);
        readonly deprecatedStateMapping: Object;
        onChange(selectedValues: number[]): void;
        render(): JSX.Element;
    }
}
declare module "weave/tool/DataFilterTool" {
    import * as React from "react";
    import * as weavejs from "weavejs";
    import LinkableString = weavejs.core.LinkableString;
    import LinkableDynamicObject = weavejs.core.LinkableDynamicObject;
    import ILinkableObjectWithNewProperties = weavejs.api.core.ILinkableObjectWithNewProperties;
    import LinkableHashMap = weavejs.core.LinkableHashMap;
    import IColumnWrapper = weavejs.api.data.IColumnWrapper;
    import IVisTool, { IVisToolProps, IVisToolState } from "weave/api/ui/IVisTool";
    export default class DataFilterTool extends React.Component<IVisToolProps, IVisToolState> implements IVisTool, ILinkableObjectWithNewProperties {
        filter: LinkableDynamicObject;
        filterEditor: LinkableDynamicObject;
        altText: LinkableString;
        constructor(props: IVisToolProps);
        private initLater();
        private _editorDiff;
        private handleFilterWatcher();
        private handleEditor();
        private setEditorType(editorType, editorDiff);
        readonly deprecatedStateMapping: {
            "editor": LinkableDynamicObject;
            "filter": LinkableDynamicObject;
        };
        private getFilter();
        private getFilterEditor();
        private getFilterColumn();
        handleMissingSessionStateProperty(newState: any, property: String): void;
        readonly title: string;
        readonly selectableAttributes: Map<string, LinkableHashMap | IColumnWrapper>;
        renderEditor: (pushCrumb?: (title: string, renderFn: () => JSX.Element, stateObject: any) => void) => JSX.Element;
        render(): JSX.Element;
    }
    export interface IDataFilterEditorState {
    }
    export interface IDataFilterEditorProps {
        filterEditor: LinkableDynamicObject;
        selectableAttributes: Map<string, (IColumnWrapper | LinkableHashMap)>;
        pushCrumb?: (title: string, renderFn: () => JSX.Element, stateObject: any) => void;
    }
}
declare module "weave/tool/SessionStateMenuTool" {
    import * as weavejs from "weavejs";
    import LinkableHashMap = weavejs.core.LinkableHashMap;
    import LinkableVariable = weavejs.core.LinkableVariable;
    import LinkableDynamicObject = weavejs.core.LinkableDynamicObject;
    import LinkableString = weavejs.core.LinkableString;
    import LinkableBoolean = weavejs.core.LinkableBoolean;
    import AbstractVisTool from "weave/tool/AbstractVisTool";
    import { IVisToolProps, IVisToolState } from "weave/api/ui/IVisTool";
    export default class SessionStateMenuTool extends AbstractVisTool<IVisToolProps, IVisToolState> {
        selectedChoice: LinkableString;
        layoutMode: LinkableString;
        autoRecord: LinkableBoolean;
        choices: LinkableHashMap;
        targets: LinkableHashMap;
        panelTitle: LinkableString;
        pendingApply: Boolean;
        verifyLayoutMode(value: string): boolean;
        readonly title: string;
        constructor(props: IVisToolProps);
        setTargetStates(states: any): void;
        getTargetStates: () => {
            [key: string]: LinkableDynamicObject[];
        };
        handleChoiceSelection: (selectedValue: any) => void;
        handleChoices: () => void;
        handleAutoRecord: () => void;
        recordSelectedChoice: () => void;
        readonly options: {
            label: string;
            value: LinkableVariable;
        }[];
        renderEditor: () => JSX.Element;
        render(): JSX.Element;
    }
}
declare module "weave/menu/ControllersMenu" {
    import * as weavejs from "weavejs";
    import MenuBarItemProps = weavejs.ui.menu.MenuBarItemProps;
    import MenuItemProps = weavejs.ui.menu.MenuItemProps;
    import PopupWindow = weavejs.ui.PopupWindow;
    import IWeaveMenus from "weave/menu/IWeaveMenus";
    export default class ControllersMenu implements MenuBarItemProps {
        constructor(owner: IWeaveMenus);
        owner: IWeaveMenus;
        label: string;
        openColorController: () => PopupWindow;
        openMouseOverController: () => PopupWindow;
        readonly menu: MenuItemProps[];
        getCreateObjectItems(): {
            label: string;
            click: any;
        }[];
        static isBeta(impl: Class): boolean;
    }
}
declare module "weave/menu/ExternalToolMenu" {
    import * as weavejs from "weavejs";
    import IWeaveMenus from "weave/menu/IWeaveMenus";
    import MenuItemProps = weavejs.ui.menu.MenuItemProps;
    import MenuBarItemProps = weavejs.ui.menu.MenuBarItemProps;
    import { AbstractVisToolImpl } from "weave/tool/AbstractVisTool";
    export default class ExternalToolMenu implements MenuBarItemProps {
        tools: AbstractVisToolImpl[];
        owner: IWeaveMenus;
        label: string;
        constructor(owner: IWeaveMenus, tools: AbstractVisToolImpl[]);
        readonly menu: MenuItemProps[];
    }
}
declare module "weave/menu/WeaveMenus" {
    import * as React from "react";
    import * as weavejs from "weavejs";
    import { Weave } from "weavejs";
    import MenuBarItemProps = weavejs.ui.menu.MenuBarItemProps;
    import { IWeaveMenus } from "weave/menu/IWeaveMenus";
    import ServiceLogin from "weave/admin/ServiceLogin";
    import SystemMenu from "weave/menu/SystemMenu";
    import FileMenu from "weave/menu/FileMenu";
    import ChartsMenu from "weave/menu/ChartsMenu";
    import DataMenu from "weave/menu/DataMenu";
    import ControllersMenu from "weave/menu/ControllersMenu";
    import ExternalToolMenu from "weave/menu/ExternalToolMenu";
    import { AbstractVisToolImpl } from "weave/tool/AbstractVisTool";
    export type CreateObjectFunction = (type: Class) => void;
    export default class WeaveMenus implements IWeaveMenus {
        context: React.ReactInstance;
        weave: Weave;
        createObject: CreateObjectFunction;
        onFileLoaded: () => void;
        openDataManager: () => void;
        enableDataManagerItem: () => boolean;
        showFileMenu: boolean;
        login: ServiceLogin;
        systemMenu: SystemMenu;
        fileMenu: FileMenu;
        chartsMenu: ChartsMenu;
        dataMenu: DataMenu;
        controllersMenu: ControllersMenu;
        externalToolMenu: ExternalToolMenu;
        constructor(context: React.ReactInstance, weave: Weave, createObject: CreateObjectFunction, onFileLoaded: () => void, openDataManager: () => void, enableDataManagerItem: () => boolean, externalTools?: AbstractVisToolImpl[]);
        getMenuList(): MenuBarItemProps[];
    }
}
declare module "weave/modules/classnames" {
    var _default: ClassNamesFn;
    export default _default;
}
declare module "weave/modules/react-codemirror" {
    var _default: ReactCodeMirrorNamespace.ReactCodeMirrorClass;
    export default _default;
}
declare module "weave/editor/JSONEditor" {
    import * as React from "react";
    import * as weavejs from "weavejs";
    import SmartComponent = weavejs.ui.SmartComponent;
    export interface JSONEditorProps {
        style?: React.CSSProperties;
    }
    export interface JSONEditorState {
        value?: any;
        error?: Error;
    }
    export default class JSONEditor extends SmartComponent<JSONEditorProps, JSONEditorState> {
        json: string;
        parsed: any;
        constructor(props: JSONEditorProps);
        onFocusChange: (focused: boolean) => void;
        handleJSON: (json: string) => void;
        render(): JSX.Element;
    }
}
declare module "weave/editor/SessionStateEditor" {
    import * as React from "react";
    import * as weavejs from "weavejs";
    import ILinkableObject = weavejs.api.core.ILinkableObject;
    import WeaveTreeItem = weavejs.util.WeaveTreeItem;
    import SmartComponent = weavejs.ui.SmartComponent;
    import MenuItemProps = weavejs.ui.menu.MenuItemProps;
    import IGetMenuItems = weavejs.ui.menu.IGetMenuItems;
    import ControlPanel from "weave/editor/ControlPanel";
    export interface ISessionStateEditorProps extends React.Props<SessionStateEditor> {
        rootObject: ILinkableObject;
        initialSelectedObject?: ILinkableObject;
    }
    export interface ISessionStateEditorState {
        selectedNode: WeaveTreeItem;
    }
    export default class SessionStateEditor extends SmartComponent<ISessionStateEditorProps, ISessionStateEditorState> implements IGetMenuItems {
        static getTreeNode(object: ILinkableObject): WeaveTreeItem;
        static openInstance(context: React.ReactInstance, selectedObject: ILinkableObject): ControlPanel;
        constructor(props: ISessionStateEditorProps);
        readonly selectedObject: ILinkableObject;
        readonly selectedTreeNode: WeaveTreeItem;
        componentDidMount(): void;
        componentWillReceiveProps(props: ISessionStateEditorProps): void;
        private onSelect;
        private onDoubleClick;
        getMenuItems(): MenuItemProps[];
        /**
         * Displays a modal dialog and requests user input with OK/Cancel buttons
         * @param title dialog window title text
         * @param message dialog content text
         * @param defaultInput default value for text input box
         * @param inputValidator checked every time user modifies input and boolean result determines if the OK button should be enabled
         * @param inputHandler Called when user clicks OK button
         */
        private showInputDialog(title, message, defaultInput?, inputValidator?, inputHandler?);
        private newObject(parent, classDef);
        private canDeleteSelectedItem;
        private deleteSelectedItem;
        reportError(message: string): void;
        private treeDescriptor;
        render(): JSX.Element;
    }
}
declare module "weave/editor/WeaveToolEditor" {
    import * as React from "react";
    import { IVisTool } from "weave/api/ui/IVisTool";
    export interface WeaveToolEditorProps extends React.HTMLProps<WeaveToolEditor> {
        tool: IVisTool;
        onCloseHandler: (editor: WeaveToolEditor) => void;
    }
    export interface WeaveToolEditorState {
        activeCrumb: string;
    }
    export default class WeaveToolEditor extends React.Component<WeaveToolEditorProps, WeaveToolEditorState> {
        private toolWatcher;
        tool: IVisTool;
        private displayName;
        private mapping_crumb_renderFn;
        private mapping_crumb_children_state;
        private crumbOrder;
        constructor(props: WeaveToolEditorProps);
        openSessionStateEditor: () => void;
        pushCrumb: (title: string, renderFn: () => JSX.Element, stateObject?: any) => void;
        reset: () => void;
        componentWillReceiveProps(nextProps: WeaveToolEditorProps): void;
        private handleNewTool(tool);
        private isCrumbClicked;
        crumbClick: (crumbTitle: string, index: number) => void;
        stepBackInCrumbView: () => void;
        componentWillUpdate(): void;
        componentDidUpdate(): void;
        componentWillUnmount(): void;
        closeEditor: (event: React.MouseEvent) => void;
        private activeEditor;
        render(): JSX.Element;
    }
}
declare module "weave/layout/AbstractLayout" {
    import * as React from "react";
    import * as weavejs from "weavejs";
    import { Weave } from "weavejs";
    import SmartComponent = weavejs.ui.SmartComponent;
    import WeavePathArray = weavejs.util.WeavePathArray;
    export type LayoutPanelProps = {
        maximized?: boolean;
    };
    export type PanelRenderer = (id: WeavePathArray, panelProps?: LayoutPanelProps, panelRenderer?: PanelRenderer) => JSX.Element;
    export interface LayoutProps extends React.HTMLProps<AnyAbstractLayout> {
        panelRenderer: PanelRenderer;
    }
    export type LayoutDragData = {
        panelDragged: WeavePathArray;
        layout: WeavePathArray;
    };
    export type AnyAbstractLayout = AbstractLayout<LayoutProps, {}>;
    export abstract class AbstractLayout<P extends LayoutProps, S> extends SmartComponent<P, S> {
        title: string;
        abstract addPanel(id: WeavePathArray): void;
        abstract removePanel(id: WeavePathArray): void;
        abstract maximizePanel(id: WeavePathArray, maximize: boolean): void;
        abstract replacePanel(id: WeavePathArray, newId: WeavePathArray): void;
        abstract getPanelIds(): WeavePathArray[];
    }
    export default AbstractLayout;
    export class PanelDragEvent {
        private static DRAG_DATA_TYPE;
        static hasPanelId(event: React.DragEvent): boolean;
        static setPanelId(event: React.DragEvent, panelId: WeavePathArray, instance?: React.ReactInstance): void;
        static getPanelId(event: React.DragEvent): WeavePathArray;
        static getLayout(event: React.DragEvent, weave: Weave): AnyAbstractLayout;
    }
}
declare module "weave/layout/WeaveTool" {
    import * as React from "react";
    import * as weavejs from "weavejs";
    import { Weave } from "weavejs";
    import CSSProperties = React.CSSProperties;
    import WeaveComponentRenderer = weavejs.ui.WeaveComponentRenderer;
    import SmartComponent = weavejs.ui.SmartComponent;
    export interface IWeaveToolProps extends React.Props<WeaveTool> {
        weave: Weave;
        path: string[];
        props?: any;
        maximized?: boolean;
        style?: CSSProperties;
        onGearClick?: (tool: WeaveTool) => void;
        onPopoutClick?: (tool: WeaveTool) => void;
        onPopinClick?: (tool: WeaveTool) => void;
    }
    export interface IWeaveToolState {
        title?: string;
        showCaption?: boolean;
        caption?: string;
        hovered?: boolean;
        dragging?: boolean;
        highlightTitle?: boolean;
    }
    export default class WeaveTool extends SmartComponent<IWeaveToolProps, IWeaveToolState> {
        private watcher;
        private closeIcon;
        private gearIcon;
        private firstIcon;
        private lastIcon;
        constructor(props: IWeaveToolProps);
        handleTool: (wcr: WeaveComponentRenderer) => void;
        componentDidMount(): void;
        componentWillUnmount(): void;
        componentDidUpdate(): void;
        update(): void;
        handleKeyDown: (event: React.KeyboardEvent) => void;
        updateTitle(): void;
        updateCaption(): void;
        onGearClick: (event: React.MouseEvent) => void;
        handleGear: () => void;
        onMaximizeClick: (event: React.MouseEvent) => void;
        handleMaximize: () => void;
        onPopoutPopinClick: (event: React.MouseEvent) => void;
        handlePopoutPopin: () => void;
        onCloseClick: (event: React.MouseEvent) => void;
        handleClose: () => void;
        renderTitleBar(): JSX.Element;
        renderCaption(): JSX.Element;
        render(): JSX.Element;
    }
}
declare module "weave/layout/TabLayout" {
    import * as React from "react";
    import * as weavejs from "weavejs";
    import MenuItemProps = weavejs.ui.menu.MenuItemProps;
    import WeavePathArray = weavejs.util.WeavePathArray;
    import LinkablePlaceholder = weavejs.core.LinkablePlaceholder;
    import ILinkableVariable = weavejs.api.core.ILinkableVariable;
    import { LayoutProps, AbstractLayout } from "weave/layout/AbstractLayout";
    export interface TabState {
        id: WeavePathArray;
        label: string;
    }
    export interface TabLayoutProps extends LayoutProps {
        leadingTabs?: {
            label: React.ReactChild;
            content: JSX.Element;
        }[];
        onAdd: MenuItemProps | React.MouseEventHandler;
        onRemove: (panelId: WeavePathArray) => void;
        onTabClick: (panelId: WeavePathArray, event?: React.MouseEvent) => void;
        onTabDoubleClick: (panelId: WeavePathArray, event?: React.MouseEvent) => void;
    }
    export interface TabLayoutState {
        tabs: TabState[];
        activeTabIndex: number;
        title: string;
    }
    export default class TabLayout extends AbstractLayout<TabLayoutProps, {}> implements ILinkableVariable {
        static readonly DEFAULT_TAB_PREFIX: string;
        private linkableState;
        private resetTimer;
        constructor(props: TabLayoutProps);
        /**
         * This static function takes a layout session state and combines it
         * with another layout session state
         * @param into the layout to be merged into
         * @param from the layout to be merged from
         */
        static mergeLayout(into: TabLayout | LinkablePlaceholder<TabLayout>, from: TabLayout | LinkablePlaceholder<TabLayout>): void;
        getSessionState(): TabLayoutState;
        setSessionState(state: TabLayoutState): void;
        activeTabIndex: number;
        maximizePanel(): void;
        readonly title: string;
        readonly leadingTabsLength: number;
        readonly activePanelId: string[];
        onDragOverTab: (panel: TabState) => void;
        onDrop: (event: React.DragEvent) => void;
        onDragLeaveTab: () => void;
        getTabLabel(id: WeavePathArray): string;
        setTabLabel(id: WeavePathArray, newLabel: string): void;
        private switchPanelToActive;
        private getPanelIndex(id);
        getPanelIds(): WeavePathArray[];
        addPanel(id: WeavePathArray): void;
        private generateNextTabLabel();
        removePanel(id: WeavePathArray): void;
        replacePanel(id: WeavePathArray, newId: WeavePathArray): void;
        render(): JSX.Element;
    }
}
declare module "weave/layout/FlexibleLayout" {
    import * as React from "react";
    import * as weavejs from "weavejs";
    import WeavePathArray = weavejs.util.WeavePathArray;
    import Layout = weavejs.ui.layout.Layout;
    import LayoutState = weavejs.ui.layout.LayoutState;
    import ILinkableVariable = weavejs.api.core.ILinkableVariable;
    import { AbstractLayout, LayoutProps, AnyAbstractLayout } from "weave/layout/AbstractLayout";
    export enum DropZone {
        NONE = 0,
        LEFT = 1,
        TOP = 2,
        RIGHT = 3,
        BOTTOM = 4,
        CENTER = 5,
    }
    export type FlexibleLayoutState = {
        title?: string;
    } & LayoutState;
    export default class FlexibleLayout extends AbstractLayout<LayoutProps, {}> implements ILinkableVariable {
        private linkableState;
        private nextState;
        private rootLayout;
        private layoutRect;
        private overlay;
        private draggedId;
        private dragOverId;
        private dropZone;
        private prevClientWidth;
        private prevClientHeight;
        private outerZoneThickness;
        constructor(props: LayoutProps);
        getSessionState(): FlexibleLayoutState;
        setSessionState: (state: FlexibleLayoutState) => void;
        readonly title: string;
        componentDidMount(): void;
        componentWillUnmount(): void;
        componentDidUpdate(): void;
        addPanel(id: WeavePathArray): void;
        removePanel(id: WeavePathArray): void;
        replacePanel(id: WeavePathArray, newId: WeavePathArray): void;
        maximizePanel(id: WeavePathArray, maximized: boolean): void;
        frameHandler(): void;
        onDragStart(draggedId: WeavePathArray, event: React.DragEvent): void;
        hideOverlay: () => void;
        onDragOver(dragOverId: WeavePathArray, event: React.DragEvent): void;
        getDropZone(dragOverId: WeavePathArray): [DropZone, WeavePathArray];
        simplifyState(state: FlexibleLayoutState, topLevel?: boolean): FlexibleLayoutState;
        onDrop(dragOverId: WeavePathArray, event: React.DragEvent): void;
        onDragLeave: (event: React.DragEvent) => void;
        onDragEnd: (event: React.DragEvent) => void;
        onMouseUp: (event: MouseEvent) => void;
        handlePanelDrop(sourceLayout: AnyAbstractLayout, srcId: WeavePathArray, destId: WeavePathArray, dropZone: DropZone): void;
        getLayoutPosition(layoutOrId: Layout | WeavePathArray): ClientRect;
        repositionPanels: (layout?: Layout) => void;
        static findStateNode(state: LayoutState, id: WeavePathArray): LayoutState;
        private static getLeafNodes(state, output?);
        getPanelIds(): WeavePathArray[];
        private static sortLeafNodes(node1, node2);
        render(): JSX.Element;
    }
}
declare module "weave/layout/WindowLayout" {
    import * as React from "react";
    import * as weavejs from "weavejs";
    import DraggableDivState = weavejs.ui.DraggableDivState;
    import WeavePathArray = weavejs.util.WeavePathArray;
    import ILinkableVariable = weavejs.api.core.ILinkableVariable;
    import { AbstractLayout, LayoutProps } from "weave/layout/AbstractLayout";
    export interface PanelState {
        id?: WeavePathArray;
        position?: DraggableDivState;
        maximized?: boolean;
    }
    export interface WindowLayoutState {
        panels: PanelState[];
        title: string;
    }
    export default class WindowLayout extends AbstractLayout<LayoutProps, {}> implements ILinkableVariable {
        private linkableState;
        private overlay;
        constructor(props: LayoutProps);
        setSessionState(state: WindowLayoutState): void;
        getSessionState(): WindowLayoutState;
        readonly title: string;
        componentDidMount(): void;
        componentWillUnmount(): void;
        bringPanelForward(id: WeavePathArray): void;
        onReposition(id: WeavePathArray, position: DraggableDivState): void;
        addPanel(id: WeavePathArray): void;
        replacePanel(id: WeavePathArray, newId: WeavePathArray): void;
        static generatePosition(): DraggableDivState;
        static fudgePercent(n: number, delta: number): string;
        removePanel(id: WeavePathArray): void;
        maximizePanel(id: WeavePathArray, maximized: boolean): void;
        getPanelIds(): WeavePathArray[];
        updatePanelState(id: WeavePathArray, diff: PanelState): void;
        onDragStart(panelDragged: WeavePathArray, event: React.DragEvent): void;
        onDrag: (panelDragged: string[], event: React.DragEvent) => void;
        onDrop: (event: React.DragEvent) => void;
        onDragLeave: (event: React.DragEvent) => void;
        onDragEnd: (event: React.DragEvent) => void;
        onMouseUp: (event: MouseEvent) => void;
        onDragOver: (event: React.DragEvent) => void;
        hideOverlay: () => void;
        render(): JSX.Element;
    }
}
declare module "weave/ui/WeaveProgressBar" {
    import * as React from "react";
    import * as weavejs from "weavejs";
    import SmartComponent = weavejs.ui.SmartComponent;
    export interface WeaveProgressBarProps extends React.HTMLProps<WeaveProgressBar> {
    }
    export interface WeaveProgressBarState {
        visible: boolean;
    }
    export default class WeaveProgressBar extends SmartComponent<WeaveProgressBarProps, WeaveProgressBarState> {
        constructor(props: WeaveProgressBarProps);
        private timeBecameBusy;
        private autoVisibleDelay;
        private autoHideDelay;
        /**
         * This will automatically toggle visibility based on the target's busy status.
         */
        private toggleVisible();
        render(): JSX.Element;
    }
}
declare module "weave/editor/manager/DataSourceManager" {
    import * as React from "react";
    import * as weavejs from "weavejs";
    import { Weave } from "weavejs";
    import IDataSource = weavejs.api.data.IDataSource;
    import FileMenu from "weave/menu/FileMenu";
    export interface IDataSourceManagerProps {
        weave: Weave;
        fileMenu?: FileMenu;
    }
    export interface IDataSourceManagerState {
        selected?: IDataSource;
        rejected?: boolean;
    }
    export default class DataSourceManager extends React.Component<IDataSourceManagerProps, IDataSourceManagerState> {
        private selectedIndex;
        constructor(props: IDataSourceManagerProps);
        componentDidMount(): void;
        componentWillUnmount(): void;
        updateDataSources(): void;
        setSelectedDataSource: (dataSource: IDataSource) => void;
        getSelectedDataSource(): IDataSource;
        refreshDataSource(dataSource: IDataSource): void;
        removeDataSource(dataSource: IDataSource): void;
        handleDataFileDrop: (file: File) => void;
        render(): JSX.Element;
    }
}
declare module "weave/editor/SessionHistorySlider" {
    import * as React from "react";
    import * as weavejs from "weavejs";
    import SessionStateLog = weavejs.core.SessionStateLog;
    export interface SessionHistorySliderProps extends React.Props<SessionHistorySlider> {
        showSlider: boolean;
        stateLog: SessionStateLog;
    }
    export interface SessionHistorySliderState {
        max?: number;
        position?: number;
    }
    export default class SessionHistorySlider extends React.Component<SessionHistorySliderProps, SessionHistorySliderState> {
        private _stateLogWatcher;
        constructor(props: SessionHistorySliderProps);
        componentWillReceiveProps(props: SessionHistorySliderProps): void;
        private readonly _stateLog;
        private handleStateLogChange();
        handleKeyStroke: (event: KeyboardEvent) => void;
        componentDidMount(): void;
        componentWillUnmount(): void;
        play: () => void;
        getPlayLabel: (a: number, b: string) => string;
        handleSlider(selectedValue: string[]): void;
        private _playSpeed;
        render(): JSX.Element;
    }
}
declare module "weave/menu/WeaveMenuBar" {
    import * as React from "react";
    import { Weave } from "weavejs";
    import WeaveMenus from "weave/menu/WeaveMenus";
    export interface WeaveMenuBarProps extends React.HTMLProps<WeaveMenuBar> {
        style: React.CSSProperties;
        menus: WeaveMenus;
        weave: Weave;
    }
    export interface WeaveMenuBarState {
    }
    export default class WeaveMenuBar extends React.Component<WeaveMenuBarProps, WeaveMenuBarState> {
        constructor(props: WeaveMenuBarProps);
        render(): JSX.Element;
    }
}
declare module "weave/modules/NotifcationSystem" {
    import * as ns from "react-notification-system";
    var _default: typeof ns.System;
    export default _default;
}
declare module "weave/app/WeaveApp" {
    import * as React from "react";
    import * as weavejs from "weavejs";
    import { Weave } from "weavejs";
    import WeavePathArray = weavejs.util.WeavePathArray;
    import LinkableWatcher = weavejs.core.LinkableWatcher;
    import LinkableBoolean = weavejs.core.LinkableBoolean;
    import IColumnReference = weavejs.api.data.IColumnReference;
    import IWeaveTreeNode = weavejs.api.data.IWeaveTreeNode;
    import WeaveMenus from "weave/menu/WeaveMenus";
    import WeaveToolEditor from "weave/editor/WeaveToolEditor";
    import WeaveTool from "weave/layout/WeaveTool";
    import TabLayout from "weave/layout/TabLayout";
    import { PanelRenderer, AbstractLayout } from "weave/layout/AbstractLayout";
    import { AbstractVisToolImpl } from "weave/tool/AbstractVisTool";
    export interface WeaveAppProps extends React.HTMLProps<WeaveApp> {
        rootApp?: WeaveApp;
        weave: Weave;
        renderPath?: WeavePathArray;
        readUrlParams?: boolean;
        showFileDialog?: boolean;
        forceMenuBar?: boolean;
        initializeTabs?: boolean;
        enableTour?: boolean;
        externalTools?: AbstractVisToolImpl[];
        onClose?: () => void;
    }
    export interface WeaveAppState {
        toolPathToEdit?: WeavePathArray;
        enableTour?: boolean;
    }
    export default class WeaveApp extends React.Component<WeaveAppProps, WeaveAppState> {
        enableMenuBarWatcher: LinkableWatcher;
        menus: WeaveMenus;
        _popout_windows: Set<Window>;
        readonly popout_windows: Set<Window>;
        static defaultProps: WeaveAppProps;
        constructor(props: WeaveAppProps);
        componentWillReceiveProps(props: WeaveAppProps): void;
        getRenderPath(): WeavePathArray;
        getRootLayoutPath(): WeavePathArray;
        getDefaultLayoutPath(): WeavePathArray;
        getRenderedComponent(): React.Component<any, any>;
        urlParams: {
            file: string;
            editable: boolean;
            layout: string;
        };
        readonly openedFromAdminConsole: boolean;
        componentDidMount(): void;
        handleSideBarClose: (editor: WeaveToolEditor) => void;
        /**
         * This function will get called when the main WeaveApp gets unloaded
         */
        handleUnload: () => void;
        /**
         * This function will get called before the window unloads
         * and will provide a dialog giving the user a chance to cancel the unloading
         * @param event beforeunload event
         * @returns {string} the confirmation message
         */
        handleBeforeUnload: (event: BeforeUnloadEvent) => string;
        handleGearClick: (tool: WeaveTool) => void;
        restoreTabs: (tabLayoutPath: string[]) => void;
        handlePopoutClick: (layoutPath: string[], oldTabLayoutPath: string[]) => void;
        renderTab: (path: string[], panelProps: {
            maximized?: boolean;
        }, panelRenderer?: PanelRenderer) => JSX.Element;
        renderTool: (path: string[], panelProps: {
            maximized?: boolean;
        }, panelRenderer?: PanelRenderer) => JSX.Element;
        private toolSet;
        handleWeaveTool: (tool: WeaveTool) => void;
        enableDataManagerItem: () => boolean;
        openDataManager: () => void;
        createObject: (type: Class) => void;
        prioritizeNumericColumns(columnRefs: Array<IWeaveTreeNode & IColumnReference>): IColumnReference[];
        readonly tabLayout: TabLayout;
        private getTabLayouts();
        private getNonTabLayouts();
        private onSessionLoaded;
        private initializeTabs;
        addNewTab: (type?: typeof AbstractLayout) => void;
        removeExistingTab: (id: string[]) => void;
        onTabClick: (panelPath: string[], event: React.MouseEvent) => void;
        componentWillUpdate(nextProps: WeaveAppProps, nextState: WeaveAppState): void;
        componentWillUnmount(): void;
        readonly enableMenuBar: LinkableBoolean;
        render(): JSX.Element;
    }
}
declare module "weave/dialog/GetStartedComponent" {
    import * as React from "react";
    import { LandingPageView } from "weave/dialog/LandingPage";
    export interface GetStartedComponentProps extends React.HTMLProps<GetStartedComponent> {
        onViewSelect: (view: LandingPageView) => void;
        showInteractiveTourList?: boolean;
    }
    export interface GetStartedComponentState {
        showInteractiveTourList?: boolean;
    }
    export default class GetStartedComponent extends React.Component<GetStartedComponentProps, GetStartedComponentState> {
        constructor(props: GetStartedComponentProps);
        componentWillReceiveProps(nextProps: GetStartedComponentProps): void;
        enableInteractiveTourList: () => void;
        private items;
        interactiveListItemClick: (itemName: string) => void;
        render(): JSX.Element;
    }
}
declare module "weave/dialog/LandingPage" {
    import * as React from "react";
    import { Weave } from "weavejs";
    import WeaveApp from "weave/app/WeaveApp";
    export type LandingPageView = "splash" | "default" | "file" | "tour list" | "tour";
    export interface LandingPageProps {
        initialView: LandingPageView;
        weave: Weave;
        weaveAppRef: (weaveApp: WeaveApp) => void;
    }
    export interface LandingPageState {
        view: LandingPageView;
    }
    export default class LandingPage extends React.Component<LandingPageProps, LandingPageState> {
        urlParams: any;
        constructor(props: LandingPageProps);
        loadGetStartedComponentWithTourList: () => void;
        render(): JSX.Element;
    }
}
declare module "index" {
}
declare module "weave/api/ui/IPlotTask" {
    import * as weavejs from "weavejs";
    import Bounds2D = weavejs.geom.Bounds2D;
    import IQualifiedKey = weavejs.api.data.IQualifiedKey;
    import Graphics = PIXI.Graphics;
    /**
     * An IPlotTask provides information for an IPlotter for rendering a plot asynchronously.
     */
    export class IPlotTask {
        /**
         * This is the off-screen buffer, which may change
         */
        buffer: Graphics;
        /**
         * This specifies the range of data to be rendered
         */
        dataBounds: Bounds2D;
        /**
         * This specifies the pixel range where the graphics should be rendered
         */
        screenBounds: Bounds2D;
        /**
         * These are the IQualifiedKey objects identifying which records should be rendered
         */
        recordKeys: IQualifiedKey[];
        /**
         * This counter is incremented after each iteration.  When the task parameters change, this counter is reset to zero.
         */
        iteration: number;
        /**
         * This is the time at which the current iteration should be stopped, if possible.  This value can be compared to getTimer().
         * Ignore this value if an iteration cannot be ended prematurely.
         */
        iterationStopTime: number;
        /**
         * This object can be used to optionally store additional state variables for resuming an asynchronous task where it previously left off.
         * Setting this will not reset the iteration counter.
         */
        asyncState: any;
    }
}
declare module "weave/api/ui/IPlotter" {
    import * as weavejs from "weavejs";
    import ICallbackCollection = weavejs.api.core.ICallbackCollection;
    import ILinkableObject = weavejs.api.core.ILinkableObject;
    import IFilteredKeySet = weavejs.api.data.IFilteredKeySet;
    import IQualifiedKey = weavejs.api.data.IQualifiedKey;
    import Bounds2D = weavejs.geom.Bounds2D;
    import { IPlotTask } from "weave/api/ui/IPlotTask";
    export default class IPlotter extends ILinkableObject {
        /**
         * This is an interface for adding callbacks that get called when any spatial properties of the plotter change.
         * Spatial properties are those that affect the data bounds of visual elements.  Whenever these callbacks get
         * called, data bounds values previously returned from getDataBoundsFromRecordKey() become invalid.
         */
        spatialCallbacks: ICallbackCollection;
        /**
         * This is the set of record keys relevant to this IPlotter.
         * An optional filter can be applied to filter the records before the plotter generates graphics for them.
         * @return The set of record keys that can be passed to the drawPlot() and getDataBoundsFromRecordKey() functions.
         */
        filteredKeySet: IFilteredKeySet;
        /**
         * This function provides a mapping from a record key to an Array of bounds objects, specified
         * in data coordinates, that cover the bounds associated with that record key.
         * The simplest geometric object supported is Bounds2D.  Other objects may be supported in future versions.
         * @param key The key of a data record.
         * @param output An Array which may or may not be already populated with Bounds2D objects.
         *               If there are existing Bounds2D objects in this Array, they will be used as output buffers.
         *               New Bounds2D objects will be added to the Array as needed.
         * @return An Array of geometric objects, in data coordinates, that cover the bounds associated with the record key.
         */
        getDataBoundsFromRecordKey(key: IQualifiedKey, output: Bounds2D[]): void;
        /**
         * This function will perform one iteration of an asynchronous rendering task.
         * This function will be called multiple times across several frames until its return value is 1.0.
         * This function may be defined with override by classes that extend AbstractPlotter.
         * @param task An object containing the rendering parameters.
         * @return A number between 0 and 1 indicating the progress that has been made so far in the asynchronous rendering.
         */
        drawPlotAsyncIteration(task: IPlotTask): number;
        /**
         * This function returns a Bounds2D object set to the data bounds associated with the background.
         * @return The data bounds associated with the background of the plotter.
         */
        getBackgroundDataBounds(output: Bounds2D): void;
        /**
         * This function draws the background graphics for this plotter, if there are any.
         * An example background would be the origin lines of an axis.
         * @param dataBounds The data coordinates that correspond to the given screenBounds.
         * @param screenBounds The coordinates on the given sprite that correspond to the given dataBounds.
         * @param destination The sprite to draw the graphics onto.
         */
        drawBackground(dataBounds: Bounds2D, screenBounds: Bounds2D, destination: PIXI.Graphics): void;
    }
}
declare module "weave/api/ui/IPlotterWithGeometries" {
    import * as weavejs from "weavejs";
    import IQualifiedKey = weavejs.api.data.IQualifiedKey;
    import Bounds2D = weavejs.geom.Bounds2D;
    import ISimpleGeometry = weavejs.api.data.ISimpleGeometry;
    import GeneralizedGeometry = weavejs.geom.GeneralizedGeometry;
    import IPlotter from "weave/api/ui/IPlotter";
    /**
     * This interface defines a plotter whose records are geometric objects with
     * special probing and selection. A plotter which implements this interface is
     * subject to polygon containment algorithms during probing and selection.
     */
    export interface IPlotterWithGeometries extends IPlotter {
        /**
         * This function provides a mapping from a record key to an Array of ISimpleGeometry objects
         * in data coordinates.
         *
         * @param recordKey An IQualifiedKey for which to get its geometries.
         * @param minImportance The minimum importance of the geometry objects.
         * @param bounds The visible bounds.
         * @return An Array of IGeometry objects, in data coordinates.
         */
        getGeometriesFromRecordKey(recordKey: IQualifiedKey, minImportance?: Number, bounds?: Bounds2D): (ISimpleGeometry | GeneralizedGeometry)[];
        /**
         * This function will get an array ISimpleGeometry objects.
         *
         * @return An array of ISimpleGeometry objects which can be used for spatial querying.
         */
        getBackgroundGeometries(): ISimpleGeometry[];
    }
}
declare module "weave/api/ui/ITextPlotter" {
    import IPlotter from "weave/api/ui/IPlotter";
    /**
     * A class implementing this interface is an IPlotter that renders text graphics.
     */
    export interface ITextPlotter extends IPlotter {
    }
    export class ITextPlotter {
    }
    export default ITextPlotter;
}
declare module "weave/dialog/GuidanceToolTip" {
    import * as React from "react";
    export interface GuidanceToolTipProps extends React.HTMLProps<GuidanceToolTip> {
        location: string;
        type: string;
        onClose?: Function;
    }
    export interface GuidanceToolTipState {
    }
    export default class GuidanceToolTip extends React.Component<GuidanceToolTipProps, GuidanceToolTipState> {
        static START: string;
        static NEXT: string;
        static DONE: string;
        static BOTTOM: string;
        static BOTTOM_LEFT: string;
        static BOTTOM_RIGHT: string;
        static TOP: string;
        static TOP_LEFT: string;
        static TOP_RIGHT: string;
        static LEFT: string;
        static LEFT_TOP: string;
        static LEFT_BOTTOM: string;
        static RIGHT: string;
        static RIGHT_TOP: string;
        static RIGHT_BOTTOM: string;
        constructor(props: GuidanceToolTipProps);
        componentWillReceiveProps(nextProps: GuidanceToolTipProps): void;
        closeHandler: () => void;
        render(): JSX.Element;
    }
}
declare namespace weavejs.geom.net_ivank_voronoi {
    import Point = weavejs.geom.Point;
    class VEdge {
        start: Point;
        end: Point;
        direction: Point;
        left: Point;
        right: Point;
        f: number;
        g: number;
        neighbour: VEdge;
        constructor(s: Point, a: Point, b: Point);
    }
}
declare namespace weavejs.geom.net_ivank_voronoi {
    import Point = weavejs.geom.Point;
    class VEvent {
        point: Point;
        pe: boolean;
        y: number;
        key: int;
        arch: VParabola;
        value: int;
        constructor(p: Point, pe: boolean);
        compare(other: VEvent): int;
    }
}
declare namespace weavejs.geom.net_ivank_voronoi {
    import Point = weavejs.geom.Point;
    class Voronoi {
        private places;
        private edges;
        private queue;
        private i;
        private width;
        private height;
        private root;
        private ly;
        private lasty;
        private fp;
        GetEdges(p: Array<Point>, width: int, height: int): Array<VEdge>;
        private InsertParabola(p);
        private RemoveParabola(e);
        private FinishEdge(n);
        private GetXOfEdge(par, y);
        GetParabolaByX(xx: number): VParabola;
        private GetY(p, x);
        private CheckCircle(b);
        private GetEdgeIntersection(a, b);
        private GetLeft(n);
        private GetRight(n);
        private GetLeftParent(n);
        private GetRightParent(n);
        private GetLeftChild(n);
        private GetRightChild(n);
    }
}
declare namespace weavejs.geom.net_ivank_voronoi {
    import Point = weavejs.geom.Point;
    class VParabola {
        site: Point;
        cEvent: VEvent;
        parent: VParabola;
        private _left;
        private _right;
        isLeaf: boolean;
        edge: VEdge;
        constructor(s?: Point);
        left: VParabola;
        right: VParabola;
    }
}
declare namespace weavejs.geom.net_ivank_voronoi {
    class VQueue {
        private q;
        private i;
        sortOnY(a: VEvent, b: VEvent): number;
        enqueue(p: VEvent): void;
        dequeue(): VEvent;
        remove(e: VEvent): void;
        isEmpty(): boolean;
        clear(b: boolean): void;
    }
}
declare namespace weavejs.geom.radviz {
    import CallbackCollection = weavejs.core.CallbackCollection;
    import IAttributeColumn = weavejs.api.data.IAttributeColumn;
    /**
     * An abstract class with a callback collection which implements ILayoutAlgorithm
     */
    class AbstractLayoutAlgorithm extends CallbackCollection implements ILayoutAlgorithm {
        unorderedLayout: IAttributeColumn[];
        orderedLayout: IAttributeColumn[];
        /**
         * @param keyNumberMap recordKey->column->value mapping to speed up computation
         */
        keyNumberMap: D2D_KeyColumnNumber;
        /**
         * Runs the layout algorithm and calls performLayout()
         * @param array An array of IAttributeColumns to reorder
         * @param keyNumberHashMap recordKey->column->value mapping to speed up computation
         * @return An ordered array of IAttributeColumns
         */
        run(array: IAttributeColumn[], keyNumberHashMap: D2D_KeyColumnNumber): IAttributeColumn[];
        /**
         * Classes that extend LayoutAlgorithm must implement this function
         * @param columns An array of IAttributeColumns
         */
        performLayout(columns: IAttributeColumn[]): void;
    }
}
declare namespace weavejs.geom.radviz {
    import IAttributeColumn = weavejs.api.data.IAttributeColumn;
    /**
     * An implementation of the optimal layout algorithm that generates all permutations of the original anchor layout
     * and returns the best one, if one exists
     */
    class BruteForceLayoutAlgorithm extends AbstractLayoutAlgorithm implements ILayoutAlgorithm {
        private similarityMatrix;
        private neighborhoodMatrix;
        performLayout(columns: IAttributeColumn[]): void;
        private getNthPermutation<T>(symbols, n);
        private n_to_factoradic(n, p?);
        private permutation<T>(symbols, factoradic);
        private factorial(n);
    }
}
declare namespace weavejs.geom.radviz {
    import IAttributeColumn = weavejs.api.data.IAttributeColumn;
    import DynamicColumn = weavejs.data.column.DynamicColumn;
    /**
     * An implementation of the Class Discrimination Layout dimensional ordering algorithm.
     * This algorithm groups dimensions according to the Classes found in the initial Column selected for class determination
     */
    class ClassDiscriminationLayoutAlgorithm extends AbstractLayoutAlgorithm implements ILayoutAlgorithm {
        tAndpMapping: Map<string, string[]>;
        tandpValuesMapping: Map<string, number[]>;
        ClassToColumnMap: Map<string, ClassInfoObject>;
        /** structure of ClassToColumnMap (Bins)
         for example :    type                        				Array
         ClassToColumnMap[japanese]      			   			 Object 1
                                                                 ColumnName1     values in Column1
                                                                 ColumnName2		       Column2
                                                                 ColumnName3		       Column3
         
         ClassToColumnMap[american]          					 Object 2
                                                                 ColumnName1     values in Column1
                                                                 ColumnName2		       Column2
                                                                 ColumnName3		       Column3
         */
        /** This function determines the classes and  populates the Dictionary called ClassToColumnMap which is used for the Class Discrimination Layout Algorithm
         can be used when the discriminator class is of a categorical nature  */
        fillingClassToColumnMap(selectedColumn: DynamicColumn, colObjects: IAttributeColumn[], columnNames: string[], normalizedColumns: IAttributeColumn[]): void;
        /**This function segregates the columns into classes using the statistical measure (t-statistic in this case) */
        performClassDiscrimination(columnNames: string[], ClassToColumnMap: Map<string, ClassInfoObject>, layoutMeasure: string, thresholdValue: number, columnNumPerClass: number): Map<string, string[]>;
    }
}
declare namespace weavejs.geom.radviz {
    class ClassInfoObject {
        columnMapping: Map<string, number[]>;
        tStatisticArray: number[];
        pValuesArray: number[];
    }
}
declare namespace weavejs.geom.radviz {
    import IAttributeColumn = weavejs.api.data.IAttributeColumn;
    /**
     * An implementation of the GREEDY_LAYOUT dimensional ordering algorithm.
     * This algorithm keeps adding nearest possible pairs of dimensions until all dimensions have been added.
     */
    class GreedyLayoutAlgorithm extends AbstractLayoutAlgorithm implements ILayoutAlgorithm {
        performLayout(columns: IAttributeColumn[]): void;
    }
}
declare namespace weavejs.geom.radviz {
    import ICallbackCollection = weavejs.api.core.ICallbackCollection;
    import Dictionary2D = weavejs.util.Dictionary2D;
    import IAttributeColumn = weavejs.api.data.IAttributeColumn;
    import IQualifiedKey = weavejs.api.data.IQualifiedKey;
    /**
     * An interface for dimensional layout algorithms
     */
    interface ILayoutAlgorithm extends ICallbackCollection {
        /**
         * Runs the layout algorithm and calls performLayout()
         * @param array An array of IAttributeColumns to reorder
         * @param keyNumberHashMap hash map to speed up computation
         * @return An ordered array of IAttributeColumns
         */
        run(array: IAttributeColumn[], keyNumberHashMap: D2D_KeyColumnNumber): IAttributeColumn[];
        /**
         * Performs the calculations to reorder an array
         * @param columns an array of IAttributeColumns
         */
        performLayout(columns: IAttributeColumn[]): void;
    }
    type D2D_KeyColumnNumber = Dictionary2D<IQualifiedKey, IAttributeColumn, number>;
    class ILayoutAlgorithm {
    }
}
declare namespace weavejs.geom.radviz {
    import IAttributeColumn = weavejs.api.data.IAttributeColumn;
    /**
     * An implementation of the incremental dimensional ordering algorithm.
     * This algorithm successively adds dimensions to the best position in a search to define a suitable order.
     */
    class IncrementalLayoutAlgorithm extends AbstractLayoutAlgorithm implements ILayoutAlgorithm {
        performLayout(columns: IAttributeColumn[]): void;
    }
}
declare namespace weavejs.geom.radviz {
    import IAttributeColumn = weavejs.api.data.IAttributeColumn;
    class MatrixEntry {
        similarity: number;
        dimension1: IAttributeColumn;
        dimension2: IAttributeColumn;
    }
}
declare namespace weavejs.geom.radviz {
    import IAttributeColumn = weavejs.api.data.IAttributeColumn;
    /**
     * An implementation of the NEAREST_NEIGHBOR dimensional ordering algorithm.
     * This algorithm finds nearest neighbors of a dimension successfully until all dimensions have been added.
     */
    class NearestNeighborLayoutAlgorithm extends AbstractLayoutAlgorithm implements ILayoutAlgorithm {
        private ssm;
        performLayout(columns: IAttributeColumn[]): void;
        private searchForAnchorMatch(matchTo, ignore, orderedColumns);
    }
}
declare namespace weavejs.geom.radviz {
    import IAttributeColumn = weavejs.api.data.IAttributeColumn;
    import IQualifiedKey = weavejs.api.data.IQualifiedKey;
    import LinkableHashMap = weavejs.core.LinkableHashMap;
    class RadVizUtils {
        /**
         * Reorders columns in a LinkableHashMap using the ordered layout
         * @param columns A LinkableHashMap containing IAttributeColumns
         * @param newColumnOrder An array of IAttributeColumns that are contained in columns
         */
        static reorderColumns(columns: LinkableHashMap, newColumnOrder: IAttributeColumn[]): void;
        /**
         * Checks for adjacency, assuming the columns in the array are placed in order around a circle
         * @param column1 An IAttributeColumn in the circle
         * @param column2 An IAttributeColumn in the circle
         * @param columns An array of IAttributeColumns
         * @return true if the column parameters are adjacent in the circle
         */
        static isAdjacent(column1: IAttributeColumn, column2: IAttributeColumn, columns: IAttributeColumn[]): boolean;
        /**
         * Calculates circular distance, assuming the indices in the array are placed in order around a circle
         * @param index1 An array index
         * @param index2 An array index
         * @param length the length of the array
         * @return Number of indices between two indices in an array
         */
        static getCircularDistance(index1: int, index2: int, length: int): number;
        /**
         * @param recordKeys an array of IQualifiedKeys
         * @param column1 first IAttributeColumn
         * @param column2 second IAttributeColumn
         * @param keyNumberMap key->column->value mapping to speed up computation
         * @return The euclidean distance between the two column parameters
         */
        static getEuclideanDistance(recordKeys: IQualifiedKey[], column1: IAttributeColumn, column2: IAttributeColumn, keyNumberMap: D2D_KeyColumnNumber): number;
        /**
         * @param recordKeys an array of IQualifiedKeys
         * @param column1 first IAttributeColumn
         * @param column2 second IAttributeColumn
         * @param keyNumberMap recordKey->column->value mapping to speed up computation
         * @return The cosine similarity between two parameter columns
         */
        static getCosineSimilarity(recordKeys: IQualifiedKey[], column1: IAttributeColumn, column2: IAttributeColumn, keyNumberMap: D2D_KeyColumnNumber): number;
        /**
         * Creates a dxd similarity matrix (where d is the length of the parameter array)
         * @param array An array of IAttributeColumns
         * @param keyNumberMap recordKey->column->value mapping to speed up computation
         * @return A 2D Array representing a similarity matrix
         */
        static getGlobalSimilarityMatrix(array: IAttributeColumn[], keyNumberMap: D2D_KeyColumnNumber): number[][];
        /**
         * Creates a neighborhood matrix (where d is the length of the parameter array)
         * @param array An array of IAttributeColumns
         * @return A 2D Array representing a neighborhood matrix
         */
        static getNeighborhoodMatrix(array: IAttributeColumn[]): number[][];
        /**
         * Creates a sorted similarity matrix consisting of MatrixEntry objects,
         * with the columns with the highest similarity first
         * @param array An array of IAttributeColumns
         * @param keyNumberMap recordKey->column->value mapping to speed up computation
         * @return A 1D array consisting of MatrixEntry objects
         */
        static getSortedSimilarityMatrix(array: IAttributeColumn[], keyNumberMap: D2D_KeyColumnNumber): MatrixEntry[];
        /**
         * Calculates and returns the similarity measure
         * @param similarityMatrix A 2D Array representing a similarity matrix
         * @param neighborhoodMatrix A 2D Array representing a neighborhood matrix
         * @return similarity measure for the parameter matrices
         */
        static getSimilarityMeasure(similarityMatrix: number[][], neighborhoodMatrix: number[][]): number;
        /**
         * Searches for parameter IAttributeColumn inside the array parameter
         * @param column column to search for
         * @param orderedColumns array of IAttributeColumns to search for column parameter
         * @return the column if it is found, null if not
         */
        static searchForColumn(column: IAttributeColumn, orderedColumns: IAttributeColumn[]): IAttributeColumn;
    }
}
declare namespace weavejs.geom.radviz {
    import IAttributeColumn = weavejs.api.data.IAttributeColumn;
    import LinkableNumber = weavejs.core.LinkableNumber;
    /**
     * An implementation of the RANDOM_LAYOUT dimensional ordering algorithm.
     * This algorithm randomly swaps dimensions for a certain number of iterations using a similarity measure.
     */
    class RandomLayoutAlgorithm extends AbstractLayoutAlgorithm implements ILayoutAlgorithm {
        iterations: LinkableNumber;
        private similarityMatrix;
        private neighborhoodMatrix;
        performLayout(columns: IAttributeColumn[]): void;
    }
}
declare module "weave/plot/AbstractPlotter" {
    import * as weavejs from "weavejs";
    import { Graphics } from "pixi.js";
    import Bounds2D = weavejs.geom.Bounds2D;
    import IQualifiedKey = weavejs.api.data.IQualifiedKey;
    import Rectangle = weavejs.geom.Rectangle;
    import ILinkableObject = weavejs.api.core.ILinkableObject;
    import ICallbackCollection = weavejs.api.core.ICallbackCollection;
    import IKeySet = weavejs.api.data.IKeySet;
    import FilteredKeySet = weavejs.data.key.FilteredKeySet;
    import IFilteredKeySet = weavejs.api.data.IFilteredKeySet;
    import IColumnWrapper = weavejs.api.data.IColumnWrapper;
    import ILinkableHashMap = weavejs.api.core.ILinkableHashMap;
    import ISelectableAttributes = weavejs.api.data.ISelectableAttributes;
    import { IPlotTask } from "weave/api/ui/IPlotTask";
    import IPlotter from "weave/api/ui/IPlotter";
    /**
     * This is a base implementation for an IPlotter.
     */
    export abstract class AbstractPlotter implements IPlotter, ISelectableAttributes {
        constructor();
        readonly selectableAttributes: Map<string, IColumnWrapper | ILinkableHashMap>;
        getSelectableAttributeNames(): string[];
        getSelectableAttributes(): (IColumnWrapper | ILinkableHashMap)[];
        /**
         * Registers dependencies that affect data bounds and should trigger spatial callbacks.
         */
        protected addSpatialDependencies(...dependencies: ILinkableObject[]): void;
        /**
         * This variable should not be set manually.  It cannot be made constant because we cannot guarantee that it will be initialized
         * before other properties are initialized, which means it may be null when someone wants to call registerSpatialProperty().
         */
        private _spatialCallbacks;
        /**
         * This is an interface for adding callbacks that get called when any spatial properties of the plotter change.
         * Spatial properties are those that affect the data bounds of visual elements.
         */
        readonly spatialCallbacks: ICallbackCollection;
        /**
         * This will set up the keySet so it provides keys in sorted order based on the values in a list of columns.
         * @param columns An Array of IAttributeColumns to use for comparing IQualifiedKeys.
         * @param sortDirections Array of sort directions corresponding to the columns and given as integers (1=ascending, -1=descending, 0=none).
         * @see weave.data.KeySets.FilteredKeySet#setColumnKeySources()
         */
        protected setColumnKeySources(columns: IKeySet[], sortDirections?: number[]): void;
        /**
         * This function sets the base IKeySet that is being filtered.
         * @param keySet A new IKeySet to use as the base for this FilteredKeySet.
         */
        protected setSingleKeySource(keySet: IKeySet): void;
        /**
         * This variable is returned by get keySet().
         */
        protected _filteredKeySet: FilteredKeySet;
        /**
         * @return An IKeySet interface to the record keys that can be passed to the drawRecord() and getDataBoundsFromRecordKey() functions.
         */
        readonly filteredKeySet: IFilteredKeySet;
        /**
         * This function must be implemented by classes that extend AbstractPlotter.
         * When you implement this function, you may use initBoundsArray() for convenience.
         *
         * This function returns a Bounds2D object set to the data bounds associated with the given record key.
         * @param recordKey The key of a data record.
         * @param output An Array of Bounds2D objects to store the result in.
         * @return An Array of Bounds2D objects that make up the bounds for the record.
         */
        getDataBoundsFromRecordKey(recordKey: IQualifiedKey, output: Bounds2D[]): void;
        /**
         * variables for template code
         */
        protected clipRectangle: Rectangle;
        /**
         * This function will perform one iteration of an asynchronous rendering task.
         * This function will be called multiple times across several frames until its return value is 1.0.
         * This function may be defined with override by classes that extend AbstractPlotter.
         * @param task An object containing the rendering parameters.
         * @return A number between 0 and 1 indicating the progress that has been made so far in the asynchronous rendering.
         */
        drawPlotAsyncIteration(task: IPlotTask): number;
        protected addRecordGraphics(recordKey: IQualifiedKey, dataBounds: Bounds2D, screenBounds: Bounds2D, buffer: Graphics): void;
        /**
         * This function draws the background graphics for this plotter, if applicable.
         * An example background would be the origin lines of an axis.
         * @param dataBounds The data coordinates that correspond to the given screenBounds.
         * @param screenBounds The coordinates on the given sprite that correspond to the given dataBounds.
         * @param destination The sprite to draw the graphics onto.
         */
        drawBackground(dataBounds: Bounds2D, screenBounds: Bounds2D, destination: Graphics): void;
        /**
         * This function returns a Bounds2D object set to the data bounds associated with the background.
         * @return A Bounds2D object specifying the background data bounds.
         */
        getBackgroundDataBounds(output: Bounds2D): void;
        /**
         * This is a convenience function for use inside getDataBoundsFromRecordKey().
         * @param output An output Array, which may already contain any number of Bounds2D objects.
         * @param desiredLength The desired number of output Bounds2D objects to appear in the output Array.
         * @return The first Bounds2D item in the Array, or null if desiredLength is zero.
         */
        initBoundsArray(output: Bounds2D[], desiredLength?: number): Bounds2D;
    }
    export default AbstractPlotter;
}
declare module "weave/plot/AbstractGlyphPlotter" {
    import * as weavejs from "weavejs";
    import Point = weavejs.geom.Point;
    import IQualifiedKey = weavejs.api.data.IQualifiedKey;
    import Bounds2D = weavejs.geom.Bounds2D;
    import IObjectWithDescription = weavejs.api.ui.IObjectWithDescription;
    import LinkableBoolean = weavejs.core.LinkableBoolean;
    import IColumnStatistics = weavejs.api.data.IColumnStatistics;
    import DynamicColumn = weavejs.data.column.DynamicColumn;
    import LinkableString = weavejs.core.LinkableString;
    import IKeySet = weavejs.api.data.IKeySet;
    import { AbstractPlotter } from "weave/plot/AbstractPlotter";
    /**
     * A glyph represents a point of data at an X and Y coordinate.
     */
    export default class AbstractGlyphPlotter extends AbstractPlotter implements IObjectWithDescription {
        constructor();
        getDescription(): string;
        dataX: DynamicColumn;
        dataY: DynamicColumn;
        zoomToSubset: LinkableBoolean;
        protected statsX: IColumnStatistics;
        protected statsY: IColumnStatistics;
        hack_setSingleKeySource(keySet: IKeySet): void;
        sourceProjection: LinkableString;
        destinationProjection: LinkableString;
        tempPoint: Point;
        private _projector;
        private _xCoordCache;
        private _yCoordCache;
        /**
         * This gets called whenever any of the following change: dataX, dataY, sourceProjection, destinationProjection
         */
        private updateProjector;
        getCoordsFromRecordKey(recordKey: IQualifiedKey, output: Point): void;
        /**
         * The data bounds for a glyph has width and height equal to zero.
         * This function returns a Bounds2D object set to the data bounds associated with the given record key.
         * @param recordKey The key of a data record.
         * @param output An Array of Bounds2D objects to store the result in.
         */
        getDataBoundsFromRecordKey(recordKey: IQualifiedKey, output: Bounds2D[]): void;
        /**
         * This function returns a Bounds2D object set to the data bounds associated with the background.
         * @param output A Bounds2D object to store the result in.
         */
        getBackgroundDataBounds(output: Bounds2D): void;
    }
}
declare module "weave/plot/DrawUtils" {
    import * as weavejs from "weavejs";
    import { Graphics } from "pixi.js";
    import Point = weavejs.geom.Point;
    /**
     * A set of static functions for drawing to Graphics objects.
     */
    export default class DrawUtils {
        /**
         * Clears the line style for a Graphics object with optimal performance.
         */
        static clearLineStyle(graphics: Graphics): void;
        /**
         * Similar to lineTo() and curveTo(), this will draw an arc on a Graphics object.
         * @param graphics The Graphics where the arc will be drawn
         * @param continueLine If this is true, lineTo() will be used on the first coordinate instead of moveTo()
         * @param xCenter The x center coord of the arc
         * @param yCenter The y center coord of the arc
         * @param startAngle The angle where the arc starts
         * @param endAngle The angle where the arc ends
         * @param radius The radius of the circle that contains the arc
         * @param yRadius Optional y radius for an elliptical arc instead of a circular one
         * @param outputStartCoords A Point object used to output the starting coordinates of the arc.
         */
        static arcTo(graphics: Graphics, continueLine: boolean, xCenter: number, yCenter: number, startAngle: number, endAngle: number, radius: number, yRadius?: number, outputStartCoords?: Point): void;
        /**
         * @param horizontalEndPoints When true, the curve starts and ends horizontal. When false, vertical.
         * @param curveNormValue Values that produce nice curves range from 0 to 1, 0 being a straight line.
         * @param continuingLine If true, the graphics cursor is assumed to be already at (startX,startY) and moveTo will not be used prior to drawing the curve.
         */
        static drawDoubleCurve(graphics: Graphics, startX: number, startY: number, endX: number, endY: number, horizontalEndPoints: boolean, curveNormValue?: number, continuingLine?: boolean): void;
        static drawCurvedLine(graphics: Graphics, startX: number, startY: number, endX: number, endY: number, curvature: number): void;
        /**
         * Draws a dashed line using lineTo/moveTo with the current lineStyle of a Graphics object.
         * @param graphics The Graphics object on which to draw.
         * @param points A list of Point objects defining a polyline.
         * @param dashedLengths A list of alternating segment and gap lengths.
         */
        static drawDashedLine(graphics: Graphics, points: Point[], dashedLengths: number[]): void;
    }
}
declare module "weave/plot/ScatterPlotPlotter" {
    import * as weavejs from "weavejs";
    import { Graphics } from "pixi.js";
    import IKeySet = weavejs.api.data.IKeySet;
    import DynamicColumn = weavejs.data.column.DynamicColumn;
    import LinkableBoolean = weavejs.core.LinkableBoolean;
    import LinkableNumber = weavejs.core.LinkableNumber;
    import ISelectableAttributes = weavejs.api.data.ISelectableAttributes;
    import IColumnWrapper = weavejs.api.data.IColumnWrapper;
    import ILinkableHashMap = weavejs.api.core.ILinkableHashMap;
    import Bounds2D = weavejs.geom.Bounds2D;
    import IQualifiedKey = weavejs.api.data.IQualifiedKey;
    import AbstractGlyphPlotter from "weave/plot/AbstractGlyphPlotter";
    import SolidFillStyle from "weave/plot/SolidFillStyle";
    import SolidLineStyle from "weave/plot/SolidLineStyle";
    export default class ScatterPlotPlotter extends AbstractGlyphPlotter implements ISelectableAttributes {
        constructor();
        readonly selectableAttributes: Map<string, ILinkableHashMap | IColumnWrapper>;
        sizeBy: DynamicColumn;
        minScreenRadius: LinkableNumber;
        maxScreenRadius: LinkableNumber;
        defaultScreenRadius: LinkableNumber;
        showSquaresForMissingSize: LinkableBoolean;
        line: SolidLineStyle;
        fill: SolidFillStyle;
        colorBySize: LinkableBoolean;
        colorNegative: LinkableNumber;
        colorPositive: LinkableNumber;
        private _sizeByStats;
        private colorDataWatcher;
        private _extraKeyDependencies;
        private _keyInclusionLogic;
        hack_setKeyInclusionLogic(keyInclusionLogic: (key: IQualifiedKey) => boolean, extraColumnDependencies: IKeySet[]): void;
        private handleColor();
        private updateKeySources();
        drawBackground(dataBounds: Bounds2D, screenBounds: Bounds2D, destination: Graphics): void;
        /**
         * This may be defined by a class that extends AbstractPlotter to use the basic template code in AbstractPlotter.drawPlot().
         */
        protected addRecordGraphics(recordKey: IQualifiedKey, dataBounds: Bounds2D, screenBounds: Bounds2D, graphics: Graphics): void;
        readonly deprecatedStateMapping: {
            absoluteValueColorEnabled: LinkableBoolean;
            absoluteValueColorMin: LinkableNumber;
            absoluteValueColorMax: LinkableNumber;
            xColumn: DynamicColumn;
            yColumn: DynamicColumn;
            alphaColumn: weavejs.data.column.AlwaysDefinedColumn;
            colorColumn: weavejs.data.column.AlwaysDefinedColumn;
            radiusColumn: DynamicColumn;
        };
    }
}
declare module "weave/tool/BarChartLegend" {
    import * as React from "react";
    import * as weavejs from "weavejs";
    import CSSProperties = React.CSSProperties;
    import ColorRamp = weavejs.util.ColorRamp;
    import LinkableHashMap = weavejs.core.LinkableHashMap;
    import LinkableNumber = weavejs.core.LinkableNumber;
    import FilteredKeySet = weavejs.data.key.FilteredKeySet;
    import DynamicKeySet = weavejs.data.key.DynamicKeySet;
    import LinkableString = weavejs.core.LinkableString;
    import IColumnWrapper = weavejs.api.data.IColumnWrapper;
    import ILinkableObjectWithNewProperties = weavejs.api.core.ILinkableObjectWithNewProperties;
    import IVisTool, { IVisToolProps, IVisToolState } from "weave/api/ui/IVisTool";
    export default class BarChartLegend extends React.Component<IVisToolProps, IVisToolState> implements IVisTool, ILinkableObjectWithNewProperties {
        chartColors: ColorRamp;
        columns: LinkableHashMap;
        panelTitle: LinkableString;
        shapeSize: LinkableNumber;
        filteredKeySet: FilteredKeySet;
        selectionKeySet: DynamicKeySet;
        probeKeySet: DynamicKeySet;
        altText: LinkableString;
        private spanStyle;
        constructor(props: IVisToolProps);
        readonly title: string;
        handleClick(label: number, temp: any): void;
        handleProbe(bin: number, mouseOver: boolean): void;
        getInteractionStyle(bin: number): CSSProperties;
        render(): JSX.Element;
        selectableAttributes: Map<string, LinkableHashMap | IColumnWrapper>;
        renderEditor: () => JSX.Element;
        readonly deprecatedStateMapping: {
            "children": {
                "visualization": {
                    "plotManager": {
                        "plotters": {
                            "plot": {
                                "filteredKeySet": FilteredKeySet;
                                "chartColors": ColorRamp;
                                "columns": LinkableHashMap;
                                "shapeSize": LinkableNumber;
                            };
                        };
                    };
                };
            };
            "panelTitle": LinkableString;
        };
    }
}
declare module "weave/tool/d3tool/AbstractAxis" {
    import * as React from "react";
    export interface AxisProps extends React.Props<AbstractAxis> {
        y: number;
        x: number;
        scale: Function;
        scalingMethod?: string;
        format: (num: any) => string;
        length: number;
    }
    export interface AxisState {
        scale: Function;
    }
    export default class AbstractAxis extends React.Component<AxisProps, AxisState> {
        element: SVGElement;
        scale: Function;
        axis: any;
        orientation: "top" | "bottom" | "left" | "right";
        constructor(props: AxisProps);
    }
}
declare module "weave/tool/d3tool/XAxis" {
    import AbstractAxis, { AxisProps } from "weave/tool/d3tool/AbstractAxis";
    export default class XAxis extends AbstractAxis {
        constructor(props: AxisProps);
        componentDidUpdate(): void;
        render(): JSX.Element;
    }
}
declare module "weave/tool/d3tool/YAxis" {
    import AbstractAxis, { AxisProps } from "weave/tool/d3tool/AbstractAxis";
    export default class YAxis extends AbstractAxis {
        constructor(props: AxisProps);
        componentDidUpdate(): void;
        render(): JSX.Element;
    }
}
declare module "weave/tool/d3tool/BoxWhiskerPlot" {
    import * as React from "react";
    import * as weavejs from "weavejs";
    import ResizingDiv = weavejs.ui.ResizingDiv;
    import AlwaysDefinedColumn = weavejs.data.column.AlwaysDefinedColumn;
    import DynamicColumn = weavejs.data.column.DynamicColumn;
    import IQualifiedKey = weavejs.api.data.IQualifiedKey;
    import Bounds2D = weavejs.geom.Bounds2D;
    import AbstractVisTool from "weave/tool/AbstractVisTool";
    import { IVisToolProps, IVisToolState } from "weave/api/ui/IVisTool";
    export type ScatterPlotRecord = {
        id: IQualifiedKey;
        x: number;
        y: number;
        r: number;
        color: string;
    };
    export type BoxWhiskerRecord = {
        id: IQualifiedKey;
        x: number;
        y: number;
    };
    export type LinePlotRecord = {
        id: IQualifiedKey;
        x: number;
        y: number;
        grouBy: number;
    };
    export interface BoxWhiskerPlotProps extends IVisToolProps, React.Props<BoxWhiskerPlot> {
    }
    export interface BoxWhiskerPlotState extends IVisToolState {
        width?: number;
        height?: number;
    }
    export default class BoxWhiskerPlot extends AbstractVisTool<BoxWhiskerPlotProps, BoxWhiskerPlotState> {
        boxwhiskerX: DynamicColumn;
        boxwhiskerY: DynamicColumn;
        scatterX: DynamicColumn;
        scatterY: DynamicColumn;
        scatterRadius: AlwaysDefinedColumn;
        scatterColor: AlwaysDefinedColumn;
        lineX: DynamicColumn;
        lineY: DynamicColumn;
        lineGrouBy: DynamicColumn;
        private boxWhiskerXStats;
        private boxWhiskerYStats;
        private scatterXStats;
        private scatterYStats;
        private lineXStats;
        private lineYStats;
        dataBounds: Bounds2D;
        screenBounds: Bounds2D;
        xScale: Function;
        yScale: Function;
        private xAxisDataType;
        private yAxisDataType;
        readonly title: string;
        private BOXWHISKER_RECORD_FORMAT;
        private LINE_RECORD_FORMAT;
        private SCATTER_RECORD_FORMAT;
        constructor(props: BoxWhiskerPlotProps);
        updateSVGSize: (resizingDiv: ResizingDiv, props: any, state: any, context: any) => void;
        renderScatterPlot(records: ScatterPlotRecord[]): JSX.Element;
        renderLinePlot(records: LinePlotRecord[]): JSX.Element;
        getPathStr(points: {
            x: number;
            y: number;
        }[]): string;
        getQ(values: number[], q: number): number;
        getYValues(key: IQualifiedKey): number[];
        renderBoxWhiskerPlot(records: BoxWhiskerRecord[]): JSX.Element;
        xAxisFormat: (num: any) => string;
        yAxisFormat: (num: any) => string;
        render(): JSX.Element;
    }
}
declare module "weave/tool/PIXIScatterPlot" {
    import AbstractVisTool from "weave/tool/AbstractVisTool";
    import ScatterPlotPlotter from "weave/plot/ScatterPlotPlotter";
    import { IVisToolProps, IVisToolState } from "weave/api/ui/IVisTool";
    export interface PIXIScatterPlotProps extends IVisToolProps {
    }
    export interface PIXIScatterPlotState extends IVisToolState {
    }
    export default class PIXIScatterPlot extends AbstractVisTool<PIXIScatterPlotProps, PIXIScatterPlotState> {
        element: HTMLDivElement;
        renderer: PIXI.WebGLRenderer | PIXI.CanvasRenderer;
        graphics: PIXI.Graphics;
        stage: PIXI.Container;
        plotter: ScatterPlotPlotter;
        constructor(props: PIXIScatterPlotProps);
        componentDidMount(): void;
        componentDidUpdate(): void;
        render(): JSX.Element;
    }
}
declare module "weave/ui/SessionStateTree" {
    import * as React from "react";
    import * as weavejs from "weavejs";
    import WeaveTreeItem = weavejs.util.WeaveTreeItem;
    import ILinkableObject = weavejs.api.core.ILinkableObject;
    export interface ISessionTreeProps extends React.HTMLProps<SessionStateTree> {
        root: WeaveTreeItem;
        open?: boolean;
        enableAccordion?: boolean;
        filter?: ILinkableObject;
        selectionStyle?: React.CSSProperties;
        clickHandler?: (selectedItem: WeaveTreeItem, state: boolean) => void;
    }
    export interface ISessionTreeState {
        open?: boolean;
    }
    export default class SessionStateTree extends React.Component<ISessionTreeProps, ISessionTreeState> {
        openedItems: WeaveTreeItem[];
        filteredArray: WeaveTreeItem[];
        selectedTreeNode: any;
        selectedTreeNodeAtEachDepth: any[];
        constructor(props: ISessionTreeProps);
        state: ISessionTreeState;
        componentWillReceiveProps(nextProps: ISessionTreeProps): void;
        getChildrenTrailOfType(child: WeaveTreeItem, childCopy: WeaveTreeItem, rootParent: WeaveTreeItem, filter: any): boolean;
        private getWeaveTreeItemCopy;
        render(): JSX.Element;
    }
    export interface ITreeNodeProps extends ISessionTreeProps {
        root: WeaveTreeItem;
        open?: boolean;
        filter?: ILinkableObject;
        selectionStyle?: React.CSSProperties;
        clickHandler?: (selectedItem: WeaveTreeItem, state: boolean) => void;
        manager: SessionStateTree;
        depth: number;
    }
}
declare module "weave/ui/LinkableDynamicObjectComponent" {
    import * as React from "react";
    import * as weavejs from "weavejs";
    import LinkableDynamicObject = weavejs.core.LinkableDynamicObject;
    import SmartComponent = weavejs.ui.SmartComponent;
    export interface ILinkableDynamicObjectComponentProps extends React.HTMLProps<LinkableDynamicObjectComponent> {
        dynamicObject: LinkableDynamicObject;
        label?: string;
    }
    export interface ILinkableDynamicObjectComponentState {
        openSessionNav?: boolean;
        linkedObjectName?: string;
    }
    export default class LinkableDynamicObjectComponent extends SmartComponent<ILinkableDynamicObjectComponentProps, ILinkableDynamicObjectComponentState> {
        constructor(props: ILinkableDynamicObjectComponentProps);
        componentWillReceiveProps(nextProps: ILinkableDynamicObjectComponentProps): void;
        componentDidMount(): void;
        private toggleFilteredSessionNav;
        private closePopOver;
        private linkSessionObject;
        unLinkSessionObject: () => void;
        render(): JSX.Element;
    }
}
